<?php
/*******************************************************************************
 *   Photos
 *******************************************************************************
 *   GuppY PHP Script - version 5.0
 *   CeCILL Copyright (C) 2004-2013 by Laurent Duveau
 *   Initiated by Laurent Duveau and Nicolas Alves
 *   Web site = http://www.freeguppy.org/
 *   e-mail   = guppy@freeguppy.org
 *   V5 developed by Lud Bienaimé
 *      with the participation of Jean-Michel Misrachi and the GuppY Team
 *******************************************************************************
 *   Version History :
 * v5.0.0 (February 15, 2014)    : initial release.
 * v5.0.2 (March 25, 2014)       : modify treatment of photos display
 * v5.0.3 (April 15, 2014)       : modify for separate display
 * v5.0.7 (August 21, 2014)      : corrected photo display
 * v5.00.10 (December 29, 2014)  : improve display photorama
 * v5.00.11 (March 2, 2015)      : add navigation bar to photorama
 *                               : modified quick admin icons
 * v5.01.00 (June 12, 2015)      : improvement for a mobile-friendly structure
 * v5.01.02 (December 02, 2015)  : corrected quick config (thanks Papinou)
 *                               : adding members access with private groups
 *                               : adding a custom error handling 404
 *                               : changing the treatment of $tconfig
 * v5.01.03 (June 07, 2016)      : replace css properties by class rules
 * v5.01.04 (September 07, 2016) : adding a visits counter
 * v5.02.00 (May 09, 2017)       : improve cookies and session management for firewall use
 *                               : improvement of impressions
 * v5.02.01 (August 28, 2017)    : suppress session cookie parameters for Edge and mobiles
 * v5.02.02 (December 18, 2017)  : added slideshow Unite Gallery
 *                               : correction of the multi-page display of slideshows
 * v5.02.03 (February 01, 2018)  : automatic disconnection improvement
 *                               : correction link "Become a member"
 ******************************************************************************/

header('Pragma: no-cache');
define('CHEMIN', '');
include CHEMIN.'inc/includes.inc';

if ($serviz[9] != 'on') {
    exit($web[143]);
}

$pg       = import('pg');
$tconfig  = import('tconfig', '', true, 0);
$largpage = import('largpage', '', true, 'N');
$idpg     = import('idpg', '', true, 1);

if (!empty($pg)) {
    $dbwork = SelectDbFieldsByField(ReadDBFields(DBPHOTO), 4, $pg);
	$isdoc  = !empty($dbwork);
	if ($isdoc) {
		$isdoc = isAuthorizedPublication($dbwork[0][5]);
        if (!isAccessGranted($dbwork[0][6])) {
			header('HTTP/1.0 403 Forbidden');
        }
    }
    if (!$isdoc) {
        $dbwork = array();
        if ($site[10] != '') {
            header('location:'.$site[3].'error.php?lng='.$lng.'&err=404');
            exit;
        }
        else header('HTTP/1.0 404 Not Found');
        $web[38] = '';
    }
}
sort($dbwork);
if (!empty($dbwork)) {
    ReadDoc($dbwork[0][4]);
	$img = getNewUpdateDoc($creadate, $moddate, $serviz[142]);
    if ($lng == $lang[0]) {
        $txt1 = $img.$fieldb1;
        $txt2 = $fieldc1;
        $txt3 = $fielda1;
    } else {
        $txt1 = $fieldb2;
        $txt2 = $fieldc2;
        $txt3 = $fielda2;
    }
    $dirgal  = 'gal_'.$fileid;
    $dirmin  = $dirgal.'/vgnt';
    $dbphoto = ReadDBFields(PHOTOREP.$dirgal.'/'.$dirgal.DBEXT);
    $tmpi    = 0;
    $tmp[0]  = array();
    $tmp[1]  = array();
    $tmp[2]  = array();
    $tmp[3]  = array();
    $tmp[4]  = array();
    $tmp[5]  = array();
    $tmp[6]  = array();
    for ($ii = 0; $ii < count($dbphoto); $ii++) {
        if ($dbphoto[$ii][1] == 'a') {
            $tmp[0][$tmpi] = $dbphoto[$ii][0];
            $tmp[1][$tmpi] = $dbphoto[$ii][1];
            $tmp[2][$tmpi] = $dbphoto[$ii][2];
            $tmp[3][$tmpi] = $dbphoto[$ii][3];
            $tmp[4][$tmpi] = $dbphoto[$ii][4];
            $tmp[5][$tmpi] = $dbphoto[$ii][5];
            $tmp[6][$tmpi] = $dbphoto[$ii][6];
            $tmpi++;
        }
    }
    unset($dbphoto);
    $cr = array_multisort($tmp[2], SORT_ASC, $tmp[0], $tmp[1], $tmp[3], $tmp[4], $tmp[5], $tmp[6]);
	if (file_exists(PHOTOREP.$dirgal.'/params_'.substr($dirgal, 4).INCEXT))
		include PHOTOREP.$dirgal.'/params_'.substr($dirgal, 4).INCEXT;
}
switch ($param4) {
case 'lightbox' :
    if (is_dir(CHEMIN.'inc/photo/lightbox')) {
		$headinc .= '
<link href="'.CHEMIN.'inc/photo/lightbox/css/lightbox.css" rel="stylesheet" />'.
JavascriptFile(CHEMIN.'inc/photo/lightbox/js/lightbox-2.6.min.js').
JavascriptFile(CHEMIN.'inc/photo/lightbox/js/modernizr.custom.js');
    }
    break;
case 'lytebox' :
    if (is_dir(CHEMIN.'inc/photo/lytebox')) {
        $headinc .= '
<link rel="stylesheet" href="'.CHEMIN.'inc/photo/lytebox/lytebox.css" type="text/css" media="screen" />'.
JavascriptFile(CHEMIN.'inc/photo/lytebox/lytebox.js');
    }
    break;
}

$topmess = strip_tags(getLabel($nom[$lng == $lang[0] ? 2 : 12])).' - '.(empty($txt3) ? '' : $txt3.' : ').$txt1;
if ($page[9] != '') {
    $topmess = '<img src="inc/img/icons/'.$page[9].'/photo.gif" class="f-right img32x32 valignMiddle" alt="" />'.$topmess;
}
$largpage = empty($largpage) ? 'N' : $largpage;
switch($largpage) {
case 'W' :
	$userprefs3 = '';
	$widepage = 'on';
	break;
case 'L' :
	$userprefs3 = 'L';
	break;
case 'R' :
	$userprefs3 = 'R';
	break;
default : 
	$userprefs3 = '';
	break;
}
include 'inc/hpage.inc';
if (function_exists('htable1'))
    htable1($topmess, 'PH2'.$tconfig, '100%');
else
    htable($topmess, '100%');

if ($members[0] == 'on' && $userprefs[1] == '' && !isAccessGranted($members[2])) {
    echo '
<div class="textCenter web342">'.$web[342];
	if ($members[19] != '0' && $members[19] != '3') 
		echo '
  <p>[&nbsp;
    <a href="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[15].'-5-new-'.$tconfig.$z2 : $site['USR'].'.php?lng='.$lng.'&amp;uuser=new&amp;tconfig='.$tconfig.$z2).'">'.$web[160].'</a>&nbsp;]
  </p>';
	echo '
</div>';
} else {
    $errpg = false;
    if (!is_file(PHOTOREP.$dirgal.'/params_'.substr($dirgal, 4).INCEXT)) {
        $txt2 = '
<p class="textCenter"><br>'.$web[680].'<br /><br /></p>';
    }
    if ($param4 == 'unitegallery') {
        $ugfile = PHOTOREP.$dirgal.'/'.$lng.'-th'.$param13.'_'.$pg.INCEXT;
        if (is_file($ugfile)) {
            if (!empty($txt2)) 
                echo '
  <div class="phcomment">'.$txt2.'</div>';
            include $ugfile;
            $countgal = UpdateDocCounter($dbwork[0][4]);
            $txtcount = $web[685].'<b>'.$countgal.' '.($countgal < 2 ? $web[188] : $web[189]).'</b>';
            if ($param12 != 'on') echo '
  <div class="galcounter textRight">('.$txtcount.')</div>';
        } else
            $errpg = true;
    } else {
        if (!empty($dbwork)) {
		echo '
  <div class="phrubr2 phsubrubr">'.$txt1.($param11 != 'on' ? '<span class="phcpt">('.$tmpi.' photos)</span>' : '').'</div>';
       	if (!empty($txt2))
			echo '
  <div class="phcomment">'.$txt2.'</div>';
        $fileid = substr($dirgal, 4);
        echo '
  <div class="phimgs">';
        if ($tmpi > 0 && is_file(PHOTOREP.$dirgal.'/params_'.$fileid.INCEXT)) {
            echo '
    <div class="phimgs2 width100 marginAuto '.($param8 == 'L' ? 'textLeft' : ($param8 == 'C' ? 'textCenter' : 'textRight')).'">';
            $nbmin = min($param1, $tmpi);
			$nbpl  = min($param6, $nbmin);
			$nb    = 0;
            if (empty($idpg)) {
                $idpg = 1;
            } else {
                while ($tmpi <= ($idpg - 1)* $nbmin) $idpg--;
            }
            $navbar = GetNavBar(($site['URLR'] == 'on' ? $lng.'-'.$urlrw[9].'-3-'.$pg.'-'.$largpage.'-'.$tconfig.'-' : 
                'photorama2.php?lng='.$lng.'&amp;pg='.$pg.'&amp;largpage='.$largpage.'&amp;tconfig='.$tconfig.'&amp;idpg='), $tmpi, $idpg, $nbmin, $z2);
            for ($ii = 0; $ii < max($nbmin*($idpg-1), 0); $ii++) {
                $filemin = PHOTOREP.$dirmin.'/'.$tmp[2][$ii];
                $fileimg = PHOTOREP.$dirgal.'/'.$tmp[2][$ii];
                $comment = stripslashes($tmp[$lng == $lang[0] ? 5 : 6][$ii]);
				echo '
      <span class="displayNone">';							
				switch ($param4) {
				case 'lightbox' :
					echo '
	    <a href="'.$fileimg.'" class="lightshow" title="'.$comment.'" data-lightbox="'.$dbwork[0][4].'" rel="lightbox[plants]">';
					break;
				case 'lytebox' :
					echo '
	    <a href="'.$fileimg.'" class="lyteshow" data-lyte-options="slide:true group:'.$dbwork[0][4].' slideInterval:'.($param5*1000).'" data-title="'.$comment.'" rel="lyteshow[diapo'.$dbwork[0][4].']">';
					break;
				}
				echo '
<style type="text/css">
.phimg2'.$fileid.$ii.' {
    width: '.$tmp[3][$ii].'px;
    height: '.$tmp[4][$ii].'px;
}
</style>
          <img src="'.$filemin.'"  class="phimg2'.$fileid.$ii.'" alt="" title="" />
	    </a>
	  </span>';
            }
            $countgal = UpdateDocCounter($dbwork[0][4]);
            $txtcount = $web[685].'<b>'.$countgal.' '.($countgal < 2 ? $web[188] : $web[189]).'</b>';
            for ($ii = $nbmin*($idpg-1); $ii < Min($nbmin*$idpg, $tmpi); $ii++) {
                $filemin = PHOTOREP.$dirmin.'/'.$tmp[2][$ii];
                $fileimg = PHOTOREP.$dirgal.'/'.$tmp[2][$ii];
                $comment = stripslashes($tmp[$lng == $lang[0] ? 5 : 6][$ii]);
				switch ($param4) {
				case 'lightbox' :
					echo '
	  <a href="'.$fileimg.'" class="lightshow" title="'.$comment.'" data-lightbox="'.$dbwork[0][4].'" rel="lightbox[plants]">';
					break;
				case 'lytebox' :
					echo '
	  <a href="'.$fileimg.'" class="lyteshow" data-lyte-options="slide:true group:'.$dbwork[0][4].' slideInterval:'.($param5*1000).'" data-title="'.$comment.'" rel="lyteshow[diapo'.$dbwork[0][4].']">';
					break;
				}
				echo '
<style type="text/css">
.phimg'.$fileid.$ii.' {
    width: '.$tmp[3][$ii].'px;
    height: '.$tmp[4][$ii].'px;
    margin: '.intval($param7/2).'px;
}
</style>
        <img src="'.$filemin.'" class="phimg phimg'.$fileid.$ii.'" alt="" title="" />
	  </a>';
				$nb++;
				if ($nb == $nbpl) {
					echo '<br />';
					$nb = 0;
				}
            }
            for ($ii = Min($nbmin*$idpg, $tmpi); $ii < $tmpi; $ii++) {
                $filemin = PHOTOREP.$dirmin.'/'.$tmp[2][$ii];
                $fileimg = PHOTOREP.$dirgal.'/'.$tmp[2][$ii];
                $comment = stripslashes($tmp[$lng == $lang[0] ? 5 : 6][$ii]);
				echo '
      <span class="displayNone">';							
				switch ($param4) {
				case 'lightbox' :
					echo '
	    <a href="'.$fileimg.'" class="lightshow" title="'.$comment.'" data-lightbox="'.$dbwork[0][4].'" rel="lightbox[plants]">';
					break;
				case 'lytebox' :
					echo '
	    <a href="'.$fileimg.'" class="lyteshow" data-lyte-options="slide:true group:'.$dbwork[0][4].' slideInterval:'.($param5*1000).'" data-title="'.$comment.'" rel="lyteshow[diapo'.$dbwork[0][4].']">';
					break;
				}
				echo '
<style type="text/css">
.phimg3'.$fileid.$ii.' {
    width: '.$tmp[3][$ii].'px;
    height: '.$tmp[4][$ii].'px;
}
</style>
          <img src="'.$filemin.'"  class="phimg3'.$fileid.$ii.'" alt="" title="" />
	    </a>
	  </span>';
            }
            echo $navbar;
            echo '
    </div>';
            if ($param12 != 'on') echo '
    <div class="galcounter textRight">('.$txtcount.')</div>';
            echo '
    <div class="c-both"></div>';
            if (empty($prt)) echo 
    displayQuickConfig(NULL, false, 'photo&amp;form=2&amp;id='.$dbwork[0][4], 'photo&amp;act=i&amp;id='.$dbwork[0][4], 'photo&amp;del='.$dbwork[0][4], 18);
        }
        unset($tmp[0],$tmp[1],$tmp[2],$tmp[3],$tmp[4],$tmp[5],$tmp[6]);
        echo '
  </div>';
 	} else
        $errpg = true;
    }
    if (!empty($pg) && $errpg) {
        echo '
<p>'.$web[36].'</p>';
    }
}
btable();

include_once 'inc/bpage.inc';
?>