<?php
/*******************************************************************************
 *   Search
 *******************************************************************************
 *   GuppY PHP Script - version 5.0
 *   CeCILL Copyright (C) 2004-2014 by Laurent Duveau
 *   Initiated by Laurent Duveau and Nicolas Alves
 *   Web site = http://www.freeguppy.org/
 *   e-mail   = guppy@freeguppy.org
 *   V5 developed by Lud Bienaimé
 *      with the participation of Jean-Michel Misrachi and the GuppY Team
 *******************************************************************************
 *   Version History :
 * v5.0.0 (February 15, 2014)    : initial release.
 * v5.0.3 (April 15, 2014)       : corrected import of $searchin
 * v5.0.5 (June 07, 2014)        : corrected navigation between pages
 * v5.0.9 (November 28, 2014)    : corrected blog and agenda search in secong lang
 * v5.00.11 (March 2, 2015)      : corrected title link for articles (thanks jerlal)
 * v5.01.00 (June 12, 2015)      : improvement for a mobile-friendly structure
 *                               : add checkbox option to print result
 *                               : add searching on author
 * v5.01.02 (December 02, 2015)  : adding members access with private groups
 *                               : changing the treatment of $tconfig
 * v5.01.03 (June 07, 2016)      : replace css properties by class rules
 * v5.01.04 (September 07, 2016) : correcting access rights forum, reblog, react
 * v5.02.00 (May 09, 2017)       : improve cookies and session management for firewall use
 * v5.02.01 (August 28, 2017)    : suppress session cookie parameters for Edge and mobiles
 * v5.02.03 (February 01, 2018)  : automatic disconnection improvement
 *                               : correction link "Become a member"
 ******************************************************************************/

header('Pragma: no-cache');
define('CHEMIN', '');
include CHEMIN.'inc/includes.inc';

include CONFIGREP.'searchconfig.inc';

if ($serviz[24] != 'on') {
    exit($web[143]);
}

$search    = import('search');
$searchin  = import('searchin');
$searchlng = import('searchlng');
$cat       = import('cat', '', false, 0);

$savesearch = $search;
$restricted = false;

$savepertinencemin = $pertinencemin;
$pertinencemin     = import('pert');

if ($userprefs[1] == '' && $members[0] == 'on') {
    if (!empty($searchin)) {
        $searchfor = array($searchin);
        $illegal   = false;
        switch ($searchin) {
        case TYP_ART :
        case TYP_REACT :
            if (!isAccessGranted($members[1])) $illegal = true;
            break;
        case TYP_BLOG :
        case TYP_REBLOG :
            if (!isAccessGranted($members[15])) $illegal = true;
            break;
        case TYP_DNLOAD :
            if (!isAccessGranted($members[7])) $illegal = true;
            break;
        case TYP_FAQ :
            if (!isAccessGranted($members[4])) $illegal = true;
            break;
        case TYP_FORUM :
            if (!isAccessGranted($members[5])) $illegal = true;
            break;
        case TYP_GUESTBK :
            if (!isAccessGranted($members[12])) $illegal = true;
            break;
        case TYP_LINKS :
            if (!isAccessGranted($members[3])) $illegal = true;
            break;
        case TYP_NEWS :
            if (!isAccessGranted($members[13])) $illegal = true;
            break;
        case TYP_PHOTO :
            if (!isAccessGranted($members[2])) $illegal = true;
            break;
        case TYP_AGENDA :
            if (!isAccessGranted($members[14])) $illegal = true;
            break;
        }
        if ($illegal) {
            die('STOP ! Illegal search');
        }
    } else {
		$searchall = array (TYP_ART, TYP_DNLOAD, TYP_FAQ, TYP_FORUM, TYP_FREEBOX, TYP_GUESTBK, TYP_LINKS, TYP_NEWS, TYP_PHOTO, TYP_REACT, TYP_AGENDA, TYP_BLOG, TYP_REBLOG, TYP_ARCH);
        $searchfor = array();
        foreach ($searchall as $typ) {
            switch ($typ) {
            case TYP_ART :
            case TYP_REACT :
                if (isAccessGranted($members[1])) $searchfor[] = $typ; else $restricted = true;
                break;
            case TYP_BLOG :
            case TYP_REBLOG :
                if (isAccessGranted($members[15])) $searchfor[] = $typ; else $restricted = true;
                break;
            case TYP_DNLOAD :
                if (isAccessGranted($members[7])) $searchfor[] = $typ; else $restricted = true;
                break;
            case TYP_FAQ :
                if (isAccessGranted($members[4])) $searchfor[] = $typ; else $restricted = true;
                break;
            case TYP_FORUM :
                if (isAccessGranted($members[5])) $searchfor[] = $typ; else $restricted = true;
                break;
            case TYP_GUESTBK :
                if (isAccessGranted($members[12])) $searchfor[] = $typ; else $restricted = true;
                break;
            case TYP_LINKS :
                if (isAccessGranted($members[3])) $searchfor[] = $typ; else $restricted = true;
                break;
            case TYP_NEWS :
                if (isAccessGranted($members[13])) $searchfor[] = $typ; else $restricted = true;
                break;
            case TYP_PHOTO :
                if (isAccessGranted($members[2])) $searchfor[] = $typ; else $restricted = true;
                break;
            case TYP_AGENDA :
                if (isAccessGranted($members[14])) $searchfor[] = $typ; else $restricted = true;
                break;
            case TYP_ARCH :
                $searchfor[] = $typ;
                break;
            default :
                $searchfor[] = $typ;
            }
            unset($searchall);
        }
    }
} else {
    $searchfor = array (TYP_ART, TYP_DNLOAD, TYP_FAQ, TYP_FORUM, TYP_FREEBOX, TYP_GUESTBK, TYP_LINKS, TYP_NEWS, TYP_PHOTO, TYP_REACT, TYP_AGENDA, TYP_BLOG, TYP_REBLOG, TYP_ARCH);
}

function Rechercher($expr, $string) {
	global $tokens;
	$res        = 0;
	$total      = 0;
	$occurrence = array();
	$i          = 0;
	$k          = 0;
	foreach ($expr as $exp) {
		$r = preg_match_all('"'.$exp.'"', $string, $x);
		if (($r !== false) && ($r > 0)) {
			$res += (10 + max(100-20*$i, 1))*(9 + min($r, 5));
		}
		if (in_array($exp, $tokens)) {
			$occurrence['mot'][$k] = $exp;
			$occurrence['nb'][$k]  = $r;
			$total += $r;
			$k++;
		}
		$i++;
	}
	if ($total == 0) $res = 0;
	$occurrence['stat'][0] = $res;
	$occurrence['stat'][1] = $total;
	return $occurrence;
}

function GetTitleMenuBox($id) {
	global $lng, $lang;
	$title = '';
    $id    = TestFileID($id);
    if (FileDBExist(DBBASE.$id.INCEXT)) {
        include DBBASE.$id.INCEXT;
		$title = ($lng == $lang[0]) ? $fieldb1 : $fieldb2;
    }
	return $title;
}

$longword  = 100;
$longbarre = 75;
$nbresult  = $resultbypage;

$stylespan  = '<span style="';
$stylespan .= ($styleocc[0] == '') ? '' : 'color:'.$styleocc[0].'; ';
$stylespan .= ($styleocc[1] == '') ? '' : 'font-style:'.$styleocc[1].'; ';
$stylespan .= ($styleocc[2] == '') ? '' : 'font-weight:'.$styleocc[2].'; ';
$stylespan .= ($styleocc[3] == '') ? '' : 'text-decoration:'.$styleocc[3].'; ';
$stylespan .= ($styleocc[4] == '') ? '' : 'background-color:';
$endstyle   = '</span>';

$found  = array();
$search = stripslashes(trim($search));
$search = str_replace(array('^', '[', ']', '.', '+', '?', '*', '|'), '', $search);
$search = str_replace(array('(', ')'), ' ', $search);

if (!empty($search)) {
    $searchlower = strtolower($search);

    $nbres = preg_match_all('/[ \t]*"([^ \t"]+[^"]*[^ \t"]+)"[ \t]*|[ \t]*([^ \t]+)[ \t]*/', $searchlower, $res);
    if (($nbres !== false) && ($nbres > 0)) {
        $search = '';
        for ($i=0; $i < count($res[1]); $i++) {
            if (empty($res[1][$i])) {
                $tokens[] = str_replace(array('/', '"'), array('\/', ''), trim($res[0][$i]));
                $search  .= $tokens[$i].' ' ;
            }
            else {
                $tokens[] = str_replace('/', '\/', $res[1][$i]);
                $search  .= "'".$tokens[$i]."' ";
            }
        }

		//------ Elargir la recherche sur des expressions similaires à la requête ------//
		$expression = array();
		$k          = 0;
		for ($i = 0; $i < count($tokens); $i++) {
			$expression[$k] = '';
			for ($j = 0; $j < count($tokens) - $i; $j++) {
				$expression[$k] .= ' '.$tokens[$j];
			}
			$expression[$k] = trim($expression[$k]);
			$k++;
		}
		for ($i = 1; $i < count($tokens); $i++) {
			$expression[$k] = $tokens[$i];
			$k++;
		}
		for ($i = count($tokens) - 2; $i > 0; $i--) {
			$expression[$k] = '';
			for ($j = count($tokens) - 1; $j >= $i; $j--) {
				$expression[$k] = $tokens[$j].' '.$expression[$k];
			}
			$expression[$k] = trim($expression[$k]);
			$k++;
		}
		unset($k);
		$tokens     = array_unique($tokens);
		$expression = array_unique($expression);
		
		//---------------- Vire tous les termes inutiles (non exhaustif) ---------------//
		$exclus = $lng == $lang[0] ? $exclure0 : $exclure1;
		if (!empty($exclus)) {
			$exclure = explode(',', $exclus);
			for ($i = 0; $i < count($exclure); $i++) {
				$exclure[$i] = trim($exclure[$i]);
				if ($exclure[$i] == '') {
					array_splice($exclure, $i);
					$i--;
				}
			}
			array_unique($exclure);
		}
		
		$ignore = array();
		$j      = 0;
		for ($i = 0; $i < count($tokens); $i++) {
			if (in_array($tokens[$i], $exclure)) {
				if (!in_array($tokens[$i], $ignore)) {
					$ignore[$j] = $tokens[$i];
					$j++;
				}
				array_splice($tokens, $i, 1);
				$i--;
			}
			if (strpos($tokens[$i], "'") == 1) $tokens[$i] = substr(strrchr($tokens[$i], "'"), 1);
		}
		unset($j);

		if (!empty($tokens)) {
			for ($i = 0; $i < count($expression); $i++) {
				if (in_array($expression[$i], $exclure)) {
					array_splice($expression, $i, 1);
					$i--;
				}
				if (strpos($expression[$i], "'") == 1) $expression[$i] = substr(strrchr($expression[$i], "'"), 1);
			}
			if ($tokens[0] != $expression[0]) {
				for ($i=count($tokens); $i>0; $i--) {
					$tokens[$i] = $tokens[$i-1];
				}
				$tokens[0] = $expression[0];
			}
		} else {
			$expression = $tokens;
		}

        $search = trim($search);		
        if (!empty($searchin)) {
            if ($searchin == TYP_ARCH) {
				$dbwork = SelectDBFieldsByStatus(ReadDBFields(DOCIDARCH), 'a');
				for ($i = 0; $i < count($dbwork); $i++) $dbwork[$i][4] = 'i';
			} else {
				$dbwork = SelectDBFields($searchin, 'a', '');
				for ($i = 0; $i < count($dbwork); $i++) $dbwork[$i][4] = 'a';
			}
        } else {
            $dbw1 = SelectDBFieldsByStatus(ReadDBFields(DOCID), 'a');
			for ($i = 0; $i < count($dbw1); $i++) $dbw1[$i][4] = 'a';
            $dbw2 = SelectDBFieldsByStatus(ReadDBFields(DOCIDARCH), 'a');
			for ($i = 0; $i < count($dbw2); $i++) $dbw2[$i][4] = 'i';
			$dbwork = array_merge($dbw1, $dbw2);
        }
        @rsort($dbwork);

        $type_unilingue = array(TYP_GUESTBK, TYP_REACT, TYP_REBLOG, TYP_FORUM);
        $searchlng0     = (empty($searchlng) || $searchlng == $lang[0]);
        $searchlng1     = (empty($searchlng) || $searchlng == $lang[1]);

        $j = 0;
        foreach ($dbwork as $dbw) {
            if ($dbw[4] == 'a')
				ReadDoc($dbw[1]);
			else
				ReadDoc($dbw[1], ARCHDBBASE);
            if ($type == TYP_FORUM) {
                $frcat = explode(',', $fieldb2);
                if (!empty($frcat[1]) && !isAccessGranted($frcat[1])) {
                    continue;
                }
            } else {
                if (!isAccessGranted($fieldmod) || !isAuthorizedPublication($creadate)) {
                    continue;
                }
            }
            if ((empty($type)) || (!in_array($type, $searchfor))) continue;
            $unilingue = in_array($type, $type_unilingue);
            if ($searchlng0 || $unilingue) {
				//----- Variable $occurrence qui stocke les résultats attribuée à $found[5] ----//
                $txt        = strip_tags(strtolower($author.' '.$fielda1.' '.$fieldb1.' '.$fieldc1));
				$occurrence = Rechercher($expression, $txt);
				$note       = $occurrence['stat'][0];
                if ($note > 0) {
                    $found[0][$j] = $note;
                    $found[1][$j] = (empty($moddate) ? $creadate : $moddate);
                    $found[2][$j] = ($unilingue ? 0 : 1);
                    $found[3][$j] = $type;
                    $found[4][$j] = $dbw[1];
					$found[5][$j] = $occurrence;
                    $found[6][$j] = $dbw[4];
                    $j++;
                }
            }
            if ($searchlng1 && $type != TYP_FORUM) {
                $txt        = strip_tags(strtolower($author.' '.$fielda2.' '.$fieldb2.' '.$fieldc2));
				$occurrence = Rechercher($expression, $txt);
				$note       = $occurrence['stat'][0];
                if ($note > 0) {
                    $found[0][$j] = $note;
                    $found[1][$j] = (empty($moddate) ? $creadate : $moddate);
                    $found[2][$j] = 2;
                    $found[3][$j] = $type;
                    $found[4][$j] = $dbw[1];
					$found[5][$j] = $occurrence;
                    $found[6][$j] = $dbw[4];
                    $j++;
                }
            }
        }
        unset($dbwork);

        if (count($found) > 0) {
            array_multisort($found[0], SORT_DESC, SORT_NUMERIC, $found[1], SORT_DESC, $found[2], SORT_ASC, $found[3], $found[4], $found[5], $found[6]);

            if (empty($searchin) || $searchin == TYP_FORUM) {
                $cattitle = array();
                if ($serviz[18] == 'on') {
                    $catwork = ReadDBFields(DBFORUMCAT);
				    for ($i = 0; $i < count($catwork); $i++){
						$cattitle[$catwork[$i][0]][1] = $catwork[$i][1];
						$cattitle[$catwork[$i][0]][2] = $catwork[$i][2];
					}
                    unset($catwork);
                }
                $fridthd = array();
                $frtitle = array();
                $fridcat = array();
                $frwork = ReadDBFields(DBFORUM);
                for ($i = 0; $i < count($frwork); $i++) {
                    $fridthd[$frwork[$i][1]] = $frwork[$i][2];
                    $frtitle[$frwork[$i][1]] = $frwork[$i][5];
                    $fridcat[$frwork[$i][1]] = $frwork[$i][12];
                }
                unset($frwork);
            }
        }
    }
}

//------------ Caractères à remplacer dans str_word_count ----------------------//
$accent     = array("à", "â", "é", "è", "ê", "ë", "î", "ï", "ô", "ù");
$sansaccent = array("a", "a", "e", "e", "e", "e", "i", "i", "o", "u");
//------------------------------------------------------------------------------//

$tconfig = $confpage == 'ALL' ? import('tconfig', '', true, 0) : $confpage;
$topmess = $web[59].' - '.stripslashes($search);
include 'inc/hpage.inc';
if (function_exists('htable1'))
    htable1($topmess, 'TrSCH'.$tconfig, '100%');
else
    htable($topmess, '100%');

if (empty($found)) {
	echo '
<p class="textCenter"><strong>'.$web[62].'</strong></p>';
	btable();
	include('inc/bpage.inc');
	exit();
}

if (empty($id)) {
    $id = 1;
}

if (count($found[0]) != 0) {
    if (count($found[0]) == 1) {
        echo '
<p class="textCenter"><strong>1</strong> '.$web[60].' <strong>'.stripslashes($search).'</strong></p>';
    }
    else {
        echo '
<p class="textCenter"><strong>'.count($found[0]).'</strong> '.$web[61].' <strong>'.stripslashes($search).'</strong></p><hr /> ';
    }
	
	//--------------------------- Affiche les mots ignorés -------------------------//
	if (!empty($ignore)) {
		echo '<div class="textCenter marginAuto">( ';
		if (count($ignore) == 1) {
			echo ($web[569].'<b>'.$ignore[0].'</b>'.$web[570].$web[573]);
		} else {
			echo ($web[571]);
			for ($i = 0; $i < count($ignore); $i++) {
				echo ('<b>'.$ignore[$i].'</b>, ');
			}
			echo($web[572].$web[573]);    
		}
		echo ')</div>';
	}
  
	//------------------------------------------------------------------------------//
	if ($pertinencemin > 0) echo '<div class="textCenter marginAuto fontXsmall">'.$web[574].'</div>';
	echo '<br /><br />';

    if (count($found[0]) - ($nbresult * ($id - 1)) > $nbresult) {
        $maxresult = $nbresult;
    } else {
        $maxresult = count($found[0]) - ($nbresult*($id-1));
    }
    $imgprtsearc = '<img src="'.$reptheme.'/print.png" class="clsCursor" alt="'.$web[22].'" title="'.$web[22].'" /> '.$web[22].' ';
    $imgdnlsearc = '<img src="'.$reptheme.'/dd.png" class="clsCursor" alt="'.$web[362].'" title="'.$web[362].'" /> '.$web[362].' ';
    $ilng        = ($lng != $lang[1] ? 0 : 1);
	
	//---- Modification de l'affichage des barres de résultat qui tient compte: ----//
	//---- de l'absence de résultat sur un terme de la requête ---------------------//
	//---- de la présence de l'expression exacte dans les résultats ----------------//
	$notemax = $found[0][0];
	$first   = $found[5][0];
	for ($i = 1; $i < count($first['mot']); $i++) {
		if ($first['nb'][$i] == 0) {
			$notemax += $found[0][0] * (count($first['mot']) - $i) / count($first['mot']);
		} 
	}
	if ($first['nb'][0] > 0) {
		$coef    = 1 + 2 / 10;
		$notemax = $notemax * $coef;
	}
	//------------------------------------------------------------------------------//
	$stop          = false;
	$nbresultshown = 0;
	$prive         = 0; /// modif accès privé
    for ($i = $nbresult*($id-1); $i < Min($nbresult*$id, count($found[0])); $i++) {
		if (!$stop) {
			if ($found[6][$i] == 'a')
				ReadDoc($found[4][$i]);
			else
				ReadDoc($found[4][$i], ARCHDBBASE);
			$acces  = isAccessGranted($fieldmod) && isAuthorizedPublication($creadate);
			$doctit = '';
			$doclnk = '';
			$doctxt = '';
			$docinv = '';
			switch ($found[2][$i]) {
			case 0 :
				$doclang = 'lang';
				switch ($found[3][$i]) {
				case TYP_GUESTBK :
					$doctit = '<strong>'.getLabel($nom[9 + 10 * $ilng]).' :</strong> '.$web[39].' <strong>'.$fielda1.'</strong> - '.$web[6].' '.$author.' '.$web[7].' '.FormatDate($creadate);
					$doclnk = $site['URLR'] == 'on'? $lng.'-'.$urlrw[7].'-3-'.$fileid.$z2 : $site['GB'].'.php?lng='.$lng.'&amp;pg='.$fileid.$z2;
					break;
				case TYP_REACT :
					$doctit0 = '<strong>'.$web[187].' :</strong> ';
					$doctit2 = $web[185].$fielda1.' - '.$web[6].' '.$author.' '.$web[7].' '.FormatDate($creadate);
					$doclnk = $site['URLR'] == 'on' ? $lng.'-'.$urlrw[20].'-101-'.$fielda2.'-'.$fileid.$z2 : 'articles.php?lng='.$lng.'&amp;pg='.$fielda2.'&amp;react='.$fileid.$z2;
					ReadDoc($fielda2);
                    $acces   = isAccessGranted($fieldmod) && isAuthorizedPublication($creadate);
					$doctit1 = ($lng == $lang[0] ? $fieldb1 : $fieldb2);
					$doctit  = $doctit0.' <strong>'.$doctit1.' :</strong> '.$doctit2;
					break;
				case TYP_REBLOG :
					$doctit0 = '<strong>'.$web[381].' - '.$web[379].' :</strong> ';
					$doctit2 = $web[185].$fielda1.' - '.$web[6].' '.$author.' '.$web[7].' '.FormatDate($creadate);
					if ($found[6][$i] == 'a') {
						$doclnk = $site['URLR'] == 'on' ? $lng.'-'.$urlrw[1].'-47-'.$fielda2.'-'.$fileid.$z2 : $site['BL'].'.php?lng='.$lng.'&amp;pg='.$fielda2.'&amp;react='.$fileid.$z2;
						ReadDoc($fielda2);
					} else {
						$doclnk = $site['URLR'] == 'on' ? $lng.'-'.$urlrw[1].'-48-'.$fielda2.'-'.$fileid.$z2 : 'blogarch.php?lng='.$lng.'&amp;pg='.$fielda2.'&amp;react='.$fileid.$z2;
						ReadDoc($fielda2, ARCHDBBASE);
					}
                    $acces   = isAccessGranted($fieldmod) && isAuthorizedPublication($creadate);
					$doctit1 = ($lng == $lang[0] ? $fieldb1 : $fieldb2);
					$doctit  = $doctit0.' <strong>'.$doctit1.' :</strong> '.$doctit2;
					break;
				case TYP_FORUM :
                    $frcat = explode(',', $fieldb2);
                    $acces = isForumAccessGranted($frcat[0]) && (empty($frcat[0]) ? $serviz[18] == '' : true);
					$doctit = '<strong>'.getLabel($nom[22 + $ilng]).'</strong>';
					if ($serviz[18] == 'on' && !empty($fridcat[$fielda1]) && !empty($cattitle[$fridcat[$fielda1]][1 + $ilng])) {
						$doctit .= ' : <strong>'.$cattitle[$fridcat[$fielda1]][1 + $ilng].'</strong>';
					}
					if (!empty($fieldb1)) {
						$doctit .= ' : '.$web[63].' '.$fielda1.' <strong>'.$fieldb1.'</strong>';
						if ($found[6][$i] == 'a') {
							$thrdid = GetThreadId($fielda1);
							$doclnk = $site['URLR'] == 'on' ? $lng.'-'.$urlrw[5].'-4-'.$thrdid.'-'.(empty($fridcat[$fielda1]) ? 0: $fridcat[$fielda1]).$z2 : $site['TH'].'.php?lng='.$lng.'&amp;pg='.$thrdid.GetOptionnalArg('cat', (empty($fridcat[$fielda1])? 0: $fridcat[$fielda1])).$z2;
						} else {
							$thrdid = GetThreadId($fielda1, DBTHREADARCH);
							$doclnk = $site['URLR'] == 'on' ? $lng.'-'.$urlrw[5].'-42-'.$thrdid.'-'.(empty($fridcat[$fielda1]) ? 0: $fridcat[$fielda1]).$z2 : 'threadarch.php?lng='.$lng.'&amp;pg='.$thrdid.GetOptionnalArg('cat', (empty($fridcat[$fielda1])? 0: $fridcat[$fielda1])).$z2;
						}
					} else {
						$doctit .= ' : '.$web[63].' '.$fielda1.' <strong>'.(empty($frtitle[$fielda1])? '': $frtitle[$fielda1]).'</strong> - '.$web[68].$fielda2;
						if (empty($fridthd[$fielda1]) || empty($fridcat[$fielda1]))
							$doclnk = '';
						else {
							if ($found[6][$i] == 'a')
								$doclnk = $site['URLR'] == 'on' ? $lng.'-'.$urlrw[5].'-5-'.$fridthd[$fielda1].'-'.$fridcat[$fielda1].'-'.ceil($fielda2/$serviz[20]).'#R'.$fielda2 : $site['TH'].'.php?lng='.$lng.'&amp;pg='.$fridthd[$fielda1].GetOptionnalArg('cat', $fridcat[$fielda1]).GetOptionnalArg('id', ceil($fielda2/$serviz[20])).'#R'.$fielda2;
							else
								$doclnk = $site['URLR'] == 'on' ? $lng.'-'.$urlrw[5].'-52-'.$fridthd[$fielda1].'-'.$fridcat[$fielda1].'-'.ceil($fielda2/$serviz[20]).'#R'.$fielda2 : 'threadarch.php?lng='.$lng.'&amp;pg='.$fridthd[$fielda1].GetOptionnalArg('cat', $fridcat[$fielda1]).GetOptionnalArg('id', ceil($fielda2/$serviz[20])).'#R'.$fielda2;
						}
					}
					$doctit .= ' - '.$web[6].' '.$author.' '.$web[7].' '.FormatDate($creadate);
					break;
				}
				$doctxt = WrapLongWords(CutLongWord(strip_tags($fieldc1), $longword));
				$doctxtlong = $fieldc1;
				break;
			case 1 :
				$doclang = $lang[0];
				switch ($found[3][$i]) {
				case TYP_ART :
					if (substr($fieldd1, 0, 3) == 'MNU') {
						$mnuid    = intval(substr($fieldd1, 4));
						$mnutitle = GetTitleMenuBox($mnuid);
						$doctit   = '<strong>'.$mnutitle.' :</strong> ';
					} else {
						$doctit = '<strong>'.$fileid.' :</strong> ';
					}
					if (!empty($doctit)) {
						$doctit .= ' <strong>'.$fielda1.'</strong> - ';
						$doctit .= '<strong>'.$fieldb1.'</strong>';
						$doclnk = $site['URLR'] == 'on' ? $lang[0].'-'.$urlrw[20].'-100-'.$fileid.$z2 : 'articles.php?lng='.$lang[0].'&amp;pg='.$fileid.$z2;
						$docinv = '<a href="'.($site['URLR'] == 'on' ? $lang[0].'-'.$urlrw[20].'-1001-'.$fileid.'-1' : 'articles.php?lng='.$lang[0].'&amp;pg='.$fileid.'&amp;prt=1').'" target="_blank">'.$imgprtsearc.'</a>';
					}
					break;
				case TYP_DNLOAD :
					$doctit = '<strong>'.getLabel($nom[1]).' :</strong> '.$fieldb1;
					$doctit .= ' - '.$web[6].' '.$author.' '.$web[7].' '.FormatDate($moddate);
					$doclnk = $site['URLR'] == 'on' ? $lang[0].'-'.$urlrw[11].'-4-'.$fileid.$z2 : $site['DN'].'.php?lng='.$lang[0].'&amp;pg='.$fileid.$z2;
					$docinv = '<a href="javascript:PopupWindow(\''.($site['URLR'] == 'on'? $lang[0].'-'.$urlrw[11].'-6-'.$fileid: 'dwnld.php?lng='.$lang[0].'&amp;pg='.$fileid).'\',\'dnload\',400,265,\'no\',\'no\')">'.$imgdnlsearc.'</a>';
					break;
				case TYP_LINKS :
					$doctit = '<strong>'.getLabel($nom[3]).' :</strong> '.$fieldb1;
					$doclnk = $site['URLR'] == 'on' ? $lang[0].'-'.$urlrw[6].'-1-'.$fileid.$z2 : 'links.php?lng='.$lang[0].'&amp;pg='.$fileid.$z2;
					break;
				case TYP_NEWS :
					$doctit = '<strong>'.getLabel($nom[7]).' :</strong> <strong>'.$fieldb1.'</strong>';
					$doctit .= ' - '.$web[6].' '.$author.' '.$web[7].' '.FormatDate($moddate);
					if ($found[6][$i] == 'a')
						$doclnk = $site['URLR'] == 'on' ? $lang[0].'-'.$urlrw[8].'-2-'.$fileid.$z2 : $site['NE'].'.php?lng='.$lang[0].'&amp;pg='.$fileid.$z2;
					else
						$doclnk = $site['URLR'] == 'on' ? $lang[0].'-'.$urlrw[8].'-262-'.$fileid.$z2 : 'newsarch.php?lng='.$lang[0].'&amp;pg='.$fileid.$z2;
					break;
				case TYP_BLOG :
					$doctit = '<strong>'.getLabel($nom[42]).' :</strong> <strong>'.$fieldb1.'</strong>';
					$doctit .= ' - '.$web[6].' '.$author.' '.$web[7].' '.FormatDate($moddate);
					if ($found[6][$i] == 'a')
						$doclnk = $site['URLR'] == 'on' ? $lang[0].'-'.$urlrw[1].'-4-'.$fileid.$z2 : $site['BL'].'.php?lng='.$lang[0].'&amp;pg='.$fileid.$z2;
					else
						$doclnk = $site['URLR'] == 'on' ? $lang[0].'-'.$urlrw[1].'-42-'.$fileid.$z2 : 'blogarch.php?lng='.$lang[0].'&amp;pg='.$fileid.$z2;
					break;
				case TYP_FREEBOX :
					$doctit = '<strong>'.$fieldb1.'</strong>';
					$doctit .= ' - '.$web[6].' '.$author.' '.$web[7].' '.FormatDate($moddate);
					$doclnk = $site['URLR'] == 'on' ? $lang[0].'-'.$urlrw[0].$z2 : 'index.php?lng='.$lang[0].$z2;
					break;
				case TYP_FAQ :
					$doctit = '<strong>'.getLabel($nom[24]).' :</strong> '.$fieldb1;
					$doclnk = $site['URLR'] == 'on' ? $lang[0].'-'.$urlrw[4].'-3-'.$fileid.$z2 : 'faq.php?lng='.$lang[0].'&amp;pg='.$fileid.$z2;
					$docinv = '<a href="'.($site['URLR'] == 'on' ? $lang[0].'-'.$urlrw[4].'-4-'.$fileid.'-1' : 'faq.php?lng='.$lang[0].'&amp;pg='.$fileid.'&amp;prt=1').'" target="_blank">'.$imgprtsearc.'</a>';
					break;
				case TYP_PHOTO :
					$doctit = '<strong>'.getLabel($nom[2]).' :</strong> '.$fieldb1;
					$doclnk = $site['URLR'] == 'on' ? $lang[0].'-'.$urlrw[9].'-4-'.$fileid.$z2 : 'photorama.php?lng='.$lang[0].'&amp;pg='.$fileid.$z2;
					break;
				case TYP_AGENDA :
					$doctit = $web[287].' '.$fieldb1;
					if ($found[6][$i] == 'a')
						$doclnk = $site['URLR'] == 'on' ? $lang[0].'-'.$urlrw[17].'-2-'.$fileid.'-'.$fileid.'-1'.$z2 : 'agenda.php?lng='.$lang[0].'&amp;idpg='.$fileid.'-&amp;pg='.$fileid.'&agv=1'.$z2;
					else
						$doclnk = "";
					break;
				}
				$doctxt = WrapLongWords(CutLongWord(strip_tags($fieldc1), $longword));
				$doctxtlong = $fieldc1;
				break;
			case 2 :
				$doclang = $lang[1];
				switch ($found[3][$i]) {
				case TYP_ART :
					if (substr($fieldd1, 0, 3) == 'MNU') {
						$mnuid    = intval(substr($fieldd1, 4));
						$mnutitle = GetTitleMenuBox($mnuid);
						$doctit   = '<strong>'.$mnutitle.' :</strong> ';
					} else {
						$doctit = '<strong>'.$fileid.' :</strong> ';
					}
					if (!empty($doctit)) {
						$doctit .= ' <strong>'.$fielda2.'</strong> - ';
						$doctit .= '<strong>'.$fieldb2.'</strong>';
						$doclnk =  $site['URLR'] == 'on' ? $lang[1].'-'.$urlrw[20].'-100-'.$fileid.$z2 : 'articles.php?lng='.$lang[1].'&amp;pg='.$fileid.$z2;
						$docinv = '<a href="'.($site['URLR'] == 'on' ? $lang[1].'-'.$urlrw[20].'-1001-'.$fileid.'-1' : 'articles.php?lng='.$lang[1].'&amp;pg='.$fileid.'&amp;prt=1').'" target="_blank">'.$imgprtsearc.'</a>';
					}
					break;
				case TYP_DNLOAD :
					$doctit = '<strong>'.getLabel($nom[11]).' :</strong> '.$fieldb2;
					$doctit .= ' - '.$web[6].' '.$author.' '.$web[7].' '.FormatDate($moddate);
					$doclnk = $site['URLR'] == 'on' ? $lang[1].'-'.$urlrw[11].'-4-'.$fileid.$z2 : $site['DN'].'.php?lng='.$lang[1].'&amp;pg='.$fileid.$z2;
					$docinv = '<a href="javascript:PopupWindow(\''.($site['URLR'] == 'on'? $lang[1].'-'.$urlrw[11].'-6-'.$fileid: 'dwnld.php?lng='.$lang[1].'&amp;pg='.$fileid).'\', \'dnload\', 400, 265, \'no\', \'no\')">'.$imgdnlsearc.'</a>';
					break;
				case TYP_LINKS :
					$doctit = '<strong>'.getLabel($nom[13]).' :</strong> '.$fieldb2;
					$doclnk = $site['URLR'] == 'on' ? $lang[1].'-'.$urlrw[6].'-1-'.$fileid.$z2 : 'links.php?lng='.$lang[1].'&amp;pg='.$fileid.$z2;
					break;
				case TYP_BLOG :
					$doctit = '<strong>'.getLabel($nom[42]).' :</strong> <strong>'.$fieldb2.'</strong>';
					if ($found[6][$i] == 'a')
						$doclnk = $site['URLR'] == 'on' ? $lang[1].'-'.$urlrw[1].'-4-'.$fileid.$z2 : $site['BL'].'.php?lng='.$lang[1].'&amp;pg='.$fileid.$z2;
					else
						$doclnk = $site['URLR'] == 'on' ? $lang[1].'-'.$urlrw[1].'-42-'.$fileid.$z2 : 'blogarch.php?lng='.$lang[1].'&amp;pg='.$fileid.$z2;
					break;
				case TYP_NEWS :
					$doctit = '<strong>'.getLabel($nom[17]).' :</strong> <strong>'.$fieldb2.'</strong> - '.$web[6].' '.$author.' '.$web[7].' '.FormatDate($moddate);
					if ($found[6][$i] == 'a')
						$doclnk = $site['URLR'] == 'on' ? $lang[1].'-'.$urlrw[8].'-2-'.$fileid.$z2: $site['NE'].'.php?lng='.$lang[1].'&amp;pg='.$fileid.$z2;
					else
						$doclnk = $site['URLR'] == 'on' ? $lang[1].'-'.$urlrw[8].'-262-'.$fileid.$z2 : 'newsarch.php?lng='.$lang[1].'&amp;pg='.$fileid.$z2;
					break;
				case TYP_FREEBOX :
					$doctit = '<strong>'.$fieldb2.'</strong>';
					$doclnk = $site['URLR'] == 'on' ? $lang[1].'-'.$urlrw[0].$z2 : 'index.php?lng='.$lang[1].$z2;
					break;
				case TYP_FAQ :
					$doctit = '<strong>'.getLabel($nom[25]).' :</strong> '.$fieldb2;
					$doclnk = $site['URLR'] == 'on' ? $lang[1].'-'.$urlrw[4].'-3-'.$fileid.$z2 : 'faq.php?lng='.$lang[1].'&amp;pg='.$fileid.$z2;
					$docinv = '<a href="'.($site['URLR'] == 'on' ? $lang[1].'-'.$urlrw[4].'-4-'.$fileid.'-1': 'faq.php?lng='.$lang[1].'&amp;pg='.$fileid.'&amp;prt=1').'" target="_blank">'.$imgprtsearc.'</a>';
					break;
				case TYP_PHOTO :
					$doctit = '<strong>'.getLabel($nom[12]).' :</strong> '.$fieldb2;
					$doclnk = $site['URLR'] == 'on' ? $lang[1].'-'.$urlrw[9].'-4-'.$fileid.$z2 : 'photorama.php?lng='.$lang[1].'&amp;pg='.$fileid.$z2;
					break;
				case TYP_AGENDA :
					$doctit = $web[287].' '.$fieldb2;
					if ($found[6][$i] == 'a')
						$doclnk = $site['URLR'] == 'on' ? $lang[1].'-'.$urlrw[17].'-22-'.$fileid.'-'.$fileid.'-1-'.$tconfig.$z2 : 'agenda.php?lng='.$lang[1].'&amp;idpg='.$fileid.'-&amp;pg='.$fileid.'&agv=1&amp;tconfig='.$tconfig.$z2;
					else
						$doclnk = "";
					break;
				}
				$doctxt = WrapLongWords(CutLongWord(strip_tags($fieldc2), $longword));
				$doctxtlong = $fieldc2;
				break;
			}
			for ($j=0; $j<count($tokens); $j++) {
				$doctxt = preg_replace('/('.$tokens[$j].')/i', '<strong>\\1</strong>', $doctxt);
			}

			//--- Applique le style aux occurrences en excluant celles dans les balises ----//
			for ($j = count($tokens) - 1; $j >= 0; $j--) {
				if ($styleocc[4] == 'on') {
					$background = $bgcolor[fmod($j, count($bgcolor))].';';
				}
				$document = '';
				$text = preg_split('/('.$tokens[$j].')/i', $doctxtlong, -1, PREG_SPLIT_OFFSET_CAPTURE);
				if ($text[0][1] != 0) {
					$document .= substr($doctxtlong, 0, $text[0][1] - 1);
				}
				for ($k = 0; $k < count($text) - 1; $k++) {
					if (strrpos($text[$k][0], '<') > strrpos($text[$k][0], '>') || strpos($text[$k+1][0], '>') < strpos($text[$k+1][0], '<')) {
						$document .= $text[$k][0].substr($doctxtlong, $text[$k+1][1]-strlen($tokens[$j]), strlen($tokens[$j]));
					} else {
						$document .= $text[$k][0].$stylespan.$background.'">'.substr($doctxtlong, $text[$k+1][1]-strlen($tokens[$j]), strlen($tokens[$j])).$endstyle;
					}
				}
				$document  .= $text[count($text) - 1][0];
				$doctxtlong = $document;
			}
			//------------------------------------------------------------------------------//

			$doctit = strip_tags($doctit, '<strong>');

			//-------- Récupération des occurrences pour chaque résultat et pondération ----//
			//-------- Calcul de la pertinence du résultat et modification de l'affichage --//
			$occurrence = $found[5][$i];
			if ($occurrence['nb'][0] > 0) {
				$found[0][$i] = $found[0][$i]*$coef;
			}
			if ($found[0][$i] > $notemax) $found[0][$i] = $notemax;
			$pourcent   = ceil($found[0][$i] / $notemax * $longbarre);
			$pertinence = ceil($pourcent / $longbarre * 100);
			$stop       = ($pertinence < $pertinencemin) ? true : false;
			if ($stop) break;

			$width = $longbarre + 36;

			if ($acces) {
				echo '
<style type="text/css">
.divbars { width: '.$width.'px; }
.imggreen { width: '.$pourcent.'px; height: 8px; }
.imgyellow { width: '.($longbarre - $pourcent).'px; height: 8px; margin-left: -3px; }
.imglang { padding: 2px 0 0 4px; width: 18px; }
</style>
  <div class="bord">
	<div class="tbldiv width100">
	  <div class="trtbldiv trheadsearch">
		<div class="tdtbldiv">
		  <div class="divbars">
		    <img src="'.CHEMIN.'inc/img/bars/vert.gif" alt="" class="valignMiddle imggreen" />';
				if ($pourcent < $longbarre) {
					echo '
			<img src="'.CHEMIN.'inc/img/bars/jaune.gif" alt="" class="valignMiddle imgyellow" />';
				}
				echo '
			<img src="inc/lang/'.$doclang.'.gif" alt="'.$doclang.'" class="valignMiddle imglang" />
		  </div>
		</div>
		<div class="tdtbldiv width100 textLeft">&nbsp;'.($doclnk == '' ? $doctit : '<a href="'.$doclnk.'" title="'.$web[326].'">'.$doctit.'</a>').'</div>
	  </div>
    </div>
	<div class="tbldiv">
	  <div class="trtbldiv fontXsmall trheadsearch">
		<div class="tdtbldiv width100">&nbsp;'.$web[566].$pertinence.'% - ';
				if (str_word_count(str_replace($accent, $sansaccent, $occurrence['mot'][0])) > 1 && $occurrence['nb'][0] > 0) {
					echo $web[567].'<u><b>'.$occurrence['mot'][0].':</b></u> '.$occurrence['nb'][0].' - ';
					$firstocc = 1;
				} else {
					$firstocc = 0;
				}
				echo $web[568].' : ';
				$tiret = false;
				for ($j = $firstocc; $j < count($occurrence['mot']); $j++) {
					if ($styleocc[4] == 'on') {
						$background = $bgcolor[fmod($j, count($bgcolor))].';';
					}
					if ($occurrence['nb'][$j] > 0) {
						if ($tiret) echo ' - ';
						echo $stylespan.$background.'">'.$occurrence['mot'][$j].$endstyle.' : '.$occurrence['nb'][$j];
						$tiret = true;
					}
				}
				echo '
		</div>
	  </div>
    </div>
    <div class="tbldiv width100">
	  <div class="trtbldiv textLeft">
		<div class="tdtbldiv tr2headsearch">
		  <div id="court'.$i.'">
			<img src="'.$reptheme.'/plus.png" alt="'.$web[429].'" title="'.$web[429].'" class="img11x11 valignMiddle clsCursor" onclick="ActiveMenu(\'court\',\'long\','.$nbresult*($id-1).','.$maxresult.','.$i.')" />
			&nbsp; '.$doctxt.' ...
		  </div>
		  <div id="long'.$i.'" class="displayNone">
			<div>
			  <img src="'.$reptheme.'/minus.png" alt="'.$web[57].'" title="'.$web[57].'" class="img11x11 valignMiddle clsCursor" onclick="DesactiveItem(\'court\',\'long\','.$i.')" />
			  &nbsp; '.(TYP_SCREEN == 'MOB' || $hideprint == 'on' ? '' : $docinv).'
			</div>';
						if (strlen($doctxtlong) > 750) {
                            echo '
			<div class="txthiddensearch">'.$doctxtlong.'</div>
		  </div>';
						} else {
                            echo '
			<div>'.$doctxtlong.'</div>
		  </div>';
						}
						echo '
	    </div>
      </div>
	</div>
  </div>
	<br />';
			} else {
				$prive++;
			}
		} //------------------------- fin d'affichage pour $pertinence > $pertinence min
		$nbresultshown++;
    }
} else {
	echo '<div class="textCenter marginAuto">'.$web[62].'</div><br />';
	if (!empty($search) && count($tokens) == 0) {
		$words = explode(' ', $search);
		if (count($words) == 1) 
			echo '<div class="textCenter marginAuto">'.$web[569].'<b>'.$words[0].'</b>'.$web[575].'</div><br />';
		elseif (count($words) > 1) {
			echo '<div class="textCenter marginAuto">'.$web[571];
			for ($j = 0; $j < count($words); $j++) 
				echo '<b>'.$words[$j].'</b>'.(($j == count($words) - 2) ? ' & ' : ', ');
			echo $web[576].'</div><br />';
		}
	}
}
//------------ On récupère la requête initiale pour la page suivante... --------//
$search = stripslashes($savesearch);
//------------------------------------------------------------------------------//

$max = 1;
if ($pertinencemin > 0) {
	$nbresulttotshown = $nbresult * ($id - 1) + $nbresultshown;
	$nextpage         = ($nbresultshown == $nbresult && $pertinence > $pertinencemin) ? 1 : 0;
	$max              = max($max, $nbresulttotshown + $nextpage);
}

if ($pertinencemin > 0 && $max < count($found[0])) {
	if ($nbresulttotshown == 1) 
		echo '
<div class="textCenter marginAuto">'.$web[559].'<div><br />';
	elseif ($nbresulttotshown > 1) 
		echo '
<div class="textCenter marginAuto">'.$web[560].'<b>'.$nbresulttotshown.'</b>'.$web[561].'<div><br />';
	echo '
<div class="textCenter marginAuto">
  <a href="'.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[12].'-3-'.$cat.'-'.$search.'-'.$searchin.'-'.$searchlng.'-0-'.$max.'-'.$id.$z2 :
  'search.php?lng='.$lng.GetOptionnalArg('cat', $cat).'&amp;search='.$search.'&amp;searchin='.$searchin.'&amp;searchlng='.$searchlng.'&amp;pert=0&amp;max='.$max.'&amp;id='.$id.$z2).'">'.(($id > 1) ? $web[563] : $web[562]).'</a>
</div>
<br /><br />';
}

if ($pertinencemin == 0) {
	echo 
GetNavBar(($site['URLR'] == 'on' ? $lng.'-'.$urlrw[12].'-3-'.$cat.'-'.$search.'-'.$searchin.'-'.$searchlng.'-0-'.$max.'-' :
  'search.php?lng='.$lng.GetOptionnalArg('cat', $cat).'&amp;search='.$search.'&amp;searchin='.$searchin.'&amp;searchlng='.$searchlng.'&amp;pert='.$pertinencemin.'&amp;max='.$max.'&amp;id='), count($found[0]), $id, $nbresult, $z2).'
<br />
<div class="textCenter marginAuto">'.$web[564].'<br />
  <a href="'.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[12].'-3-'.$cat.'-'.$search.'-'.$searchin.'-'.$searchlng.'-'.$savepertinencemin.'-'.$max.'-1'.$z2 :
  'search.php?lng='.$lng.GetOptionnalArg('cat', $cat).'&amp;search='.$search.'&amp;searchin='.$searchin.'&amp;searchlng='.$searchlng.'&amp;pert='.$savepertinencemin.'&amp;max='.$max.'&amp;id=1'.$z2).'">'.$web[565].'</a>
</div>
<br /><br />';          
} 

if ($prive > 0) {
  echo '<hr />
<p class="textCenter"><strong>... '.$web[446].'</strong></p>';
}
if ($restricted) {
    echo '
<hr />
<p class="textCenter">'.$web[441].'</p>';
	if ($members[19] != '0' && $members[19] != '3') 
		echo '
<p class="textCenter">
  <a href="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[15].'-5-new-'.$tconfig.$z2 : $site['USR'].'.php?lng='.$lng.'&amp;uuser=new&amp;tconfig='.$tconfig.$z2).'" title="'.$web[160].'">['.$web[160].']</a>
</p>';
}
btable();
include('inc/bpage.inc');
?>
