<?php
/*******************************************************************************
 *   Functions for boxes
 *******************************************************************************
 *   GuppY PHP Script - version 5.0
 *   CeCILL Copyright (C) 2004-2013 by Laurent Duveau
 *   Initiated by Laurent Duveau and Nicolas Alves
 *   Web site = https://www.freeguppy.org/
 *   e-mail   = guppy@freeguppy.org
 *   V5 developed by Lud Bienaimé
 *      with the participation of Jean-Michel Misrachi and the GuppY Team
 *******************************************************************************
 *   Version History :
 * v5.0.0 (February 15, 2014)    : initial release.
 * v5.0.1 (March 8, 2014)        : adding a display control for fbox_contact
 *                               : adding visits counters into user box
 *                               : improvements in the processing of the height 
 *                                 of news/blogs
 * v5.0.2 (March 25, 2014)       : corrected quick link in visits counter
 *                               : eliminated the blocking dynamic menus (tanks JChouix)
 *                               : corrected input value for search boxes (thanks JChouix)
 * v5.0.3 (April 15, 2014)       : add photorama sidebox
 * v5.0.4 (April 30, 2014)       : add diaporama title in slideshow box
 *                               : corrected class current for menuicons
 * v5.0.5 (June 07, 2014)        : corrected parameter for photorama dynamic box
 *                               : adding IP addresses of visitors
 *                               : protection against copying in certain fields
 *                               : corrected contact link (thanks Jean-Denis)
 *                               : modify flag link in url-rw (thanks Ludo)
 *                               : corrected print link in url-rw (thanks Ludo)
 * v5.0.6 (July 02, 2014)        : add parameter for site of control of IP
 *                               : corrected captcha display in fbox_newslet
 *                               : improvement of management members
 *                               : corrected click box of drop-down menu options
 * v5.0.7 (August 21, 2014)      : corrected whois link
 *                               : corrected menu links in fbox_menubox
 *                               : add title of linear dropdown menu
 *                               : add visits of the day management
 *                               : add nb characters of direct forum
 *                               : corrected images display for dropdown menus
 *                               : writing 0 to display all of characters of news
 *                               : modified display of news for articles
 * v5.0.8 (October 02, 2014)     : add page configuration for news
 *                               : changed the calculation of the number of characters 
 *                                 in the live forum (thanks Ludo)
 *                               : corrected labels of news of the site
 * v5.0.9 (November 28, 2014)    : add menu options in What's new
 *                               : corrected links target
 *                               : corrected email display in fbox_guest()
 *                               : add choice of position of picture New/Update for menubox
 * v5.00.10 (December 29, 2014)  : improve display of what's new box
 *                               : corrected the scrolling menus and sub-menus
 *                               : improve photorama box display
 * v5.00.11 (March 2, 2015)      : corrected news box access
 *                               : improve displayQuickConfig() function
 *                               : limited of menu options in What's new
 * v5.01.00 (June 12, 2015)      : add ckeckbox for hostings behind a cache (thanks jcp)
 *                               : sorting agenda events in what\'s new box
 *                               : improvement for a mobile-friendly structure
 * v5.01.01 (September 02, 2015) : possibly to hide an article or a menu option with character §
 *                               : controls the display of the box poll with $serviz[23]
 *                               : adding the partial display of free boxes
 *                               : adding display of What's new for mobile
 *                               : corrected adresses with anchor in menu
 * v5.01.02 (December 02, 2015)  : adding parameter to hide date of What's new
 *                               : adding access control for photobox
 *                               : adding members access with private groups
 *                               : dynamic freeboxes in top and bottom areas
 *                               : adding a custom error handling 404
 *                               : changing the treatment of $tconfig
 * v5.01.03 (June 07, 2016)      : corrected url-rw rule for connect link
 *                               : corrected display of news box in home page
 *                               : marking the current option of the drop-down menus
 *                               : replace css properties by class rules
 *                               : improvement of IP address reading
 * v5.01.04 (September 07, 2016) : correction of update or new image display in menu option
 *                               : improve dropdown menus display
 *                               : modification of the calculation of height adjustable boxes
 *                               : correction of the display active forums on the homepage
 * v5.01.05 (September 27, 2016) : optimizing the limited height display for news
 * v5.01.06 (December 06, 2016)  : correction of current display menu icon
 * v5.01.07 (January 04, 2016)   : correction for non numeric values
 *                               : correction of end of documents
 * v5.02.00 (May 09, 2017)       : mofify end of documents
 *                               : suppress flash management
 *                               : sorting of news by publication date (thanks Laroche)
 *                               : correction of members list access
 *                               : improvement of impressions
 *                               : adding page number in rss link
 * v5.02.01 (August 28, 2017)    : control active Contact form
 *                               : correction of news archive link (thanks Laroche)
 *                               : independence of the admin part
 * v5.02.02 (December 18, 2017)  : correction of isAdmin() function
 *                               : secondary admin support
 *                               : correction of dynamic menu addresses (thanks Papinou)
 * v5.02.03 (February 01, 2018)  : improvement of password input
 *                               : correction link "Become a member"
 ******************************************************************************/
 
if (stristr($_SERVER['SCRIPT_NAME'], 'func_boxes.php')) {
    header('location:../index.php');
    die();
}

################################################################################

function fbox_ariane($pos = NULL, $args = NULL) {
    global $lng, $lang, $nom, $page, $site, $web, $urlrw, $reptheme, $endurl, $npage, $pgtype, $topmess, $tconfig, $z2;
	$root   = $site[3].($site['URLR'] == 'on' ? $lng.'-'.$urlrw[0] : 'index.php?lng='.$lng);
    $stroot = strip_tags(getLabel($nom[($lng == $lang[0] ? 0 : 10)]));
	$sep    = '&raquo;';
    switch ($pgtype) {
    case 5 :
        $ariane = '<span class="arianeOff">'.$npage[5].'</span>';
        break;
    case 18 : // plugins
        if (isset($topmess) && !empty($topmess)) {
            $plugin_name = strip_tags($topmess);
        } else {
			$tmp = explode('/', $endurl);
			foreach ($tmp as $key=>$val) {
				if ($val == 'plugins') break;
			}
			$plugin_dirname = 'plugins/'.$tmp[$key + 1];
			$plugin_file    = CHEMIN.$plugin_dirname.'/plugin.inc';
            $plugin_name    = '';
            if (is_file($plugin_file)) {
                $plugin_bar_name = '';
                include $plugin_file;
                if (!empty($plugin_bar_name)) {
                    $plugin_name = $plugin_bar_name;
                }
            }
            if (empty($plugin_name)) {
                $plugin_name = '';
                if (is_file(CHEMIN.'admin/'.$plugin_dirname.'/plugin.inc')) {
                    $plugin_admin_name = '';
                    include_once CHEMIN.'admin/'.$plugin_dirname.'/plugin.inc';
                    if (!empty($plugin_admin_name)) {
                        $plugin_name = $plugin_admin_name;
                    }
                }
            }
            if (empty($plugin_name)) {
                $plugin_name = $web[465];
            }
        }
        $ariane = '<span class="arianeOn"><a href="'.$root.'" title="'.$stroot.'"> '.$stroot.' </a></span> '.$sep.' <span class="arianeOff">'.$plugin_name.'</span>';
        break;
    case 13 : // blog
        $topmess2 = explode(' - ', empty($topmess) ? $npage[$pgtype] : strip_tags($topmess));
        $last     = ' '.$sep.' <span class="arianeOff">'.array_pop($topmess2).'</span>';
        $middle   = (0 == count($topmess2)) ? '' : ' '.$sep.' <span class="arianeOn"><a href="'.$site[3].($site['URLR'] == 'on' ? $lng.'-'.$urlrw[1].$z2 : $site['BLS'].'.php?lng='.$lng.$z2).'" title="'.$topmess2[0].'">'.$topmess2[0].'</a></span>';
        $ariane   = '<span class="arianeOn"><a href="'.$root.'" title="'.$stroot.'"> '.$stroot.' </a></span>'.$middle.$last;
        break;
    case 3 : // forum
        $topmess2 = explode(' - ', empty($topmess) ? $npage[$pgtype] : strip_tags($topmess, '<a>'));
        $last     = ' '.$sep.' <span class="arianeOff">'.array_pop($topmess2).'</span>';
        $middle   = '';
        foreach ($topmess2 as $item) {
            $middle .= ' '.$sep.' <span class="arianeOn">'.$item.'</span>';
        }
        $ariane = '<span class="arianeOn"><a href="'.$root.'" title="'.$stroot.'"> '.$stroot.' </a></span>'.$middle.$last;
        break;
    case FALSE :
        $ariane = '<span class="arianeOn"><a href="'.$root.'" title="'.$stroot.'"> '.$stroot.' </a></span> '.$sep.' <span class="arianeOff">'.(empty($topmess) ? '???' : strip_tags($topmess, '<a>')).'</span>';
        break;
    default :
        $topmess2 = explode(' > ', empty($topmess) ? $npage[$pgtype] : strip_tags($topmess, '<a>'));
        $last = ' '.$sep.' <span class="arianeOff">'.array_pop($topmess2).'</span>';
        $middle = '';
        foreach ($topmess2 as $item) {
            $middle .= ' '.$sep.' <span class="arianeOn">'.$item.'</span>';
        }
        $ariane = '<span class="arianeOn"><a href="'.$root.'" title="'.$stroot.'"> '.$stroot.' </a></span>'.$middle.$last;
    }
	$out = '
<div class="ariane'.(in_array($pos, array(BOX_TOP, BOX_BOTTOM)) ? ' ARN'.$pos.$tconfig : '').'">'
	.$web[637].$ariane.'
</div>';
	if (in_array($pos, array(BOX_TOP, BOX_BOTTOM))) {
		return $out;
	} else {
		if (in_array($pos, array(BOX_LEFT, BOX_RIGHT))) {
			return '
<div class="'.$pos.$tconfig.'ARN">'.boxthin($pos, '', $out, ' ARN'.$pos.$tconfig).'
</div>';
		} else {
			return boxwide($pos, '', $out, ' ARN'.$pos.$tconfig);
		}
	}
}

################################################################################

function fbox_print($pos = NULL, $args = NULL) {
    global $serviz, $web, $endurl, $pgtype, $site, $lng, $prt, $urlrw, $page, $tconfig, $reptheme;
	$url1 = str_replace('&', '&amp;', $endurl).'&amp;prt=-2';
	$url2 = str_replace('&', '&amp;', $endurl).'&amp;prt=2';
	$url3 = str_replace('&', '&amp;', $endurl).'&amp;prt=-3';
	$url4 = str_replace('&', '&amp;', $endurl).'&amp;prt=3';
	if ($site['URLR'] == 'on' && strpos($endurl, '/admin/') === false) {
		$infos = explode('/', $_SERVER['SCRIPT_NAME']);
		$qstrs = explode('&', $_SERVER['QUERY_STRING']);
		$fname = explode('.', $infos[count($infos) - 1]);
		$urls  = array(
			'index'=>$urlrw[0].'-1', $site['BLS']=>$urlrw[1].'-1', $site['BL'].'pg'=>$urlrw[1].'-41', 'blogsarch'=>$urlrw[1].'-71', $site['BL'].'selpg'=>$urlrw[1].'-21', 
		    'blogsarchselpgcatdatejdateid'=>$urlrw[1].'-72', 'blogarchpg'=>$urlrw[1].'-43', $site['BL'].'pgreact'=>$urlrw[1].'-470', 'blogarchpgreact'=>$urlrw[1].'-480', 
		    'contact'=>$urlrw[2].'-1', 'connect'=>$urlrw[3].'-2', 'connectconnectuuser'=>$urlrw[3].'-31', 'compte'=>$urlrw[3].'-141', 'lostpass'=>$urlrw[3].'-160', 
			'faq'=>$urlrw[4].'-1', 'faqpg'=>$urlrw[4].'-4', 'faqid'=>$urlrw[4].'-5', $site['FRT']=>$urlrw[5].'-1', $site['FR'].'cat'=>$urlrw[5].'-3', 
			$site['TH'].'pgcat'=>$urlrw[5].'-40', $site['TH'].'pgcatid'=>$urlrw[5].'-50', 'threadarchpgcat'=>$urlrw[5].'-420', 'threadarchpgcatid'=>$urlrw[5].'-520', 
			'links'=>$urlrw[6].'-2', 'linkspg'=>$urlrw[6].'-3', $site['GB']=>$urlrw[7].'-1', $site['GB'].'id'=>$urlrw[7].'-20', $site['GB'].'pg'=>$urlrw[7].'-30', 
			$site['NE']=>$urlrw[8].'-1', $site['NE'].'pgid'=>$urlrw[8].'-31', $site['NE'].'pg'=>$urlrw[8].'-20', 'newsarch'=>$urlrw[8].'-261', 'newsarchpg'=>$urlrw[8].'-263', 
			'newsarchpgid'=>$urlrw[8].'-41', 'photorama'=>$urlrw[9].'-1', 'photorama2pg'=>$urlrw[9].'-20', 'photoramapg'=>$urlrw[9].'-40', 
			'stats'=>$urlrw[10].'-1', 'download'=>$urlrw[11].'-1', 'downloadpg'=>$urlrw[11].'-5', 'downloadid'=>$urlrw[11].'-70', 'search'=>$urlrw[12].'-1', 
			'tinymsg'=>$urlrw[13].'-1', 'tinymsgaction'=>$urlrw[13].'-31', 'tinymsgactionid'=>$urlrw[13].'-51', 'tinymsgactionidtofrom'=>$urlrw[13].'-41', 
			'tinymsgactiontofrom'=>$urlrw[13].'-21', $site['PG'].'typ'=>$urlrw[14].'-0', $site['PG'].'typmodnumpg'=>$urlrw[14].'-10', $site['PG'].'typnumpg'=>$urlrw[14].'-20', 
			$site['PG'].'typcat'=>$urlrw[14].'-30', $site['PG'].'typpg'=>$urlrw[14].'-40', $site['USR']=>$urlrw[15].'-0', $site['USR'].'uuser'=>$urlrw[15].'-50', 
			$site['USR'].'modifuuser'=>$urlrw[15].'-60', 'poll'=>$urlrw[16].'-1', 'agendamoisanagv'=>$urlrw[17].'-211', 'agendamoisanagvid'=>$urlrw[17].'-231', 
			'agendaidpgpgagv'=>$urlrw[17].'-221', $site['NL']=>$urlrw[18].'-0', 'rss'=>$urlrw[19].'-1', 'articlespg'=>$urlrw[20].'-1001', 'articlespgtconfig'=>$urlrw[20].'-102', 
			'articlespgreact'=>$urlrw[20].'-1010', 'articlespgtconfig'=>$urlrw[20].'-1020', 'articlespgmnuidtconfig'=>$urlrw[20].'-1030'
			);
		$vars = '';
		$vals = '-';
		foreach($qstrs as $key=>$val) {
			if ($key != 'lng') {
				$param = explode('=', $val);
				$vars .= $param[0];
				$vals .= $param[1].'-';
			}
		}
		$urlr = '';
		foreach($urls as $key=>$url) {
			if ($fname[0].$vars == $key) {
				$urlr = $url;
				break;
			}
		}
		$url1 = $lng.'-'.$urlr.$vals.'-2';
		$url2 = $lng.'-'.$urlr.$vals.'2';
		$url3 = $lng.'-'.$urlr.$vals.'-3';
		$url4 = $lng.'-'.$urlr.$vals.'3';
	}
    if ($pgtype != 11) {
        $out = '
<div class="boxprint'.(in_array($pos, array(BOX_TOP, BOX_BOTTOM)) ? ' PRT'.$pos.$tconfig : '').'">
  <span class="boxprint1">
    <a href="'.$url1.'" target="'.TYP_BLANK.'"><img src="'.$reptheme.'/look.png" alt="'.$web[264].'" title="'.$web[264].'" /></a>&nbsp;
    <a href="'.$url2.'" target="'.TYP_BLANK.'"><img src="'.$reptheme.'/print.png" alt="'.$web[22].'" title="'.$web[22].'" /></a>&nbsp;
  </span>
  <span class="boxprint2">'.$web[470].'</span>
  ';
        if ( !in_array($pgtype, array(5, 8, 9, 12, 14, 15, 16, 18))
        &&   !($pgtype == 3 && (strpos($endurl, $site['FRT'].'.php') !== FALSE))
        &&   !($pgtype == 8 && empty($serviz[21]))
        &&   $pgtype !== FALSE
           ) {
            $out .= '
  <br class="c-both" />
  <span class="boxprint1">
    <a href="'.$url3.'" target="'.TYP_BLANK.'"><img src="'.$reptheme.'/look.png" alt="'.$web[264].'" title="'.$web[264].'" /></a>&nbsp;
    <a href="'.$url4.'" target="'.TYP_BLANK.'"><img src="'.$reptheme.'/print.png" alt="'.$web[22].'" title="'.$web[22].'" /></a>&nbsp;
  </span>
  <span class="boxprint2">'.$web[471].'</span>
  ';
        }
        $out .= '
</div>';
		if (in_array($pos, array(BOX_TOP, BOX_BOTTOM))) {
			return $out;
		} else {
			if (in_array($pos, array(BOX_LEFT, BOX_RIGHT))) {
				return '
<div class="'.$pos.$tconfig.'PRT">'.boxthin($pos, '', $out, ' PRT'.$pos.$tconfig).'
</div>';
			} else {
				return boxwide($pos, '', $out, ' PRT'.$pos.$tconfig);
			}
		}
    } else {
        return FALSE;
    }
}

################################################################################

function fbox_logo($pos = NULL, $args = NULL) {
    global $lang, $lng, $page, $site, $skn_logo, $urlrw, $tconfig, $meskin;
    $img  = explode('|', $page[4]);
    $urli = substr($img[0], 0, 1) == 'I' ? CHEMIN.'img/' : $meskin.'img/';
    $logo = $skn_logo != '' && empty($page[4]) ? $skn_logo : $urli.$img[1];
    if ($logo != $urli) {
		$url = ($site['URLR'] == 'on')? $lng.'-'.$urlrw[0]: 'index.php?lng='.$lng;
        return '
  <div class="logo'.(in_array($pos, array(BOX_TOP, BOX_BOTTOM)) ? ' LO'.$pos.$tconfig : '').'">
    <a href="'.$site[3].$url.'" title="'.stripslashes($site[($lang[0] == $lng ? 0 : 11)]).'">
      <img src="'.$logo.'" alt="'.stripslashes($site[($lang[0] == $lng ? 0 : 11)]).'" />
    </a>
  </div>
';
    } else {
        return FALSE;
    }
}

################################################################################
    
function fbox_menu($pos = NULL, $args = NULL) {
    global $lng, $lang, $drtuser, $nom, $page, $site, $serviz, $userprefs, $web, $menuico, 
	    $urlrw, $tconfig, $flag1, $flag2, $dynabox, $endurl, $charset, $reptheme, $z2, 
		$fielda1, $fieldb1, $fieldb2, $fieldc1, $fieldc2, $fieldd1, $fieldd2, $fieldweb, $fieldmail, $fieldmod;
	$title_menu = TYP_SCREEN == 'WEB' ? getLabel($nom[$lng == $lang[0] ? 44 : 45]) : getLabel($nom[$lng == $lang[0] ? 58 : 59]);
	$title_menu = mb_substr(trim($title_menu), 0, 1, $charset) == '§' ? '' : DisplayDownArrow($dynabox[20]).$title_menu;
	$tconfig    = empty($tconfig) ? '0' : $tconfig;
	$flags      = '';
    if ($lang[1] != '') { // boxlang
		if ($site['URLR'] == 'on') {
			$len     = strlen(parse_url($site[3], PHP_URL_PATH));
            $flagurl = substr($endurl, $len);
            $pds     = (strstr($flagurl, '/')) ? strripos( $flagurl, '/') : 0;
            if ($pds > 1) {
				$len           = strlen(substr($flagurl, $pds + 1));
                $chemin_plugin = substr($flagurl, 0, $pds + 1);
                $flagurl       = substr($flagurl, $pds + 1);
			} else $chemin_plugin = '';
			$flagurl0 = $site[3].$chemin_plugin.$lang[$lng == $lang[0] ? 1 : 0].'-'.substr($flagurl, 3);
			$flagurl1 = $site[3].($lng == $lang[0] ? $lang[1] : $lang[0]).'-'.$urlrw[0];
            $flagurl = strlen($flagurl) > 3 ? $flagurl0 : $flagurl1;
		} else {
			$slng = strpos($endurl, '?lng=') > 0 || strpos($endurl, '&lng=') > 0 ? '' : 'lng='.$lng;
			if ($slng != '') $endurl .= (strpos($endurl, '?') > 0) ? '&'.$slng : '?'.$slng;
			$flagurl = str_replace('&', '&amp;', $endurl);
			if ($lng == $lang[0]) $flagurl = str_replace('lng='.$lang[0], 'lng='.$lang[1], $flagurl); 
			if ($lng == $lang[1]) $flagurl = str_replace('lng='.$lang[1], 'lng='.$lang[0], $flagurl); 
		}
		$flags = '
  	  <div class="pop menuIcons_flag">
	    <a href="'.$flagurl.(strpos($flagurl, 'index.php') > 0 || strpos($flagurl, $urlrw[0]) > 0 ? '' : $z2).'">';
		if ($lng == $lang[0]) {
			$flags .= '
		  <img src="'.$flag2.'" alt="'.$web[87].': '.$lang[1].'" />
	      <span class="popflag"><em></em>'.$web[555].': <b>'.$lang[1].'</b></span>';
		} else {
			$flags .= '
		  <img src="'.$flag1.'" alt="'.$web[87].': '.$lang[0].'" />
	      <span class="popflag"><em></em>'.$web[556].': <b>'.$lang[0].'</b></span>';
		}
		$flags .= '
		</a>
	  </div><div class="c-left"></div>';
        if ($pos != BOX_LEFT && $pos != BOX_RIGHT) { // Drapeau menu horizontal
			$flags  = (($page[9] != '')? '<br />' : '').$flags;
        } else { // Drapeau menu boite latérale
			$flags = '
  	  <div class="pop menuIcons_flag">
	    <a href="'.$flagurl.'">';
			if ($lng == $lang[0]) {
				$flags .= '
		  <img src="'.$flag2.'" alt="'.$web[87].': '.$lang[1].'" class="imglatflag" />
	      <span class="popflagS"><em></em>'.$web[555].': <b>'.$lang[1].'</b></span>';
			} else {
				$flags .= '
		  <img src="'.$flag1.'" alt="'.$web[87].': '.$lang[0].'" class="imglatflag" />
	      <span class="popflagT"><em></em>'.$web[556].': <b>'.$lang[0].'</b></span>';
			}
			$flags .= '
		</a>
	  </div><div class="c-left"></div>';
			$title_menu = $flags.'<div'.(empty($lang[1]) ? '' : ' class="titleboxmenu"').'>'.$title_menu.'</div>';
        }
    } // boxlang
    $base_current = basename(substr($_SERVER["SCRIPT_NAME"], strlen(parse_url($site[3], PHP_URL_PATH))));
	$full_current = $base_current.'?'.$_SERVER["QUERY_STRING"];
    unset($dbw);
    $menu = array();
    $i    = ($lng == $lang[0])? 0 : 10;
    $j    = ($lng == $lang[0])? 0 : 1;
    //Home
    if ($serviz[1] == 0 && $menuico[0] == 'on') {
        $menu[getLabel($nom[$i+0]).'_home'] = array(
            'id'       => 'home',
            'z2'       => false,
            'name'     => strip_tags(getLabel($nom[$i+0])),
            'title'    => getLabel($nom[$i+0], 1),
            'icon'     => 'inc/img/icons/'.$page[9].'/home.gif',
            'pageexec' => 0,
            'pagedisp' => $tconfig,
            'url'      => ($site['URLR'] == 'on') ? $lng.'-'.$urlrw[0] : 'index.php',
			'base'     => 'index.php',
			'target'   => '_self'
        );
    }
    //Blog
    if ($serviz[53] == 'on' && $menuico[2] == 'on') {
        $menutconf = $menuico[13] == 'ALL' ? $tconfig : $menuico[13];
    	$menu[getLabel($nom[$j+42]).'_blog'] = array(
    		'id'       => 'blog',
            'z2'       => $z2,
            'name'     => strip_tags(getLabel($nom[$j+42])),
            'title'    => getLabel($nom[$j+42], 1),
    		'icon'     => 'inc/img/icons/'.$page[9].'/blog.gif',
            'pageexec' => $menutconf,
            'pagedisp' => $menuico[23] == 'ALL' ? $tconfig : $menuico[23],
    		'url'      => ($site['URLR'] == 'on') ? $lng.'-'.$urlrw[1].'-'.$menutconf : $site['BLS'].'.php',
    		'alturls'  => array($site['BL'].'.php', 'blogsarch.php', 'blogarch.php'),
			'base'     => $site['BLS'].'.php',
			'target'   => '_self'
    	);
    }
    //Contact
    if ($serviz[21] == 'on' && $serviz[99] == 'on' && $menuico[10] == 'on') {
        $menutconf = $menuico[21] == 'ALL' ? $tconfig : $menuico[21];
    	$menu[getLabel($nom[$j+46]).'_contact'] = array(
    		'id'       => 'contact',
            'z2'       => $z2,
            'name'     => strip_tags(getLabel($nom[$j+46])),
            'title'    => getLabel($nom[$j+46], 1),
    		'icon'     => 'inc/img/icons/'.$page[9].'/contact.gif',
            'pageexec' => $menutconf,
            'pagedisp' => $menuico[31] == 'ALL' ? $tconfig : $menuico[31],
    		'url'      => ($site['URLR'] == 'on') ? $lng.'-'.$urlrw[2].'-'.$menutconf : $site['CT'].'.php',
			'base'     => $site['CT'].'.php',
			'target'   => '_self'
    	);
    }
    //Connexion
    if ($menuico[11] == 'on') {
		$jj              = $userprefs[1] == '' ? $j : $j + 2;
        $menutconf       = $serviz[172] == 'ALL' ? $tconfig : $serviz[172];
		$connectName     = $userprefs[1] == '' ? 'connect.php' : 'connect.php?lng='.$lng.'&amp;connect=no';
		$connectNameURLR = $userprefs[1] == '' ? $urlrw[3].'-0' : $urlrw[3].'-1-no';
    	$menu[getLabel($nom[$jj+50]).'_connect'] = array(
    		'id'       => 'connect',
            'z2'       => $z2,
            'name'     => strip_tags(getLabel($nom[$jj+50])),
            'title'    => getLabel($nom[$jj+50], 1),
    		'icon'     => 'inc/img/icons/'.$page[9].'/'.($userprefs[1] == '' ? 'login' : 'logout').'.gif',
            'pageexec' => $menutconf,
            'pagedisp' => $serviz[173] == 'ALL' ? $tconfig : $serviz[173],
    		'url'      => ($site['URLR'] == 'on') ? $lng.'-'.$connectNameURLR.'-'.$menutconf : $connectName,
			'base'     => 'connect.php',
			'target'   => '_self'
    	);
    }
    //FAQ
    if ($serviz[14] == 'on' && $menuico[6] == 'on') {
        $menutconf = $menuico[17] == 'ALL' ? $tconfig : $menuico[17];
    	$menu[getLabel($nom[$j+24]).'_faq'] = array(
    		'id'       => 'faq',
            'z2'       => $z2,
            'name'     => strip_tags(getLabel($nom[$j+24])),
            'title'    => getLabel($nom[$j+24], 1),
    		'icon'     => 'inc/img/icons/'.$page[9].'/faq.gif',
            'pageexec' => $menutconf,
            'pagedisp' => $menuico[27] == 'ALL' ? $tconfig : $menuico[27],
    		'url'      => ($site['URLR'] == 'on') ? $lng.'-'.$urlrw[4].'-9-'.$menutconf : 'faq.php',
			'base'     => 'faq.php',
			'target'   => '_self'
    	);
    }
    //Forum
    if ($serviz[13] == 'on' && $menuico[8] == 'on') {
        $menutconf = $menuico[19] == 'ALL' ? $tconfig : $menuico[19];
    	$forumName = ($serviz[18] == 'on') ? $site['FRT'] : $site['FR'];
    	$forumNameURLR = ($serviz[18] == 'on') ? $urlrw[5].'-'.$menutconf : $urlrw[5].'-31-'.$menutconf;
    	$menu[getLabel($nom[$j+22]).'_forum'] = array(
    		'id'       => 'forum',
            'z2'       => $z2,
            'name'     => strip_tags(getLabel($nom[$j+22])),
            'title'    => getLabel($nom[$j+22], 1),
    		'icon'     => 'inc/img/icons/'.$page[9].'/forum.gif',
            'pageexec' => $menutconf,
            'pagedisp' => $menuico[29] == 'ALL' ? $tconfig : $menuico[29],
    		'url'      => ($site['URLR'] == 'on') ? $lng.'-'.$forumNameURLR : $forumName.'.php',
    		'alturls'  => array($site['TH'].'.php', 'forumarch.php', 'fortopicarch.php', 'treadarch.php'),
			'base'     => $forumName.'.php',
			'target'   => '_self'
    	);
    }
    //Link
    if ($serviz[11] == 'on' && $menuico[5] == 'on') {
        $menutconf = $menuico[16] == 'ALL' ? $tconfig : $menuico[16];
    	$menu[getLabel($nom[$i+3]).'_links'] = array(
    		'id'       => 'links',
            'z2'       => $z2,
            'name'     => strip_tags(getLabel($nom[$i+3])),
            'title'    => getLabel($nom[$i+3], 1),
    		'icon'     => 'inc/img/icons/'.$page[9].'/links.gif',
            'pageexec' => $menutconf,
            'pagedisp' => $menuico[26] == 'ALL' ? $tconfig : $menuico[26],
    		'url'      => ($site['URLR'] == 'on') ? $lng.'-'.$urlrw[6].'-'.$menutconf : 'links.php',
			'base'     => 'links.php',
			'target'   => '_self'
    	);
    }
    //Guestbook
    if ($serviz[12] == 'on' && $menuico[7] == 'on') {
        $menutconf = $menuico[18] == 'ALL' ? $tconfig : $menuico[18];
    	$menu[getLabel($nom[$i+9]).'_guestbk'] = array(
    		'id'       => 'guestbook',
            'z2'       => $z2,
            'name'     => strip_tags(getLabel($nom[$i+9])),
            'title'    => getLabel($nom[$i+9], 1),
    		'icon'     => 'inc/img/icons/'.$page[9].'/guestbook.gif',
            'pageexec' => $menutconf,
            'pagedisp' => $menuico[28] == 'ALL' ? $tconfig : $menuico[28],
    		'url'      => ($site['URLR'] == 'on') ? $lng.'-'.$urlrw[7].'-'.$menutconf : $site['GB'].'.php',
			'base'     => $site['GB'].'.php',
			'target'   => '_self'
    	);
    }
    //News
    if ($serviz[8] == 'on' && $menuico[1] == 'on') {
        $menutconf = $menuico[12] == 'ALL' ? $tconfig : $menuico[12];
    	$menu[getLabel($nom[$i+7]).'_news'] = array(
    		'id'       => 'news',
            'z2'       => $z2,
            'name'     => strip_tags(getLabel($nom[$i+7])),
            'title'    => getLabel($nom[$i+7], 1),
    		'icon'     => 'inc/img/icons/'.$page[9].'/news.gif',
            'pageexec' => $menutconf,
            'pagedisp' => $menuico[22] == 'ALL' ? $tconfig : $menuico[22],
    		'url'      => ($site['URLR'] == 'on') ? $lng.'-'.$urlrw[8].'-5-'.$menutconf : $site['NE'].'.php',
    		'alturls'  => array('newsarch.php'),
			'base'     => $site['NE'].'.php',
			'target'   => '_self'
    	);
    }
    //photorama
    if ($serviz[9] == 'on' && $menuico[3] == 'on') {
    	$menutconf = $menuico[14] == 'ALL' ? $tconfig : $menuico[14];
        $photoName = 'photorama'; 
    	$menu[getLabel($nom[$i+2]).'_photo'] = array(
    		'id'       => 'photo',
            'z2'       => $z2,
            'name'     => strip_tags(getLabel($nom[$i+2])),
            'title'    => getLabel($nom[$i+2], 1),
    		'icon'     => 'inc/img/icons/'.$page[9].'/photo.gif',
            'pageexec' => $menutconf,
            'pagedisp' => $menuico[24] == 'ALL' ? $tconfig : $menuico[24],
    		'url'      => ($site['URLR'] == 'on') ? $lng.'-'.$urlrw[9].'-'.$menutconf : 'photorama.php',
    		'alturls'  => array('photorama2.php'),
			'base'     => 'photorama.php',
			'target'   => '_self'
    	);
    }
    //Stats
    if ($serviz[15] == 'on' && $menuico[9] == 'on') {
    	$menutconf = $menuico[20] == 'ALL' ? $tconfig : $menuico[20];
    	$menu[getLabel($nom[$j+26]).'_stats'] = array(
    		'id'       => 'stats',
            'z2'       => $z2,
            'name'     => strip_tags(getLabel($nom[$j+26])),
            'title'    => getLabel($nom[$j+26], 1),
    		'icon'     => 'inc/img/icons/'.$page[9].'/stats.gif',
            'pageexec' => $menutconf,
            'pagedisp' => $menuico[30] == 'ALL' ? $tconfig : $menuico[30],
    		'url'      => ($site['URLR'] == 'on') ? $lng.'-'.$urlrw[10].'-'.$menutconf : 'stats.php',
			'base'     => 'stats.php',
			'target'   => '_self'
    	);
    }
    //Download
    if ($serviz[10] == 'on' && $menuico[4] == 'on') {
    	$menutconf = $menuico[15] == 'ALL' ? $tconfig : $menuico[15];
    	$menu[getLabel($nom[$i+1]).'_download'] = array(
    		'id'       => 'download',
            'z2'       => $z2,
            'name'     => strip_tags(getLabel($nom[$i+1])),
            'title'    => getLabel($nom[$i+1], 1),
    		'icon'     => 'inc/img/icons/'.$page[9].'/download.gif',
            'pageexec' => $menutconf,
            'pagedisp' => $menuico[25] == 'ALL' ? $tconfig : $menuico[25],
    		'url'      => ($site['URLR'] == 'on') ? $lng.'-'.$urlrw[11].'-'.$menutconf : $site['DN'].'.php',
			'base'     => $site['DN'].'.php',
			'target'   => '_self'
    	);
    }
    //Admin
    $menu_admin = array();
    if (isAdmin($userprefs[1])) {
    	$menu_admin = array(
    		'id'     => 'admin',
            'z2'     => false,
    		'name'   => strip_tags($web[144]),
    		'title'  => $web[144],
    		'icon'   => 'inc/img/icons/'.$page[9].'/admin.gif',
    		'url'    => ($site['URLR'] == 'on')? 'admin/'.$lng.'-'.$urlrw[0].'-19' : 'admin/admin.php?lng='.$lng,
			'base'   => 'admin.php',
			'target' => '_self'
    	);
    }
    //Plugins
    if (is_file(CHEMIN."inc/hplugins.inc")) {
    	include CHEMIN."inc/hplugins.inc";
    }
    //Icônes supplémentaires
    $dbicons = SelectDBFieldsByType(ReadDBFields(DOCID), TYP_MENUICO);
    foreach ($dbicons as $item) {
        if ($item[2] == 'a') {
            ReadDoc($item[1]);
			if (!isAccessGranted($fieldmod)) continue;
			if ($fieldmail == $tconfig || $fieldmail == 'ALL') {
				$urls = explode('||', $lng == $lang[0] ? $fieldd1 : $fieldd2);
				if (preg_match('!https?://|ftps?://|www.!', $urls[0]))
					$url = $urls[0];
				else {
					$slng = (strpos($urls[0], '?lng=') > 0 || strpos($urls[0], '&lng=') > 0 || $site['URLR'] == 'on') ? '' : 'lng='.$lng;
					if ($slng != '') $urls[0] .= (strpos($urls[0], '?') > 0) ? '&'.$slng : '?'.$slng;
					$urls[0] = strpos($urls[0], 'tconfig') > 0 ? $urls[0] : $urls[0].'&tconfig='.$tconfig;
					if ($site['URLR'] == 'on' && empty($urls[1]) && strpos($urls[0], 'articles.php') !== false) {
						$pg      = substr($urls[0], strpos($urls[0], 'pg=') + 3);
						$pg      = strpos($pg, '&') > 0 ? substr($pg, 0, strpos($pg, '&')) : $pg;
						$urls[1] = $lng.'-'.$urlrw[20].($fieldweb == 'ALL' ? '-100-'.$pg : '-102-'.$pg.'-'.$fieldweb);
					}
					$url = (count($urls) == 1 || $site['URLR'] != 'on' ? $urls[0] : $urls[1]);
				}
				$icon_name = $lang[0] == $lng ? getLabel($fieldb1) : getLabel($fieldb2);
				$basename  = $site['URLR'] == 'on' ? basename($_SERVER['SCRIPT_NAME']) : parse_url($url, PHP_URL_PATH);
				$menu[$icon_name.'menuicon_'.$fielda1] = array(
					'id'       => strip_tags($fielda1),
                    'z2'       => $z2,
					'name'     => $lang[0] == $lng ? strip_tags(getLabel($fieldb1)) : strip_tags(getLabel($fieldb2)),
					'title'    => $icon_name,
					'icon'     => 'img/'.$fieldc2,
                    'pageexec' => $fieldweb == 'ALL' ? $tconfig : $fieldweb,
                    'pagedisp' => $fieldmail == 'ALL' ? $tconfig : $fieldmail,
					'url'      => $url,
					'base'     => basename(parse_url($url, PHP_URL_PATH)).'?'.parse_url($url, PHP_URL_QUERY),
					'target'   => $fieldc1,
					'docid'    => $item[1]
				);
				unset($urls);
			}
        }
    }
    ksort($menu);
    $out = '';
    $currentMenuClass = '';
    if ($pos != BOX_LEFT && $pos != BOX_RIGHT) { // Menu horizontal
    	$out .= '
      <div class="menuIcons MI'.$pos.$tconfig.'">'.$flags.'
      <ul'.(empty($lang[1]) ? ' class="noflag"' : '').'>';
    	// Admin
    	if (isAdmin($userprefs[1])) {
    		// Class ajouté à la section du menu affichée
			$target = strtoupper($menu_admin['target']) == '_self' ? '' : ' target="'.$menu_admin['target'].'"';
    		$currentMenuClass = ($base_current == $menu_admin['base'])? ' current' : '';
    		$contents = '
			<a href="'.CHEMIN.$menu_admin['url'].'" title="'.strip_tags($menu_admin['title']).'"'.$target.'>';
    		if($page[9] != '' && is_file(CHEMIN.$menu_admin['icon'])) {
    			$contents .= '
			  <img src="'.CHEMIN.$menu_admin['icon'].'" alt="'.strip_tags($menu_admin['name']).'" title="'.strip_tags($menu_admin['title']).'" '.(($page[20] != '')? 'class="imgover"' : '').' />';
    		}
    		$contents .= '
			  <span class="name_'.$menu_admin['id'].$currentMenuClass.'">'.$menu_admin['name'].'</span>';
    		$contents .= '
			</a>';
    		$out .= '
          <li id="menu_'.$menu_admin['id'].'" class="menu_'.$menu_admin['id'].$currentMenuClass.'">'.$contents.'</li>';
    	}
    	// Sections du menu
    	$found_current = false;
    	foreach ($menu as $section) {
            if ($currentMenuClass != '') {
                $found_current = true;
                $currentMenuClass = '';
            }
            if (!$found_current) {
        		if (!isset($section['alturls'])) {
					if (isset($section['docid']))
						$currentMenuClass = ($full_current == $section['base']) ? ' current' : '';
					else
						$currentMenuClass = ($base_current == $section['base']) ? ' current' : '';
        		} else {
        		    $currentMenuClass = ($base_current == $section['base']) ? ' current' : '';
                    foreach($section['alturls'] as $url) {
                        if ($base_current == $url) {
                            $currentMenuClass = ' current';
                            break;
                        }
                    }
        		}
    		}
    		if (($page[9] != '' || $section['name'] != '') && $section['pagedisp'] == $tconfig) {
				if (strpos($section['url'], $site[3]) !== false) {
					$url  = CHEMIN.substr($section['url'], strlen($site[3]));
					$slng = (strpos($url, '?lng=') > 0 || strpos($url, '&lng=') > 0 || $site['URLR'] == 'on') ? '' : 'lng='.$lng.'&amp;tconfig='.$section['pageexec'];
					if ($slng != '') $url .= (strpos($url, '?') > 0) ? '&'.$slng : '?'.$slng;
				} elseif (preg_match('!https?://|ftps?://|www.!', $section['url'])) {
					$url = $section['url'];
				} else {
					$url  = CHEMIN.$section['url'];
					$slng = (strpos($url, '?lng=') > 0 || strpos($url, '&lng=') > 0 || $site['URLR'] == 'on') ? '' : 'lng='.$lng.'&amp;tconfig='.$section['pageexec'];
					if ($slng != '') $url .= (strpos($url, '?') > 0) ? '&'.$slng : '?'.$slng;
				}
				if ($section['target'] == '_POPUP')
					$target = '	onclick="window.open(this.href, \'popup'.(isset($section['docid']) ? $section['docid'] : '0').'\', 
						\'resizable=yes,status=yes,location=no,toolbar=yes,menubar=no,fullscreen=no,scrollbars=yes,dependent=no,width=1024,left=0,height=768,top=0\'); return false;"';
				else
					$target = strtolower($section['target']) == '_self' ? '' : ' target="'.strtolower($section['target']).'"';
				$contents = '
			<a href="'.$url.($section['z2'] ? $z2 : '').'" title="'.strip_tags($section['title']).'"'.$target.'>';
    			if($page[9] != '' && is_file(CHEMIN.$section['icon'])) {
    				$contents .= '
			  <img src="'.CHEMIN.$section['icon'].'" alt="'.strip_tags($section['name']).'" title="'.strip_tags($section['title']).'" '.(($page[20] != '')? 'class="imgover"' : '').' />';
    			}
    			if ($section['name'] != '') {
    				$contents .= '
			  <span class="name_'.$section['id'].$currentMenuClass.'">'.$section['name'].'</span>';
    			}
    			$contents .= '
			</a>';

    			$out .= '
          <li id="menu_'.$section['id'].'" class="menu_'.$section['id'].$currentMenuClass.'">
		    '.$contents.'
		  </li>';
    		}
    	}
    	$out .= '
      </ul>
      </div>
      <div class="c-both"></div>';
      return $out;
    } else { // Menu boite latérale
    	$out .= '
      <ul class="boxmenu">
    	';
    	// Sections du menu
    	$found_current = false;
    	$currentMenuClass = '';
    	foreach ($menu as $section) {
            if ($currentMenuClass != '') {
                $found_current = true;
                $currentMenuClass = '';
            }
            if (!$found_current) {
        		if (!isset($section['alturls'])) {
					if (isset($section['docid']))
						$currentMenuClass = ($full_current == $section['url']) ? ' curr_item' : '';
					else
						$currentMenuClass = ($base_current == $section['base']) ? ' curr_item' : '';
        		} else {
        		    $currentMenuClass = ($base_current == $section['base'])? ' curr_item' : '';
                    foreach($section['alturls'] as $url) {
                        if ($base_current == $url) {
                            $currentMenuClass = ' curr_item';
                            break;
                        }
                    }
        		}
    		}
    		if ($page[9] != '' || $section['name'] != '') {
				if (strpos($section['url'], $site[3]) !== false) {
					$url  = CHEMIN.substr($section['url'], strlen($site[3]));
					$slng = (strpos($url, '?lng=') > 0 || strpos($url, '&lng=') > 0 || $site['URLR'] == 'on') ? '' : 'lng='.$lng.'&amp;tconfig='.$section['pageexec'];
					if ($slng != '') $url .= (strpos($url, '?') > 0) ? '&'.$slng : '?'.$slng;
				} elseif (preg_match('!https?://|ftps?://|www.!', $section['url'])) {
					$url = $section['url'];
				} else {
					$url  = CHEMIN.$section['url'];
					$slng = (strpos($url, '?lng=') > 0 || strpos($url, '&lng=') > 0 || $site['URLR'] == 'on') ? '' : 'lng='.$lng.'&amp;tconfig='.$section['pageexec'];
					if ($slng != '') $url .= (strpos($url, '?') > 0) ? '&'.$slng : '?'.$slng;
				}
				if (strtoupper($section['target']) == '_POPUP')
					$target = '	onclick="window.open(this.href, \'popup'.(isset($section['docid']) ? $section['docid'] : '0').'\', 
						\'resizable=yes,status=yes,location=no,toolbar=yes,menubar=no,fullscreen=no,scrollbars=yes,dependent=no,width=1024,left=0,height=768,top=0\'); return false;"';
				else
					$target = strtolower($section['target']) == '_self' ? '' : ' target="'.strtolower($section['target']).'"';
				$contents = '<a href="'.$url.(isset($section['z2']) ? $section['z2'] : '').'" title="'.strip_tags($section['title']).'"'.$target.'>';
    			if($page[9] != '' && is_file(CHEMIN.$section['icon'])) {
    				$contents .= '<img src="'.CHEMIN.$section['icon'].'" alt="'.strip_tags($section['name']).'" title="'.strip_tags($section['title']).'" '.(($page[20] != '')? 'class="imgover"' : '').' />';
    			}
    			if ($section['name'] != '') {
    				$contents .= '<span class="name_'.$section['id'].$currentMenuClass.'">'.$section['name'].'</span>';
    			}
    			$contents .= '</a>';

    			$out .= '
          <li class="menu_'.$section['id'].$currentMenuClass.'">'.$contents.'</li>';
    		}
    	}
    	//Admin
    	if (isAdmin($userprefs[1])) {
    		// Class ajouté à la section du menu affichée
    		$currentMenuClass = ($base_current == $menu_admin['base'])? ' curr_item' : '';

    		$contents = ' <a href="'.CHEMIN.$menu_admin['url'].'" title="'.strip_tags($menu_admin['title']).'">';
    		if ($page[9] != '' && is_file(CHEMIN.$menu_admin['icon'])) {
    			$contents .= '<img src="'.CHEMIN.$menu_admin['icon'].'" alt="'.strip_tags($menu_admin['name']).'" title="'.strip_tags($menu_admin['title']).'"'.(($page[20] != '')? 'class="imgover"' : '').' />';
    		}
    		$contents .= '<span class="name_'.$menu_admin['id'].$currentMenuClass.'">'.$menu_admin['name'].'</span>';
    		$contents .= '</a>';

    		$out .= '
        <li class="menu_'.$menu_admin['id'].$currentMenuClass.'">'.$contents.'</li>';
    	}
    	$out .= '
      </ul>';
        $out .= displayQuickConfig($pos, false, '', '', '', 29);
    	return '
<div class="'.$pos.$tconfig.'MI">'.boxthin($pos, $title_menu, $out, ' MI'.$pos.$tconfig, TYP_SCREEN == 'WEB' ? $dynabox[0] : $dynabox[20]).'
</div>';
    }
}

################################################################################

function fbox_cita($pos = NULL, $args = NULL) {
    global $lng, $lang, $drtuser, $serviz, $userprefs, $web, $page, $tconfig, $reptheme;
    global $type, $fileid, $status, $creadate, $moddate, $author, $email,
         $fielda1, $fielda2, $fieldb1, $fieldb2, $fieldc1, $fieldc2,
         $fieldd1, $fieldd2, $fieldweb, $fieldmail, $fieldmod;
	$bc  = $args[0];
	$out = '';
    $dbw = SelectDBFields(TYP_THINK, 'a', '');
    if (count($dbw) > 0) {
		if ($serviz[108] == '') {
			srand(MakeSeed());
			$i = rand(0, count($dbw)-1);
			ReadDoc($dbw[$i][1]);
			if (isAuthorizedPublication($creadate)) {
				if ($lng == $lang[0]) {
					$txt1 = PathToImage($fieldc1);
					$txt2 = $fieldb1;
				} else {
					$txt1 = PathToImage($fieldc2);
					$txt2 = $fieldb2;
				}
				$txt1 = str_ireplace('<p>', ' ', $txt1);
				$txt1 = str_ireplace('</p>', ' ', $txt1);
				$out  = '
<div class="quote QOT'.$pos.$tconfig.'">
  <span class="labelcita">'.$web[5].'&nbsp;&nbsp;</span><span class="cita">'.$txt1.'&nbsp;&nbsp;</span><span class="author">'.$txt2.'</span>
</div>';
			}
		} else {
			$citatime = $serviz[109] * 1000;
			$out = '
<style type="text/css">
  #lgcita'.$bc.' { position: relative; }
  #lgcita'.$bc.' div { display: none; position: absolute; }
  #lgcita'.$bc.' #citafirst'.$bc.' { position: relative; display: block; }
</style>
<div class="quote">
  <div id="lgcita'.$bc.'">';
			$n = min($bc, count($dbw)) - 1;
			for ($i = 0; $i < count($dbw); $i++) {
				ReadDoc($dbw[$i][1]);
				if (!isAuthorizedPublication($creadate)) continue;
				if ($lng == $lang[0]) {
					$txt1 = PathToImage($fieldc1);
					$txt2 = $fieldb1;
				} else {
					$txt1 = PathToImage($fieldc2);
					$txt2 = $fieldb2;
				}
				$txt1 = str_ireplace('<p>', ' ', $txt1);
				$txt1 = str_ireplace('</p>', ' ', $txt1);
				$out .= '
    <div'.($i == $n ? ' id="citafirst'.$bc.'" ' : '').'>
      <span class="labelcita">'.$web[5].'&nbsp;&nbsp;</span><span class="cita">'.$txt1.'&nbsp;&nbsp;</span><span class="author">'.$txt2.'</span>
    </div>';
			}
			$out .= '
  </div>
  <script type="text/javascript">
    function nextcita'.$bc.'(speed) {
      $("#citafirst'.$bc.'").hide();
      if ($("#citafirst'.$bc.'").next().fadeOut(speed).length)
        $("#citafirst'.$bc.'").next().fadeIn(speed,function(){
          $("#citafirst'.$bc.'").removeAttr("id").next().attr("id","citafirst'.$bc.'");
        });
      else
        $("#lgcita'.$bc.' div:first").fadeIn(speed,function(){
		  $("#citafirst'.$bc.'").removeAttr("id");
          $("#lgcita'.$bc.' div:first").attr("id","citafirst'.$bc.'");
		});
    }
    setInterval("nextcita'.$bc.'(0)",'.$citatime.');
  </script>
</div>';
		}
        $out .= displayQuickConfig($pos, false, 'think', '', '', 28);
		return $out;
    } else {
        return FALSE;
    }
}

################################################################################

function fbox_count($pos = NULL, $args = NULL) {
    global $lng, $lang, $drtuser, $nom, $page, $site, $serviz, $userprefs, $web, $tabcounter, $dynabox, $tconfig, $charset, $reptheme;
    $i = $lng == $lang[0] ? 0 : 10;
    $out1 = $out2 = '
<p class="box textLeft">&nbsp;';
    if ($page[11] == '') {
        $out1 .= $tabcounter[0].'&nbsp;';
        $out2 .= $tabcounter[1].'&nbsp;';
    }
    else {
        $out1 .= AfficheCompteur(CHEMIN.'inc/img/counter/'.$page[11].'/', $tabcounter[0]);
        $out1 .= '&nbsp;&nbsp;';
        $out2 .= AfficheCompteur(CHEMIN.'inc/img/counter/'.$page[11].'/', $tabcounter[1]);
        $out2 .= '&nbsp;&nbsp;';
    }
    $out1 .= $tabcounter[0] == 1 ? $web[15] : $web[16];
    $out1 .= '
</p>';
    $out2 .= $tabcounter[1] == 1 ? $web[17] : $web[18];
    $out2 .= '
</p>';
    $out = $out1.$out2;
    $out .= displayQuickConfig($pos, false, 'counter', '', '', 31);
	$titre = TYP_SCREEN == 'WEB' ? getLabel($nom[$lng == $lang[0] ? 8 : 18]) : getLabel($nom[$lng == $lang[0] ? 62 : 63]);
	$titre = mb_substr(trim($titre), 0, 1, $charset) == '§' ? '' : DisplayDownArrow($dynabox[22]).$titre;
    return '
<div class="'.$pos.$tconfig.'CNT">'.boxthin($pos, $titre, $out, ' CNT'.$pos.$tconfig, TYP_SCREEN == 'WEB' ? $dynabox[2] : $dynabox[22]).'
</div>';
}

################################################################################

function fbox_ban($pos = NULL, $args = NULL) {
    global $lng, $lang, $drtuser, $serviz, $userprefs, $web, $page, $tconfig, $reptheme;
    global $type, $fileid, $status, $creadate, $moddate, $author, $email,
         $fielda1, $fielda2, $fieldb1, $fieldb2, $fieldc1, $fieldc2,
         $fieldd1, $fieldd2, $fieldweb, $fieldmail, $fieldmod;
	$bc  = $args[0];
    $dbw = SelectDBFields(TYP_BANNER, 'a', '');
    if (count($dbw) > 0) {
		if ($serviz[25] == '') {
			$out = '
<div class="banner">';
			srand(MakeSeed());
			$i = rand(0,count($dbw)-1);
			ReadDoc($dbw[$i][1]);
			if (isAuthorizedPublication($creadate)) {
				if ($lng == $lang[0]) {
					$img = $fielda1;
					$url = $fieldb1;
					$alt = empty($fieldd1) ? $url : $fieldd1;
				} else {
					$img = empty($fielda2) ? $fielda1 : $fielda2;
					$url = empty($fieldb2) ? $fieldb1 : $fieldb2;
					$alt = empty($fieldd2) ? $url : $fieldd2;
				}
				$img = CHEMIN.'img/'.$img;
				$extn = substr($img,-3);

				if (isImage($extn)) {
					if (!empty($url)) {
						$out .= '
  <a href="'.$url.'" target="'.TYP_BLANK.'" title="'.$alt.'">';
					}
					$out .= '
    <img src="'.$img.'" alt="'.$alt.'" title="'.$alt.'" />';
					if (!empty($url)) {
						$out .= '
  </a>';
					}
				}
			}
		} else {
			$bantime = $serviz[26] * 1000;
			$out = '
<style type="text/css">
  #ban'.$bc.' { position: relative; }
  #ban'.$bc.' a { display: none; position: absolute; }
  #ban'.$bc.' #banfirst'.$bc.' { position: relative; display: block; }
</style>
<div class="banner BAN'.$pos.$tconfig.'">
  <div id="ban'.$bc.'">';
			$n = min($bc, count($dbw)) - 1;
			for ($i = 0; $i < count($dbw); $i++) {
				ReadDoc($dbw[$i][1]);
				if (!isAuthorizedPublication($creadate)) continue;
				if ($lng == $lang[0]) {
					$img = $fielda1;
					$url = $fieldb1;
					$alt = empty($fieldd1) ? $url : $fieldd1;
				} else {
					$img = empty($fielda2) ? $fielda1 : $fielda2;
					$url = empty($fieldb2) ? $fieldb1 : $fieldb2;
					$alt = empty($fieldd2) ? $url : $fieldd2;
				}
				$img = CHEMIN.'img/'.$img;
				$extn = substr($img,-3);

				if (isImage($extn)) {
					if (!empty($url)) {
						$out .= '
    <a '.($i == $n ? 'id="banfirst'.$bc.'" ' : '').'href="'.$url.'" target="'.TYP_BLANK.'" title="'.$alt.'">';
					}
					$out .= '
	  <img src="'.$img.'" alt="'.$alt.'" title="'.$alt.'" />';
					if (!empty($url)) {
						$out .= '
	</a>';
					}
				}
			}
			$out .= '
  </div>
  <script type="text/javascript">
    function nextban'.$bc.'(speed) {
      if ($("#banfirst'.$bc.'").fadeOut(speed).next().length)
        $("#banfirst'.$bc.'").next().fadeIn(speed,function(){
          $("#banfirst'.$bc.'").removeAttr("id").next().attr("id","banfirst'.$bc.'");
        });
      else
        $("#ban'.$bc.' a:first").fadeIn(speed,function(){
		  $("#banfirst'.$bc.'").removeAttr("id");
          $("#ban'.$bc.' a:first").attr("id","banfirst'.$bc.'");
		});
    }
    setInterval("nextban'.$bc.'(0)",'.$bantime.');
  </script>';
		}
        $out .= displayQuickConfig($pos, false, 'banner', '', '', 27);
        return $out.'
</div>';
    } else {
        return FALSE;
    }
}

################################################################################

function fbox_search($pos = NULL, $args = NULL) {
    global $lng, $lang, $members, $nom, $page, $site, $serviz, $userprefs, $drtuser, $web, 
           $dynabox, $urlrw, $tconfig, $charset, $reptheme, $z2;
    static $nbox = 0;
    $nbox++;
    $i = $lng == $lang[0] ? 0 : 1;
    $j = 10 * $i;
    $options  = '';
    $options .= SearchOption(true,                isAccessGranted($members[1]),  TYP_ART,     $web[169]);
    $options .= SearchOption($serviz[29] == 'on', isAccessGranted($members[1]) && isAccessGranted($members[11]), TYP_REACT,   $web[187]);
    $options .= SearchOption($serviz[10] == 'on', isAccessGranted($members[7]),  TYP_DNLOAD,  getLabel($nom[1+$j]));
    $options .= SearchOption($serviz[14] == 'on', isAccessGranted($members[4]),  TYP_FAQ,     getLabel($nom[24+$i]));
    $options .= SearchOption($serviz[13] == 'on', isAccessGranted($members[5]),  TYP_FORUM,   getLabel($nom[22+$i]));
    $options .= SearchOption($serviz[12] == 'on', isAccessGranted($members[12]), TYP_GUESTBK, getLabel($nom[9+$j]));
    $options .= SearchOption($serviz[11] == 'on', isAccessGranted($members[3]),  TYP_LINKS,   getLabel($nom[3+$j]));
    $options .= SearchOption($serviz[8]  == 'on', isAccessGranted($members[13]), TYP_NEWS,    getLabel($nom[7+$j]));
    $options .= SearchOption($serviz[53] == 'on', isAccessGranted($members[15]), TYP_BLOG,    getLabel($nom[42+$i]));
    $options .= SearchOption($serviz[9]  == 'on', isAccessGranted($members[2]),  TYP_PHOTO,   getLabel($nom[2+$j]));
    $options .= SearchOption($serviz[47] == 'on', isAccessGranted($members[14]), TYP_AGENDA,  $web[488]);
    $options .= SearchOption(true,                true                         , TYP_ARCH,    $web[399]);

    if (in_array($pos, array(BOX_LEFT, BOX_RIGHT))) {
        $out = '
<div class="thinboxsearch TS'.$pos.$tconfig.'">
  <form class="textCenter" name="thinsearch'.$nbox.'" action="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[12].'-'.$tconfig.$z2 : 'search.php?lng='.$lng.'&amp;tconfig='.$tconfig.$z2).'" method="post">
    <input name="search" class="texte" type="text" size="18" placeholder="'.$web[58].'" value="" />
	<a href="#" onclick="javascript:document.thinsearch'.$nbox.'.submit();"> 
	  <img class="imgsearch'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'" src="'.$reptheme.'/search.png" alt="'.getLabel($nom[$lng == $lang[0] ? 20 : 21]).'" />
	</a>
    <div class="thinboxsearch'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
	  <select name="searchin">
        <option value="" selected="selected">'.$web[168].'</option>
        '.$options.'
      </select>
	</div>';
        if ($lang[1] != '') {
            $out .= '
    <div class="thinboxsearch'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
      <select name="searchlng">
        <option value="">['.$lang[0].'] '.$web[177].' ['.$lang[1].']</option>
        <option value="'.$lang[0].'"'.Selected($lng == $lang[0]).'>['.$lang[0].'] '.$web[178].'</option>
        <option value="'.$lang[1].'"'.Selected($lng == $lang[1]).'>['.$lang[1].'] '.$web[178].'</option>
      </select>
	</div>';
        } else {
            $out .= '
    <input type="hidden" name="searchlng" value="'.$lang[0].'" />';
        }
        $out .= '
 </form>
</div>';
		$out .= displayQuickConfig($pos, false, '', '', '', 49);
		$titre = TYP_SCREEN == 'WEB' ? getLabel($nom[$lng == $lang[0] ? 20 : 21]) : getLabel($nom[$lng == $lang[0] ? 64 : 65]);
		$titre = mb_substr(trim($titre), 0, 1, $charset) == '§' ? '' : DisplayDownArrow($dynabox[23]).$titre;
        return '
<div class="'.$pos.$tconfig.'TS">'.boxthin($pos, $titre, $out, ' TS'.$pos.$tconfig, TYP_SCREEN == 'WEB' ? $dynabox[3] : $dynabox[23]).'
</div>';
    } else {
       $out = '
<div class="wideboxsearch WS'.$pos.$tconfig.'">
  <form name="widesearch'.$nbox.'" action="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[12].'-2-'.$lng.'-'.$tconfig.$z2 : 'search.php?lng='.$lng.'&amp;searchlng='.$lng.'&amp;tconfig='.$tconfig.$z2).'" method="post">
    <input type="hidden" name="searchin" value="" />
	<input name="search" class="texte" type="text" size="18" placeholder="'.$web[58].'" value="" />
	<a href="#" onclick="javascript:document.widesearch'.$nbox.'.submit();"> 
	  <img class="imgsearchW" src="'.$reptheme.'/search.png" alt="'.getLabel($nom[$lng == $lang[0] ? 20 : 21]).'" />
	</a>
 </form>
</div>';
		$out .= displayQuickConfig($pos, false, '', '', '', 49);
		if (in_array($pos, array(BOX_TOP, BOX_BOTTOM))) {
			return $out;
		} else {
			return boxwide($pos, '', $out, ' WS'.$pos.$tconfig);
		}
    }
}

################################################################################

function fbox_search2($pos = NULL, $args = NULL) {
    global $lng, $lang, $members, $nom, $page, $site, $serviz, $userprefs, $drtuser, $web, $urlrw, $tconfig, $reptheme, $z2;
    static $nbox = 0;
    $nbox++;
    $i = $lng == $lang[0] ? 0 : 1;
    $j = 10 * $i;
    $options = '';
    $options .= SearchOption(true,                isAccessGranted($members[1]),  TYP_ART,     $web[169]);
    $options .= SearchOption($serviz[29] == 'on', isAccessGranted($members[1]) && isAccessGranted($members[11]), TYP_REACT,   $web[187]);
    $options .= SearchOption($serviz[10] == 'on', isAccessGranted($members[7]),  TYP_DNLOAD,  getLabel($nom[1+$j]));
    $options .= SearchOption($serviz[14] == 'on', isAccessGranted($members[4]),  TYP_FAQ,     getLabel($nom[24+$i]));
    $options .= SearchOption($serviz[13] == 'on', isAccessGranted($members[5]),  TYP_FORUM,   getLabel($nom[22+$i]));
    $options .= SearchOption($serviz[12] == 'on', isAccessGranted($members[12]), TYP_GUESTBK, getLabel($nom[9+$j]));
    $options .= SearchOption($serviz[11] == 'on', isAccessGranted($members[3]),  TYP_LINKS,   getLabel($nom[3+$j]));
    $options .= SearchOption($serviz[8]  == 'on', isAccessGranted($members[13]), TYP_NEWS,    getLabel($nom[7+$j]));
    $options .= SearchOption($serviz[53] == 'on', isAccessGranted($members[15]), TYP_BLOG,    getLabel($nom[42+$i]));
    $options .= SearchOption($serviz[9]  == 'on', isAccessGranted($members[2]),  TYP_PHOTO,   getLabel($nom[2+$j]));
    $options .= SearchOption($serviz[47] == 'on', isAccessGranted($members[14]), TYP_AGENDA,  $web[488]);
    $options .= SearchOption(true,                true                         , TYP_ARCH,    $web[399]);

    $out = '
<form name="widesearch2'.$nbox.'" action="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[12].'-2-'.$lng.'-'.$tconfig.$z2 : 'search.php?lng='.$lng.'&amp;searchlng='.$lng.'&amp;tconfig='.$tconfig.$z2).'" method="post">
  <div id="search2'.$nbox.'" class="'.(in_array($pos, array(BOX_LEFT, BOX_RIGHT)) ? 'thinboxsearch1 TS1' : 'wideboxsearch1 WS1').$pos.$tconfig.'">
    <input type="hidden" name="searchin" value="" />
	<input name="search" class="texte" type="text" size="18" placeholder="'.$web[58].'" value="" />
	<a href="#" onclick="javascript:document.widesearch2'.$nbox.'.submit();"> 
	  <img class="imgsearch'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'" src="'.$reptheme.'/search.png" alt="'.getLabel($nom[$lng == $lang[0] ? 20 : 21]).'" />
	</a>
    <div id="adv1'.$nbox.'" class="adv1'.(TYP_SCREEN == 'WEB' ? 'web' : 'mob').'">
      <a href="javascript:cache(\'adv1'.$nbox.'\'); montre(\'adv2'.$nbox.'\'); montre(\'search1'.$nbox.'\');">'.$web[590].'</a>
    </div>
    <div id="adv2'.$nbox.'" class="adv2'.(in_array($pos, array(BOX_LEFT, BOX_RIGHT)) ? '' : ' adv2W').'">&nbsp;</div>
    <div id="search1'.$nbox.'" class="'.(in_array($pos, array(BOX_LEFT, BOX_RIGHT)) ? 'thinboxsearch2'.(in_array($pos, array(BOX_LEFT, BOX_RIGHT)) ? '' : ' thinboxsearch2W') : 'wideboxsearch2'.(in_array($pos, array(BOX_LEFT, BOX_RIGHT)) ? '' : ' wideboxsearch2W')).'">
      <div class="'.(in_array($pos, array(BOX_LEFT, BOX_RIGHT)) ? 'thinboxsearch3' : 'wideboxsearch3').(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
	    <select name="searchin">
          <option value="" selected="selected">'.$web[168].'</option>
          '.$options.'
        </select>
	  </div>';
    if ($lang[1] != '') {
        $out .= '
      <div class="searchlng'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
        <select name="searchlng">
          <option value="">['.$lang[0].'] '.$web[177].' ['.$lang[1].']</option>
          <option value="'.$lang[0].'"'.Selected($lng == $lang[0]).'>['.$lang[0].'] '.$web[178].'</option>
          <option value="'.$lang[1].'"'.Selected($lng == $lang[1]).'>['.$lang[1].'] '.$web[178].'</option>
        </select>
	  </div>';
    } else {
        $out .= '
      <input type="hidden" name="searchlng" value="'.$lang[0].'" />';
    }
    $out.= '
      <img class="searchclose" src="'.$reptheme.'/close.png" alt="'.$web[57].'" title="'.$web[57].'" onclick="cache(\'adv2'.$nbox.'\'); cache(\'search1'.$nbox.'\'); montre(\'adv1'.$nbox.'\');" />
    </div>
  </div>
</form>
';
	$out .= displayQuickConfig($pos, false, '', '', '', 49);
	if (in_array($pos, array(BOX_TOP, BOX_BOTTOM))) {
		return $out;
	} else {
		if (in_array($pos, array(BOX_LEFT, BOX_RIGHT))) {
			return '
<div class="'.$pos.$tconfig.'SCH">'.boxthin($pos, '', $out, ' SCH'.$pos.$tconfig).'</div>';
		} else {
			return boxwide($pos, '', $out, ' SCH'.$pos.$tconfig);
		}
	}
}

################################################################################

function fbox_freebox($pos = NULL, $args = NULL) {
    global $lng, $lang, $drtuser, $serviz, $site, $userprefs, $web, $page, $tconfig, $charset, $reptheme;
    global $type, $fileid, $status, $creadate, $moddate, $author, $email,
         $fielda1, $fielda2, $fieldb1, $fieldb2, $fieldc1, $fieldc2,
         $fieldd1, $fieldd2, $fieldweb, $fieldmail, $fieldmod;
    $sidebox = in_array($pos, array(BOX_LEFT, BOX_RIGHT, BOX_TOP, BOX_BOTTOM));
    $id = $args[0];
    ReadDoc($id);
    if (!isAccessGranted($fieldmod) || !isAuthorizedPublication($creadate)) return FALSE;
    if ($type != TYP_FREEBOX) return FALSE;
    if ($status != 'a') return FALSE;
    $fieldweb   = intval($fieldweb);
    $max_height = $fieldweb;
	$dynbox     = explode('|', $fielda2);
	$class      = ' FB'.$fileid;
    if ($lng == $lang[0]) {
        $titre   = $fieldb1;
        $contenu = PathToImage($fieldc1);
    }
    else {
        $titre = $fieldb2;
        $contenu = PathToImage($fieldc2);
    }
	if ($pos == BOX_EDITO && mb_substr(trim($titre), 0, 2, $charset) == '§§') 
		$titre = sprintf(empty($userprefs[1]) ? $web[1] : $web[167], stripslashes($site[($lang[0] == $lng ? 0 : 11)]), $userprefs[1]);
    $titre = mb_substr(trim($titre), 0, 1, $charset) == '§' ? '' : ($pos == BOX_EDITO ? '' : DisplayDownArrow($dynbox[1])).$titre;
    $out = '
<a id="freebox'.$pos.$id.'"></a>
<div class="'.$pos.$tconfig.'fb'.$id.'">';
    $content = '';
    if (!empty($contenu)) {
        $content .= '
<style type="text/css">
.freebox'.$id.' {
  height: '.($max_height > 0 ? $max_height.'px;' : 'auto;').'
  overflow: '.($max_height > 0 ? 'hidden;' : 'visible;').'
}
</style>';
        $content .= '
  <div id="box'.$id.'30" class="box freebox'.$id.'">'.$contenu.'</div><div class="c-both"></div>';
        if ($max_height > 0) $content .= '
    <p id="box'.$id.'10" class="textRight clsCursor">
      <a href="javascript:cache(\'box'.$id.'30\');montre(\'box'.$id.'20\');cache(\'box'.$id.'10\');" title="'.$web[296].'">
        '.$web[505].' <img src="'.$reptheme.'/plus.png" alt="'.$web[296].'" />
      </a>
    </p>';
        if ($max_height > 0) {
            $content .= '
  <div id="box'.$id.'20" class="box displayNone">'.$contenu.'
    <p class="textRight clsCursor">
      <a href="#freebox'.$pos.$id.'" title="'.$web[57].'" onclick="cache(\'box'.$id.'20\');montre(\'box'.$id.'30\');montre(\'box'.$id.'10\');">
	    '.$web[57].' <img src="'.$reptheme.'/minus.png" alt="'.$web[57].'" />
      </a>
    </p>
  </div><div class="c-both"></div>';
        }
    }
  $content .= displayQuickConfig($pos, $id, 'freebox&amp;form=2&amp;tri=ch&amp;id='.$id, '', '', 26);
	if ($sidebox) {
		$out .= boxthin($pos, $titre, $content, $class, TYP_SCREEN == 'WEB' ? $dynbox[0] : $dynbox[1]);
	} else {
		$out .= boxwide($pos, $titre, $content, $class);
	}
	$out .= '
</div>';
    return $out;
}

################################################################################

function fbox_user($pos = NULL, $args = NULL) {
    global $lng, $lang, $members, $nom, $userprefs, $web, $endurl, $serviz, $cryptinstall, 
	       $dynabox, $site, $urlrw, $page, $tconfig, $charset, $reptheme, $tabcounter, $drtuser, $z2;
    static $nbox = 0;
    $nbox++;
	if (empty($cryptinstall)) {
		if ($serviz[100] == '1') {
			$cryptinstall = CRYPTREP.'cryptographp.fct.php';
			include_once $cryptinstall;
		} elseif ($serviz[100] == '2') {
			$cryptinstall = CRYPTREP.'cryptotexte.fct.php';
			include_once $cryptinstall;
		}
	}
    $out = '
    <div class="box textRight marginAuto">';

    if (!empty($userprefs[1])) {
        $out .='
	  <form name="useraccount'.$nbox.'" action="'.CHEMIN.($site['URLR'] == 'on'? $lng.'-'.$urlrw[3].'-14-'.$tconfig.$z2 : 'compte.php?lng='.$lng.'&amp;tconfig='.$tconfig.$z2).'" method="post">
	    <div class="textCenter'.(TYP_SCREEN == 'WEB' ? ' userButtonW' : ' userButtonM').'">'.SubmitButton($web[212]).'</div>
	  </form>
	  <form name="usermsg'.$nbox.'" action="'.CHEMIN.($site['URLR'] == 'on'? $lng.'-'.$urlrw[13].'-3-3-'.$tconfig.$z2 : 'tinymsg.php?lng='.$lng.'&amp;action=3&amp;tconfig='.$tconfig.$z2).'" method="post">
	    <div class="textCenter'.(TYP_SCREEN == 'WEB' ? ' userButtonW' : ' userButtonM').'">'.SubmitButton($web[318]).'</div>
	  </form>
	  <form name="useroff'.$nbox.'" action="'.CHEMIN.($site['URLR'] == 'on'? $lng.'-'.$urlrw[3].'-1-off-'.$tconfig.$z2 : 'connect.php?lng='.$lng.'&amp;connect=off&amp;tconfig='.$tconfig.$z2).'" method="post">
	    <div class="textCenter'.(TYP_SCREEN == 'WEB' ? ' userButtonW' : ' userButtonM').'">'.SubmitButton($web[372]).'</div>
	  </form>';
    }
    else {
        if ($members[19] != '0' && $members[19] != '3') {
            $out .='
	  <form name="usermemb'.$nbox.'" action="'.CHEMIN.($site['URLR'] == 'on'? $lng.'-'.$urlrw[3].'-3-on-new-'.$tconfig.$z2 : 'connect.php?lng='.$lng.'&amp;connect=on&amp;uuser=new&amp;tconfig='.$tconfig.$z2).'" method="post">
	    <div class="textCenter'.(TYP_SCREEN == 'WEB' ? ' userButtonW' : ' userButtonM').'">'.SubmitButton($web[160]).'</div>
	  </form>
	  <hr />';
        }
        $out.= '
<style type="text/css">
.fbx-password {
	font-size: 9px;
	text-transform: uppercase;
	position: absolute;
	cursor: pointer;
	margin: 6px 0 0 -20px;
}
</style>
<script text="javascript">
  $(document).ready(function(){
    $(".fbx-password").click(function() {
        if($(this).prev("input").prop("type") == "password") {
            $(this).prev("input").prop("type","text");
            $(this).children("img").prop("title","'.$web[474].'");
        } else {
            $(this).prev("input").prop("type","password");
            $(this).children("img").prop("title","'.$web[473].'");
        }
    });
  });
</script>
	  <div class="textCenter marginAuto">
        <b>'.$web[373].' :</b>
        <form name="userin'.$nbox.'" action="'.CHEMIN.($site['URLR'] == 'on'? $lng.'-'.$urlrw[3].'-0-'.$tconfig.$z2 : 'connect.php?lng='.$lng.'&amp;tconfig='.$tconfig.$z2).'" method="post">
          <input type="hidden" name="connect" value="on"/>
          <input type="hidden" name="uuser" value="old"/>
          <div class="textCenter;">
		    '.$web[49].'
            <div><input class="texte userIdent'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'" type="text" name="pseudo"  value=""/></div>
            '.$web[300].'
            <div>
              <input class="texte userIdent'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'" type="password" name="uid" value=""/>
              <span class="fbx-password"><img src="inc/img/look.png" alt="<O>" title="'.$web[473].'" /></span>
            </div>';
        if ($serviz[100] != '0' && $serviz[88] == 'on' && ($userprefs[1] == '' || $serviz[98] == '')) {
			$lbl = $serviz[100] == '3' ? $web[642] : '';
            $out .= '
			<div class="boxCrypt'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
			  '.dsp_crypt(0, 1, 3, 0, $lbl, $serviz[115] == 'on' ? $web[643] : '').'
	          <div class="textCenter marginAuto">
                '.($serviz[100] == '3' ? '' : $web[530]).'<input class="texte" type="text" name="crypt" size="6" onpaste="return false;" />
			  </div>
			</div>';
        }
        $out .= '      
              '.SubmitButton($web[52]).'
          </div>
        </form>
	  </div>
	  <div class="textCenter userLost'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
	    <a class="userLostA" href="'.CHEMIN.($site['URLR'] == 'on'? $lng.'-'.$urlrw[3].'-16-'.$tconfig.$z2 : 'lostpass.php?lng='.$lng.'&amp;tconfig='.$tconfig.$z2).'">'.sprintf($web[592], $reptheme).'</a>
	  </div><br />';
    }
    $out .= '
    </div>';

    $nbrmsg = array();
    if (FileDBExist(MSGREP.$userprefs[1].DBEXT)) {
        $dbmsg = ReadDBFields(MSGREP.$userprefs[1].DBEXT);
        if ($dbmsg[0][0] == $userprefs[7]) {
            for ($i = 2; $i < count($dbmsg); $i++) {
                if (isset($dbmsg[$i][3]) && $dbmsg[$i][3] == 'new') {
                    $nbrmsg[] = $dbmsg[$i][3];
                }
            }
        }
    }
    if (count($nbrmsg) != 0 && TYP_SCREEN == 'WEB') {
        $out .= '
	<div class="userWave textCenter">
      <a class="box" href="'.CHEMIN.($site['URLR'] == 'on'? $lng.'-'.$urlrw[13].'-3-3-'.$tconfig.$z2 : 'tinymsg.php?lng='.$lng.'&amp;action=3&amp;tconfig='.$tconfig.$z2).'">
        <img src="'.$reptheme.'/newmsg.gif" alt="'.$web[319].'" title="'.$web[319].'" />
      </a>';
        if (FALSE === stristr($endurl, 'tinymsg.php')) {
            $out .= '
      <object type="audio/wave" data="'.CHEMIN.'inc/mail/mail.wav">
        <param name="src" value="'.CHEMIN.'inc/mail/mail.wav" />
        <param name="autoplay" value="true" />
        <param name="autoStart" value="1">
        <param name="controller" value="false">
        <param name="filename" value="'.CHEMIN.'inc/mail/mail.wav" />
        <param name="showcontrols" value="false" />
      </object>';
        }
        $out .= '
    </div>';
    }
    if ($serviz[158].$serviz[159] != 'onon') $out .= '
    <hr />';
    $file_users  = opendir(MSGREP);
    $nbr_membres = 0;
    while ($nomfichier = readdir($file_users)) {
        if ('.dtb' == $nomfichier) {
            @unlink(MSGREP.$nomfichier);
            continue;
        }
        if( substr($nomfichier,-3) == "dtb" ) {
            $nbr_membres++;
        }
    }
    closedir($file_users);
    if ($nbr_membres > 1) {
        $text_nbr_membres = $web[321];
    }
    else {
        $text_nbr_membres = $web[322];
    }
	if ($serviz[149] == 'on') {
		if ($page[11] == '') {
			$out1 .= $tabcounter[0].'&nbsp;';
			$out2 .= $tabcounter[1].'&nbsp;';
		}
		else {
			$out1 .= AfficheCompteur(CHEMIN.'inc/img/counter/'.$page[11].'/', $tabcounter[0]).'&nbsp;&nbsp;';
			$out2 .= AfficheCompteur(CHEMIN.'inc/img/counter/'.$page[11].'/', $tabcounter[1]).'&nbsp;&nbsp;';
		}
		$out .= '
    <div class="userCount textLeft">&nbsp;
	  '.$out1.($tabcounter[0] == 1 ? $web[15] : $web[16]).'<br />&nbsp;
      '.$out2.($tabcounter[1] == 1 ? $web[17] : $web[18]).'<br /><br />
	</div>';
	}
    $regusers    = ReadDBFields(DBIPSTATS);
    $usersonline = array();
	$myIP        = '';
    foreach ($regusers as $reg) {
        if (!empty($reg[2])) {
			if ($userprefs[1] == $reg[2]) $myIP = $reg[0];
            $usersonline[] = array($reg[2], $reg[0]);
        }
    }
    @usort($usersonline,'AsciiCompare');
	$uniqueusers   = array();
	$uniqueusers[] = $usersonline[0];
	for ($i = 1; $i < count($usersonline); $i++) {
		if ($usersonline[$i][0] != $usersonline[$i-1][0]) {
			$uniqueusers[] = $usersonline[$i];
		}
	}
    if ($serviz[158] != 'on') {
        $out .= '
    <div class="userList box textLeft">&nbsp;';
        if ($userprefs[1] != '' && $userprefs[20] != 'on' && $userprefs[5] == 'on' && $serviz[86] == 'on' && TYP_SCREEN == 'WEB') $out .= '
	  <a href="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[15].'-9-'.$tconfig.$z2 : 'memberlist.php?lng='.$lng.'&amp;tconfig='.$tconfig.$z2).'" title="'.$web[664].'"><strong>';
        $out .= '
	    <img src="'.$reptheme.'/nbrmembres.png" alt="'.$web[320].'" title="'.$web[320].'" />&nbsp;'.$nbr_membres." ".$text_nbr_membres;
        if ($userprefs[1] != '' && $userprefs[20] != 'on' && $serviz[86] == 'on' && TYP_SCREEN == 'WEB') $out .= '</strong>
      </a>';
        $out .= '
	</div>';
    }
    $visits  = ReadDBFields(USERREP.'visitsofday.dtb');
    $today   = date('Ymd');
    $visits1 = array();
    foreach ($visits as $visit) if ($visit[1] == $today) $visits1[] = $visit;
    $found = false;
    foreach ($uniqueusers as $unuser) {
        foreach ($visits1 as $visit) if ($visit[0] == $unuser[0]) $found = true;
        if (!$found && !empty($unuser[0])) $visits1[] = array($unuser[0], $today);
        $found = false;
    }
    WriteDBFields(USERREP.'visitsofday.dtb', $visits1);
	if ($userprefs[1] != '' && $userprefs[20] != 'on' && $serviz[111] == 'on') {
		$visitsday = SelectDBFieldsByField(ReadDBFields(USERREP.'visitsofday.dtb'), 1, $today);
        $visits    = array();
		foreach ($visitsday as $visit) {
            if (is_file(MSGREP.$visit[0].'.dtb')) $visits[] = $visit;
		}
		$out .= '
	<div class="userVisits box textLeft">&nbsp;';
		$nbvisits = count($visits);
		if ($nbvisits > 0) $out .= '
	  <a class="clsCursor" title="'.$web[677].'" onmouseup="montre(\'visits\');">';
		$out .= '
	    <img src="'.$reptheme.'/nbrmembres.png" alt="'.$web[677].'" title="'.$web[677].'" />'.$web[677].$nbvisits;
		if ($nbvisits > 0) $out .= '
	  </a>';
		$out .= '
	</div>
<style type="text/css">
.visits {
    margin-top: -'.min(200, ($nbvisits*18)).'px;
}
</style>
	<div id="visits" class="visits">
	  <div class="visits2">';
		foreach ($visits as $visit) {
			$db = ReadDBFields(MSGREP.$visit[0].'.dtb');
            if (!empty($db) && $db[1][6] == 'on') {
                if (!empty($db[1][16]) || $db[1][9] != 'unknow.png') {
                    $avat = 1 == preg_match('!^[inc/img/avatars]!', $db[1][16]) ? CHEMIN.$db[1][16] : $db[1][16];
                    $src  = $db[1][9] == 'unknow.png' && !empty($db[1][16]) ? $avat : CHEMIN.'inc/img/avatars/'.$page[23].'/'.$db[1][9];
                    $out .= '
            <img src="'.$src.'" alt="" />';
                }
                elseif ($db[1][9] == 'unknow.png') {
                    $out .= '
            <img src="'.CHEMIN.'inc/img/avatars/unknow.png" alt="" />';
                }
                $out .= $visit[0].'<br />';
            }
		}
		$out .= '
	  </div>
	  <div class="visitsClose f-right clsCursor" onmouseup="cache(\'visits\')">&#xe808;</div>
	  <div class="c-both"></div>
	</div>';
	}
    if ($serviz[159] != 'on') {
        $out .= '
    <div class="box textLeft connectedList"><b>'.$web[175].'</b></div>';
        if (empty($usersonline)) {
            $out .= '
    <div class="box textCenter">'.sprintf($web[176], $reptheme).'</div>';
        }
        else {
            $out .= '
    <div class="box textLeft connectedList">';
            for ($i = 0; $i < count($uniqueusers); $i++) {
                if (1 != preg_match('!^http://!', $serviz[85])) $serviz[85] = 'http://'.$serviz[85];
                if (substr($serviz[85], -1) != '/') $serviz[85] = $serviz[85].'/';
                $whois = (($serviz[31] == $userprefs[1] || $serviz[176] == $userprefs[1] || $drtuser[42] == 'admin') && $serviz[84] == 'on' 
                  ? ' (<a href="'.$serviz[85].$uniqueusers[$i][1].'" title="'.$uniqueusers[$i][1].'" target="'.TYP_BLANK.'">'.substr($uniqueusers[$i][1], 0, 8).'...</a>)' : '');
                $db = ReadDBFields(MSGREP.$uniqueusers[$i][0].'.dtb');
                if ($db[1][6] == 'on') {
                    if (!empty($db[1][16]) || $db[1][9] != 'unknow.png') {
                        $avat   = 1 == preg_match('!^[inc/img/avatars]!', $db[1][16]) ? CHEMIN.$db[1][16] : $db[1][16];
                        $src    = $db[1][9] == 'unknow.png' && !empty($db[1][16]) ? $avat : CHEMIN.'inc/img/avatars/'.$page[23].'/'.$db[1][9];
                        $avatar = '<img class="avatar" src="'.$src.'" alt="" />';
                    }
                    elseif ($db[1][9] == 'unknow.png') {
                        $avatar = '<img class="avatar" src="'.CHEMIN.'inc/img/avatars/unknow.png" alt="" />';
                    }
                    if ($userprefs[1] != '' && $userprefs[1] != $uniqueusers[$i][0] && $db[1][24] == 'on') {
                        $from = $userprefs[1];
                        $out .= '
      <div class="'.(TYP_SCREEN == 'WEB' ? 'connectedUserW' : 'connectedUserM').'">
        <img class="connectedImg" src="'.$reptheme.'/puce1.png" alt="'.$web[321].'" title="'.$web[321].'" />'.$avatar.'
        <a href="'.CHEMIN.($site['URLR'] == 'on'? $lng.'-'.$urlrw[13].'-2-1-'.$uniqueusers[$i][0].'-'.$from.'-'.$tconfig.$z2 : 'tinymsg.php?lng='.$lng.'&amp;action=1&amp;to='.$uniqueusers[$i][0].'&amp;from='.$from.'&amp;tconfig='.$tconfig.$z2).'" title="'.$web[214]." ".$uniqueusers[$i][0].'">
          <img src="'.$reptheme.'/mail.png" alt="'.$web[214]." ".$uniqueusers[$i][0].'" title="'.$web[214]." ".$uniqueusers[$i][0].'" />
        </a>&nbsp;&nbsp;'.$uniqueusers[$i][0].$whois.'
      </div>';
                    }
                    else {
                        $out .= '
      <div class="'.(TYP_SCREEN == 'WEB' ? 'connectedUserW' : 'connectedUserM').'">
        <img class="connectedImg" src="'.$reptheme.'/puce2.png" alt="'.$web[321].'" title="'.$web[321].'" />'.$avatar.$uniqueusers[$i][0].'
      </div>';
                    }
                }
            }
            if ($userprefs[1] != '' && $serviz[84] == 'on')
                $out .= '
	  <div class="textCenter userprefIP">IP: <a href="'.$serviz[85].$myIP.'" title="'.$myIP.'" target="'.TYP_BLANK.'">'.$myIP.'</a></div>';
            $out .= '
    </div>';
        }
    }
    if (is_null($pos)) return $out;
	$out .= displayQuickConfig($pos);
	$titre = TYP_SCREEN == 'WEB' ? getLabel($nom[$lng == $lang[0] ? 34 : 35]) : getLabel($nom[$lng == $lang[0] ? 68 : 69]);
	$titre = mb_substr(trim($titre), 0, 1, $charset) == '§' ? '' : DisplayDownArrow($dynabox[25]).$titre;
    return '
<div class="'.$pos.$tconfig.'USR">'.boxthin($pos, $titre, $out, ' USR'.$pos.$tconfig, TYP_SCREEN == 'WEB' ? $dynabox[5] : $dynabox[25]).'
</div>';
}

################################################################################

function fbox_webm($pos = NULL, $args = NULL) {
    global $lng, $lang, $drtuser, $nom, $serviz, $user, $userprefs, $web, $page, $site, $dynabox, $urlrw, 
           $tconfig, $charset, $reptheme, $meskin, $z2;
    if (isset($user[1])) $em = BreakEMail($user[1]);
    $out = '
<div class="box webm">';
    if ($serviz[21] == 'on') {
		$out .= '
  <div class="tbldiv webmtbl'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
	<div class="trtbldiv">';
        if ($serviz[99] == 'on') {
            $out .= '
      <div class="tdtbldiv textCenter">
        <img class="img15x15 valignMiddle" src="'.$reptheme.'/mail.png" alt="'.$web[173].' '.stripslashes($site[($lang[0] == $lng ? 0 : 11)]).'" title="'.$web[173].' '.stripslashes($site[($lang[0] == $lng ? 0 : 11)]).'" />
      </div>
      <div class="tdtbldiv textLeft">
        <a class="box" href="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[2].'-'.$tconfig.$z2 : $site['CT'].'.php?lng='.$lng.'&amp;tconfig='.$tconfig.$z2).'" title="'.$web[464].'">&nbsp;'.$web[464].'</a>
      </div>';
        } else {
            $out .= '
      <div class="tdtbldiv textCenter">
        <img class="img15x15 valignMiddle" src="'.$reptheme.'/mail.png" alt="'.$web[173].' '.$user[0].'" title="'.$web[173].' '.$user[0].'" />
      </div>';
            if ($user[3] == 'on') {
                $out .= '
      <div class="tdtbldiv textLeft">
        <a class="box" href="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[14].'-'.TYP_MAIL.$z2 : $site['PG'].'.php?lng='.$lng.'&amp;typ='.TYP_MAIL.$z2).'" title="'.$web[173].' '.$user[0].'">&nbsp;'.$web[11].'</a>
      </div>';
            } else {
				$org  = 'webm';
                $out .= '
      <div class="tdtbldiv textLeft">
        <a class="gypoplight" href="#?w=300&amp;rel=popup_'.$org.'&amp;btn='.$web[57].'&amp;msk='.$meskin.'" title="'.$web[173].' '.$user[0].'">'.addslashes($user[0]).'</a>
      </div>
      <div class="gypopup_block" id="popup_'.$org.'">
        <p class="textCenter popupMail">'.$web[644].'</p>
        <p class="textCenter popupMail">
        <a href="javascript:showEmails'.$org.'(\''.$em[0].'\',\''.$em[1].'\',\''.$em[2].'\');" title="'.addslashes($user[0]).'" class="textCenter popupMail">'.addslashes($user[0]).'</a>
        </p>
        <p class="textCenter popupMail"><b><span id="lblemail'.$org.'">(--------------)</span></b></p>
      </div>';
	$out .=
	BeginJavascript().'
function showEmails'.$org.'(em1, em2, em3) {
  var emailFinal = "<a href=\'mailto:" + em1 + "@" + em2 + "." + em3 + "\' onclick=\'{$(\'#gyfade , .gypopup_block\').fadeOut(function() {$(\'#gyfade, a.close\').remove();})};\'>" + em1 + "@" + em2 + "." + em3 + "</a>";
  document.getElementById("lblemail'.$org.'").innerHTML = emailFinal;
}
	'.EndJavascript();
            }
        }
		$out .= '
	</div>
  </div>';
    }
    if ($serviz[62] == 'on') {
        $out .= '
  <div class="tbldiv webmtbl'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
	<div class="trtbldiv">
      <div class="tdtbldiv textCenter">
        <img class="img15x15 valignMiddle" src="'.$reptheme.'/reco.png" alt="'.$web[124].'" title="'.$web[124].'" />
      </div>
      <div class="tdtbldiv textLeft">
        <a class="box" href="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[14].'-'.TYP_RECO.$z2 : $site['PG'].'.php?lng='.$lng.'&amp;typ='.TYP_RECO.$z2).'" title="'.$web[124].'">&nbsp;'.$web[120].'</a>
      </div>
	</div>
  </div>';
    }
    if (is_dir(CHEMIN.'mobile')) {
        $out .= '
  <div class="tbldiv webmtbl'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
	<div class="trtbldiv">
      <div class="tdtbldiv textCenter">
        <img class="img15x15 valignMiddle" src="'.$reptheme.'/mobile.png" alt="'.$web[295].'" title="'.$web[295].'" />
      </div>
      <div class="tdtbldiv textLeft">
        <a class="box" href="'.CHEMIN.'mobile?lng='.$lng.'" title="'.$web[295].'" target="'.TYP_BLANK.'">&nbsp;'.$web[295].'</a>
      </div>
	</div>
  </div>';
    }
    $out .= '
</div>';
    $out .= displayQuickConfig($pos);
	$titre = TYP_SCREEN == 'WEB' ? getLabel($nom[$lng == $lang[0] ? 40 : 41]) : getLabel($nom[$lng == $lang[0] ? 74 : 75]);
	$titre = mb_substr(trim($titre), 0, 1, $charset) == '§' ? '' : DisplayDownArrow($dynabox[28]).$titre;
    return '
<div class="'.$pos.$tconfig.'WEB">'.boxthin($pos, $titre, $out, ' WEB'.$pos.$tconfig, TYP_SCREEN == 'WEB' ? $dynabox[8] : $dynabox[28]).'</div>';
}

################################################################################

function fbox_guest($pos = NULL, $args = NULL) {
    global $lng, $lang, $members, $nom, $page, $serviz, $site, $userprefs, $web, $urlrw, $reptheme, $prt, $z2;
    global $type, $fileid, $status, $creadate, $moddate, $author, $email, $tconfig, 
         $fielda1, $fielda2, $fieldb1, $fieldb2, $fieldc1, $fieldc2,
         $fieldd1, $fieldd2, $fieldweb, $fieldmail, $fieldmod;
    static $nbox = 0;
    $nbox++;
    if ($serviz[12] == 'on' && $site[21] > 0) {
        $messok = false;
        if (count(SelectDBFields(TYP_GUESTBK, 'a', $site[21])) != 0) {
            $messok = true;
        }
        $topmess = getLabel($nom[$lng == $lang[0] ? 9 : 19]).' - '.$web[180];
        if ($page[9] != '') {
            $topmess = '<img src="'.CHEMIN.'inc/img/icons/'.$page[9].'/guestbook.gif" class="f-right img32x32" alt="" />'.$topmess;
        }
        if ($members[0] == "on" && $userprefs[1] == "" && !isAccessGranted($members[12])) {
            $out = '
<div class="textCenter web342">'.$web[342];
	if ($members[19] != '0' && $members[19] != '3') 
		$out .= '
  <p>[&nbsp;
    <a href="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[15].'-5-new-'.$tconfig.$z2 : $site['USR'].'.php?lng='.$lng.'&amp;uuser=new&amp;tconfig='.$tconfig.$z2).'" title="'.$web[160].'">'.$web[160].'</a>&nbsp;]
  </p>';
	$out .= '
</div>';
        }
        else {
            if (empty($prt)) $out = '
<form name="guestbk'.$nbox.'" action="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[14].'-'.TYP_GUESTBK.$z2 : $site['PG'].'.php?lng='.$lng.'&amp;typ='.TYP_GUESTBK.$z2).'" method="post">
  <div class="textCenter">'.SubmitButton($web[41]).'</div>
</form>
<hr />';
            if ($messok) {
                ReadDoc($site[21]);
                $out .= '
<div class="textCenter marginAuto">
  <div class="tbldiv marginAuto width98">
    <div class="trtbldiv">
      <div class="forum tdtbldiv width12">'.$web[39].$fielda1.'</div>
      <div class="quest tdtbldiv width88">'.$web[6].' ';
                if ($fieldd1 == "on") {
					$out .= displayWriteEmail('guest', $author, $email);
                }
                else {
                    $out .= '
        <b>'.$author.'</b>';
                }
                $out .= '
      '.$web[7].' '.FormatDate($creadate);

                if (!empty($fieldb1)) {
                    $out .= '
        <div class="gbkb1'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
          <a href="'.$fieldb1.'" target="'.TYP_BLANK.'" title="">
            <img class="valignMiddle" src="'.$reptheme.'/gbkurl.png" alt="*"/>&nbsp;&nbsp;'.$fieldb1.'
          </a>
        </div>';
                }
                $out .= '
      </div>
    </div>
  </div>
  <div class="tbldiv marginAuto width98">
    <div class="trtbldiv">
      <div class="tdtbldiv textLeft">'.$fieldc1.'</div>
    </div>
  </div>
</div><div class="c-both"></div>';
                if (empty($prt)) $out .= displayQuickConfig($pos, $site[21], 'guestbk&form=2&id='.$site[21], '', '', 22);
            }
        }
        return boxwide($pos, $topmess, $out, ' GBK'.$pos.$tconfig);
    } else {
        return FALSE;
    }
}

################################################################################

function fbox_forum($pos = NULL, $args = NULL) {
    global $lng, $lang, $forum, $members, $nom, $page, $site, $serviz, $userprefs, $web, $urlrw, $tconfig, $reptheme, $z2;
    global $type, $fileid, $status, $creadate, $moddate, $author, $email,
         $fielda1, $fielda2, $fieldb1, $fieldb2, $fieldc1, $fieldc2,
         $fieldd1, $fieldd2, $fieldweb, $fieldmail, $fieldmod;
    if ($serviz[13] == 'on' && $site[20] > 0) {
		$dbworkcat = array();
        $l = $lng == $lang[0] ? 0 : 1;
        if ($serviz[18] == 'on') {
            $dbwork = ReadDBFields(DBFORUMCAT);
            foreach ($dbwork as $dbcat)
                if ($dbcat[5] != '') $dbworkcat[] = $dbcat;
        }
        $dbwork = array();
        $dbwork1 = ReadDBFields(DBTHREAD);
        if ('' == $serviz[18]) {
            foreach ($dbwork1 as $db) {
                if (empty($db[8])) {
                    $dbwork[] = $db;
                }
            }
        } else {
            foreach ($dbwork1 as $db) {
                $dbcat = array();
                if ($db[8] != '') $dbcat = SelectDBFieldsByField($dbworkcat, 0, $db[8]);
                if (isForumAccessGranted($db[8]) && !empty($dbcat)) {
                    $dbwork[] = $db;
                }
            }
        }
        unset($dbwork1);
        @sort($dbwork);
        $dbfor  = ReadDBFields(DBFORUM);
        $dbmess = array();
        $j = 0;
        if (!empty($dbwork)) {
            $newdate = date('YmdHi',time()-(86400*$forum[8]));
            $messtop = '<img class="valign-5" src="'.$reptheme.'/msg_t.gif" alt="'.$web[370].'" title="'.$web[370].'" />';
            $messnew = '<img class="valign-5" src="'.$reptheme.'/msg_n.png" alt="'.$web[371].'" title="'.$web[371].'" />';
            for ($i = count($dbwork)-1; $i >= max(0,count($dbwork)-$site[20]); $i--) {
                ReadDoc($dbwork[$i][3]);
                $img = getNewUpdateDoc($creadate, $moddate, $serviz[139]);
                $dbmess[$j] = array_pad(array(), 10, '');
                if ($fielda2 == '0') {
                    $dbmess[$j][0] = $fileid;
                    $sujet = strip_tags($fieldb1);
                } else {
                    for ($k = 0; $k < count($dbfor); $k++) {
                        if ($fielda1 == $dbfor[$k][1]) {
                            $fieldb2       = $dbfor[$k][12];
                            $dbmess[$j][0] = $dbfor[$k][2];
                            $sujet         = strip_tags($dbfor[$k][5]);
                            $nbrep         = $dbfor[$k][7];
                            $dbmess[$j][7] = $dbwork[$i][2];
                            $dbmess[$j][8] = $dbfor[$k][3];
                        }
                    }
                }
                $dbmess[$j][1] = $fieldb2;
                for ($k = 0; $k < count($dbworkcat); $k++) {
                    if ($dbworkcat[$k][0] == $fieldb2) {
                        $dbmess[$j][2] = $dbworkcat[$k][$l+1];
                    }
                }
                $dbmess[$j][3] = strip_tags(str_replace('<br />', ' &#172; ',$fieldc1));
                $dbmess[$j][4] = FormatDate($creadate).'<br />';
                if ($newdate < $creadate || $newdate < $moddate) {
                    $dbmess[$j][4] = FormatDate($creadate).'<br />'.$messnew.' ';
                }
                if ($moddate != $creadate) {
                    if ($moddate > date('YmdHi')) {
                        $dbmess[$j][4] = FormatDate(date('YmdHi')).'<br />'.$messtop.' ';
                    } elseif ($fieldmod != '') {
                        $datemod       = explode('#',$fieldmod);
                        $dbmess[$j][4] = FormatDate($datemod[2]).'<br />';
                    } else {
                        $dbmess[$j][4] = FormatDate($moddate).'<br />';
                    }
                }
                $dbmess[$j][5] = $img.$sujet;
                $dbmess[$j][6] = (ceil((int)$dbmess[$j][7] / $serviz[20]));
                $dbmess[$j][9] = $author;
                $j++;
            }
        }
        $topmess = getLabel($nom[$l+22]).' '.$web[179];
        if ($page[9] != '') {
            $topmess = '<img class="f-right img32x32" src="'.CHEMIN.'inc/img/icons/'.$page[9].'/forum.gif" alt=""/>'.$topmess;
        }
        if ($members[0] == 'on' && $userprefs[1] == '' && !isAccessGranted($members[5])) {
            $out = '
<div class="textCenter web342">'.$web[342];
	if ($members[19] != '0' && $members[19] != '3') 
		$out .= '
  <p>[&nbsp;
    <a href="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[15].'-5-new-'.$tconfig.$z2 : $site['USR'].'.php?lng='.$lng.'&amp;uuser=new&amp;tconfig='.$tconfig.$z2).'" title="'.$web[160].'">'.$web[160].'</a>&nbsp;]
  </p>';
			$out .= '
</div>';
        } else {
            $out = '';
            if (!empty($dbmess)) {
                $out .= '
<style type="Text/css">
.frcellheight {
  height: '.(empty($site[34]) ? 'auto' : $site[34].'px').';
  min-height: 40px;
  overflow: hidden;
}
</style>
<br />
<div class="textCenter marginAuto">
  <div class="bord tbldiv textCenter width99 frtbldiv">';
                for ($i = 0; $i < count($dbmess); $i++) {
					$dbmess[$i][7] = empty($dbmess[$i][7]) ? 0 : $dbmess[$i][7];
                    $bgcol = $i %2 == 0 ? 'rep' : 'quest';
                    $tmpmess = '
    <div class="'.$bgcol.' trtbldiv valignTop textLeft">';
                    if ($serviz[18] == 'on') {
						$urw = empty($dbmess[$i][1]) ? '-31' : '-2-'.getForumcatId($dbmess[$i][1]);
                        $tmpmess .= '
      <div class="tdtbldiv width22 frtdtbldiv">
        <a href="'.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[5].$urw.$z2 : $site['FR'].'.php?lng='.$lng.'&amp;cat='.getForumcatId($dbmess[$i][1]).$z2).'" title ="'.$web[297].'"><b>'.$dbmess[$i][2].'</b></a>
      </div>';
                    }
					$urw0 = empty($dbmess[$i][1]) ? '-41-'.$dbmess[$i][0] : '-4-'.$dbmess[$i][0].'-'.getForumcatId($dbmess[$i][1]);
					$urw1 = empty($dbmess[$i][1]) ? '-411-'.$dbmess[$i][0] : '-5-'.$dbmess[$i][0].'-'.getForumcatId($dbmess[$i][1]);
                    $tmpmess .= '
      <div class="tdtbldiv width78">
        <div class="tbldiv marginAuto textCenter width100">
          <div class="trtbldiv width100">
            <div class="tdtbldiv textLeft frtdtbldiv">
              <b>'.$web[384].' <a href="'.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[5].$urw0.$z2 : $site['TH'].'.php?lng='.$lng.'&amp;pg='.$dbmess[$i][0].'&amp;cat='.getForumcatId($dbmess[$i][1]).$z2).'" title ="'.$web[6].' '.$dbmess[$i][8].' ... '.$web[297].' ">'.$dbmess[$i][5].'</a></b>
            </div>
          </div>
          <div class="trtbldiv width100">
            <div class="tbldiv width100">
              <div class="trtbldiv textLeft">
                <div class="tdtbldiv width76 frtdtbldiv">';
                    if (TYP_SCREEN == 'MOB') $tmpmess .= '
                  <div class="textCenter"> '.$dbmess[$i][4].' ('.$web[6].' '.$dbmess[$i][9].')</div>';
                    $tmpmess .= '
                  <div class="frcellheight">
                  <a href="'.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[5].$urw1.'-'.$dbmess[$i][6].'#R'.$dbmess[$i][7] : $site['TH'].'.php?lng='.$lng.'&amp;pg='.$dbmess[$i][0].'&amp;cat='.getForumcatId($dbmess[$i][1]).'&amp;id='.$dbmess[$i][6].'#R'.$dbmess[$i][7]).'" title ="'.$web[6].' '.$dbmess[$i][9].' ... '.$web[297].' "> '.$dbmess[$i][3].' ...</a>
                  </div>
                </div>';
                    if (TYP_SCREEN == 'WEB') $tmpmess .= '
                <div class="tdtbldiv textCenter frWtdtbldiv"> '.$dbmess[$i][4].' ('.$web[6].' '.$dbmess[$i][9].')</div>';
                    $tmpmess .= '
              </div>  
            </div>
          </div>
        </div>
      </div>
    </div>';
                    $out .= $tmpmess.'<div class="c-both"></div>';
                }
                $out .= '
  </div>
</div>';
            }
        }
        return boxwide($pos, $topmess, $out, ' FRA'.$pos.$tconfig);
    } else {
        return FALSE;
    }
}

################################################################################

function fbox_poll($pos = NULL, $args = NULL) {
    global $lng, $lang, $nom, $drtuser, $page, $site, $serviz, $userprefs, $web, $dynabox, $urlrw, $tconfig, $charset, $reptheme, $z2;
    if ($serviz[23] != 'on') return FALSE;
    static $nbox = 0;
    $nbox++;
    $commun = PollCalculation();
    if ($lng == $lang[0]) {
        $i = 0;
        $j = 0;
        $txt = empty($commun[0][0])? '': $commun[0][0];
    }
    else {
        $i = 10;
        $j = 1;
        $txt = empty($commun[0][1])? '': $commun[0][1];
    }
	$titre = TYP_SCREEN == 'WEB' ? getLabel($nom[$i+6]) : getLabel($nom[$lng == $lang[0] ? 60 : 61]);
	$titre = mb_substr(trim($titre), 0, 1, $charset) == '§' ? '' : DisplayDownArrow($dynabox[21]).$titre;
    $dbippoll = ReadDbFields(DBIPPOLL);
    $dejaVote = FALSE;
    $now_time = time();
    foreach ($dbippoll as $item) {
        list($jour, $mois, $annee) = explode('/', substr($item[1], 0, 10));
        list($heure, $minute, $seconde) = explode(':', substr($item[1], 10, 18));
        if ($now_time < mktime((int)$heure, (int)$minute, (int)$seconde, (int)$mois, (int)$jour, (int)$annee) + POLL_TIME) {
            if (getIPadress($_SERVER[$site[6] == 'on' ? 'HTTP_X_FORWARDED_FOR' : 'REMOTE_ADDR']) == $item[0]) {
                $dejaVote = TRUE;
                break;
            }
        }
    }
    if ($dejaVote) {
        // déjà voté
        $out = '
<p class="box textCenter textPool">'.$txt.'</p>
<p class="box textCenter lnkPool">
  <a href="'.CHEMIN.($site['URLR'] == 'on'? $lng.'-'.$urlrw[16].'-'.$tconfig.$z2 : 'poll.php?lng='.$lng.'&amp;tconfig='.$tconfig.$z2).'" title="'.$web[10].'">'.$web[10].'</a>
</p>';
    } else {
        // pas encore voté
        $out = '
<form action="'.CHEMIN.($site['URLR'] == 'on'? $lng.'-'.$urlrw[16].'-'.$tconfig.$z2 : 'poll.php?lng='.$lng.'&amp;tconfig='.$tconfig.$z2).'" method="post" name="formV'.$nbox.'">
  <div class="tbldiv textCenter potbldiv">
    <div class="trtbldiv">
      <div class="box tdtbldiv textCenter txt2Pool">'.$txt.'</div>
    </div>';
         for ($k = 1; $k < count($commun); $k++) {
            $out .= '
    <div class="trtbldiv valignTop">
      <div class="tdtbldiv textLeft poChoice'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
	    <label>
		  <input type="radio" name="choix" value="'.$k.'"/>
          <span class="box textLeft poItem">'.$commun[$k][$j].'</span>
		</label>
	  </div>
    </div>';
        }
        $out .= '
    <div class="trtbldiv"><div class="tdtbldiv textCenter lnkPool">'.SubmitButton($web[9]).'</div></div>
    <div class="trtbldiv">
      <div class="tdtbldiv textCenter poLnkResult'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
        <a class="box" href="'.CHEMIN.($site['URLR'] == 'on'? $lng.'-'.$urlrw[16].'-'.$tconfig.$z2 : 'poll.php?lng='.$lng.'&amp;tconfig='.$tconfig.$z2).'" title="'.$web[10].'">'.$web[10].'</a>
      </div>
    </div>
  </div>
</form>';
        $out .= displayQuickConfig($pos, false, 'poll', '', '', 25);
    }
    return '
<div class="'.$pos.$tconfig.'POL">'.boxthin($pos, $titre, $out, ' POL'.$pos.$tconfig, TYP_SCREEN == 'WEB' ? $dynabox[1] : $dynabox[21]).'</div>';
}

################################################################################

function fbox_cal($pos = NULL, $args = NULL) {
    global $lng, $lang, $nom, $drtuser, $page, $serviz, $userprefs, $web, $dynabox, $site, $urlrw, $tconfig, $charset, $reptheme;
    static $nbox = 0;
    $nbox++;
    if ($serviz[47] == 'on') {
		$titre = TYP_SCREEN == 'WEB' ? getLabel($nom[$lng == $lang[0] ? 32 : 33]) : getLabel($nom[$lng == $lang[0] ? 66 : 67]);
		$titre = mb_substr(trim($titre), 0, 1, $charset) == '§' ? '' : DisplayDownArrow($dynabox[24]).$titre;
		$hcal = '190';
        $out = BeginJavascript().'
function getElement(aID) {
    return (document.getElementById) ? document.getElementById(aID) : document.all[aID];
}
function getIFrameDocument(aID){ 
    var rv = null; 
    var frame=getElement(aID);
    if (frame.contentDocument)
      rv = frame.contentDocument;
    else // bad Internet Explorer  ;)
      rv = document.frames[aID].document;
    return rv;
  }
    
function adjustMyFrameHeight() {
	var frame = getElement("calbox'.$nbox.$pos.$tconfig.'");
	var frameDoc = getIFrameDocument("calbox'.$nbox.$pos.$tconfig.'");
	frame.height = frameDoc.body.offsetHeight;
}'.EndJavascript().'
<noscript>';
		$hcal = '240';
		$out .= '
</noscript>
<div class="cal textCenter marginAuto bgInherit">
  <iframe 
    class="cal" 
    id="calbox'.$nbox.$pos.$tconfig.'" 
    src="'.CHEMIN.'inc/'.($site['URLR'] == 'on'? $lng.'-'.$urlrw[17].'-'.$pos.'-'.$tconfig: 'calendar.php?lng='.$lng.'&amp;pos='.$pos.'&amp;tconfig='.$tconfig).'" 
    height="'.$hcal.'">
  </iframe>
</div>
';
        $out   .= displayQuickConfig($pos, false, 'agenda', '', '', 37);
        return '
<div class="'.$pos.$tconfig.'CAL'.$nbox.'">'.boxthin($pos, $titre, $out, ' CAL'.$nbox.$pos.$tconfig, TYP_SCREEN == 'WEB' ? $dynabox[4] : $dynabox[24]).'</div>';
    } else {
        return FALSE;
    }
}

################################################################################

function fbox_newslet($pos = NULL, $args = NULL) {
    global $lng, $lang, $drtuser, $members, $nom, $serviz, $userprefs, $web, $page, $cryptinstall, $dynabox, $site, $urlrw,
           $tconfig, $charset, $reptheme, $z2;
    static $nbox = 0;
    $nbox++;
    if ($members[0] == 'on' && !isAccessGranted($members[18]) && $userprefs[1] == '') {
        return FALSE;
    } else {
		$titre = TYP_SCREEN == 'WEB' ? getLabel($nom[$lng == $lang[0] ? 38 : 39]) : getLabel($nom[$lng == $lang[0] ? 70 : 70]);
		$titre = mb_substr(trim($titre), 0, 1, $charset) == '§' ? '' : DisplayDownArrow($dynabox[26]).$titre;
		if (empty($cryptinstall)) {
			if ($serviz[100] == '1') {
				$cryptinstall = CRYPTREP.'cryptographp.fct.php';
				include_once $cryptinstall;
			} elseif ($serviz[100] == '2') {
				$cryptinstall = CRYPTREP.'cryptotexte.fct.php';
				include_once $cryptinstall;
			}
		}
		// suppression des inscriptions en attente hors délai
		$tmp = ReadDBFields(NEWSLET_WAIT);
		for ($i = 0; $i < count($tmp); $i++) {
			if ((date('Ymd') - $serviz[110]) > substr($tmp[$i][3], 0, 8)) {
				unset($tmp[$i]);
			}
		}
		WriteDBFields(NEWSLET_WAIT, $tmp);
        $nabon = CountDBFields(NEWSLET_LIST);
        $mot   = $nabon < 2 ? $web[257] : $web[258];
        $txt1  = !empty($userprefs[1]) ? $userprefs[1] : $web[259];
        $txt2  = !empty($userprefs[2]) ? $userprefs[2] : $web[260];
        $txt3  = ($nabon == 0)
            ? $mot.'<br />'.sprintf($web[176], $reptheme)
            : $nabon.' '.$mot;
        $txt3 = $serviz[63] == 'on' ? '' : '
<div class="nwl_nabon textCenter">'.$txt3.'</div>';
        if (empty($userprefs[1])) { // non membre
            $out = '
<form class="nwlSubscribe" name="subscribe'.$nbox.'" action="'.CHEMIN.($site['URLR'] == 'on'? $lng.'-'.$urlrw[18].$z2 : $site['NL'].'.php?lng='.$lng.$z2).'" method="post">
  <input type="hidden" name="nlsecure" value="on" />
  <div class="box">
    <div class="textCenter">'.$web[247].'<span class="displayNone"><input type="text" name="code_pseudo" value="" /></span></div>
    <div class="textCenter nwlPseudo'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
      <input class="texte" type="text" name="nlpseudo" size="20" value="'.$txt1.'" onfocus="this.value=\'\'" />
    </div>
    <div class="textCenter nwlMail'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
      <input class="texte" type="text" name="nlmail" size="20" value="'.$txt2.'" onfocus="this.value=\'\'" />
    </div>
    <div class="nwlAction'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
      <label><input type="radio" name="action" value="sub" checked="checked" />'.$web[237].'</label>
    </div>
    <div class="nwlAction'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
      <label><input type="radio" name="action" value="unsub" />'.$web[236].'</label>
    </div>';
            if ($serviz[100] != '0' && $serviz[93] == 'on' && ($userprefs[1] == '' || $serviz[98] == '')) {
				$lbl = $serviz[100] == '3' ? $web[642] : '';
                $out .= '
	<div class="textCenter boxCrypt'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
      '.dsp_crypt(0, 1, 3, 1, $lbl, $serviz[115] == 'on' ? $web[643] : '').'
	  <div class="textCenter marginAuto">
	    '.($serviz[100] == '3' ? '' : $web[530]).'<input class="texte" type="text" name="crypt" size="6" />
	  </div>
	</div>';
            }
            $out .= '
    <div class="textCenter">'.SubmitButton($web[52]).'</div>'.$txt3.'
  </div>
</form>';
        } else {
            $abon = CheckDB2Fields(NEWSLET_LIST, $userprefs[1], 0, $userprefs[2], 1);
            if ($abon) { // abonné
                $out = '
<form class="nwlUnsubscribe" name="unsubscribe'.$nbox.'" action="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[18].$z2 : $site['NL'].'.php?lng='.$lng.$z2).'" method="post">
  <input type="hidden" name="nlsecure" value="on" />
  <input type="hidden" name="action" value="unsub" />
  <input type="hidden" name="nlpseudo" value="'.$userprefs[1].'" />
  <input type="hidden" name="nlmail" value="'.$userprefs[2].'" />
  <div class="box">
    <div class="textCenter">'.$web[500].'<span class="displayNone"><input type="text" name="code_pseudo" value="" /></span></div>';
                if ($serviz[100] != '0' && $serviz[93] == 'on' && $serviz[98] == '') {
					$lbl = $serviz[100] == '3' ? $web[642] : '';
                    $out .= '
	<div class="textCenter boxCrypt'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
	  '.dsp_crypt(0, 1, 3, 1, $lbl, $serviz[115] == 'on' ? $web[643] : '').'
	  <div class="textCenter marginAuto">
	    '.($serviz[100] == '3' ? '' : $web[530]).'<input class="texte" type="text" name="crypt" size="6" />
	  </div>
	</div>';
                }
                $out .= '
    <div class="textCenter">'.SubmitButton($web[236]).'</div>'.$txt3.'
  </div>
</form>';
            } else {
                $tmp = CheckDB2Fields(NEWSLET_WAIT, $userprefs[1], 0, $userprefs[2], 1);
                if ($tmp) { // abonnement en attente de confirmation
                    $out = '
<div class="textCenter">'.$web[501].'</div>'.$txt3;
                } else { // non abonné à la newsletter
                    $out = '
<form class="nwlSubscribe" name="subscribe'.$nbox.'" action="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[18].$z2 : $site['NL'].'.php?lng='.$lng.$z2).'" method="post">
  <input type="hidden" name="nlsecure" value="on" />
  <input type="hidden" name="action" value="sub" />
  <div class="box">
    <div class="textCenter">'.$web[247].'<span class="displayNone"><input type="text" name="code_pseudo" value="" /></div>
    <div class="textCenter nwlPseudo'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
      <input class="texte" type="text" name="nlpseudo" size="20" value="'.$txt1.'" onfocus="this.value=\'\'" />
    </div>
    <div class="textCenter nwlMail'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
      <input class="texte" type="text" name="nlmail" size="20" value="'.$txt2.'" onfocus="this.value=\'\'" />
    </div>';
                    if ($serviz[100] != '0' && $serviz[93] == 'on' && $serviz[98] == '') {
						$lbl = $serviz[100] == '3' ? $web[642] : '';
                        $out .= '
	<div class="textCenter boxCrypt'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
	  '.dsp_crypt(0, 1, 3, 1, $lbl, $serviz[115] == 'on' ? $web[643] : '').'
	  <div class="textCenter marginAuto">
	    '.($serviz[100] == '3' ? '' : $web[530]).'<input class="texte" type="text" name="crypt" size="6" />
	  </div>
	</div>';
                    }
                    $out .= '
    <div class="textCenter">'.SubmitButton($web[237]).'</div>'.$txt3.'
  </div>
</form>';
                }
            }
        }

        $out   .= displayQuickConfig($pos, false, '', '', '', 33);
        return '
<div class="'.$pos.$tconfig.'NWL">'.boxthin($pos, $titre, $out, ' NWL'.$pos.$tconfig, TYP_SCREEN == 'WEB' ? $dynabox[6] : $dynabox[26]).'</div>';
    }
}

################################################################################

function fbox_socnet($pos = NULL, $args = NULL) {
    global $lng, $lang, $drtuser, $serviz, $userprefs, $web, $page, $nom, $site, $urlrw, $tconfig, $charset, 
		$status, $fieldb1, $fieldb2, $fieldc1, $fieldc2, $fieldd1, $fieldd2, $dynabox, $meskin, $reptheme, $z2;
    $dbnet = ReadDBFields(DBSOCNET);
	@sort($dbnet);
	$reprs = is_dir($meskin.'rsicons') ? $meskin.'rsicons' : CHEMIN.'img';
    $out = '';
	if ($serviz[22] == 'on' && ($serviz[16] == 'on' || $serviz[54] == 'on' || $serviz[60] == 'on' || $serviz[103] == 'on')) {
		$out .= '
<div class="f-left textCenter marginAuto rssSocnet">
  <a href="'.CHEMIN.($site['URLR'] == 'on'? $lng.'-'.$urlrw[19].$z2 : 'rss.php?lng='.$lng.$z2).'" title="'.$web[617].'">
    <img src="'.$reprs.'/rssicon.png" alt="'.$web[617].'" title="'.$web[617].'" />
  </a>
</div>';
	}
    for ($j = 0; $j < count($dbnet); $j++) {
		ReadDoc($dbnet[$j][4]);
		if ($status == 'a') {
			$out .= '
<div class="f-left textCenter iconSocnet'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">';
			if ($fieldd2 != '') {
				$out .= $fieldd2;
			} else {
				if (trim($fieldd1) != '') {
					if (strtoupper($fieldc1) == '_POPUP') {
						$out .= '
  <a href="" onclick="PopupWindow(\''.$fieldd1.'\', \'sn'.$j.'\', 1024, 768, \'yes\', \'yes\');" title="'.(strip_tags($fieldb1)).'">';
					} else {
						$out .= '
  <a href="'.$fieldd1.'" target="'.strtolower($fieldc1).'" title="'.(strip_tags($fieldb1)).'">';
					}
				}
				$out .= '
    <img src="'.$reprs.'/'.$fieldc2.'" alt="'.(strip_tags($fieldb1)).'" />';
				if (trim($fieldd1) != '') 
					$out .= '
  </a>';
			}
			$out .= '
</div>';
		}
    }
	$out .= '
<div class="c-both"></div>';
    $out .= displayQuickConfig($pos, false, 'socnet', '', '', 50);
	$titre = TYP_SCREEN == 'WEB' ? getLabel($nom[$lng == $lang[0] ? 48 : 49]) : getLabel($nom[$lng == $lang[0] ? 76 : 77]);
	if (in_array($pos, array(BOX_TOP, BOX_BOTTOM))) {
		return '<div class="boxnet NET'.$pos.$tconfig.'">'.$out.'</div>';
	} else {
		if (in_array($pos, array(BOX_LEFT, BOX_RIGHT))) {
            $titre = mb_substr(trim($titre), 0, 1, $charset) == '§' ? '' : DisplayDownArrow($dynabox[29]).$titre;
			return '
<div class="'.$pos.$tconfig.'NET">'.boxthin($pos, $titre, $out, ' NET'.$pos.$tconfig, TYP_SCREEN == 'WEB' ? $dynabox[9] : $dynabox[29]).'</div>';
		} else {
            $titre = mb_substr(trim($titre), 0, 1, $charset) == '§' ? '' : $titre;
			return boxwide($pos, $titre, $out, ' NET'.$pos.$tconfig);
		}
	}
}

################################################################################

function fbox_rss($pos = NULL, $args = NULL) {
    global $lng, $lang, $drtuser, $nom, $serviz, $userprefs, $web, $page, $dynabox, $site, 
         $urlrw, $tconfig, $charset, $reptheme, $z2;
    global $type, $fileid, $status, $creadate, $moddate, $author, $email,
         $fielda1, $fielda2, $fieldb1, $fieldb2, $fieldc1, $fieldc2,
         $fieldd1, $fieldd2, $fieldweb, $fieldmail, $fieldmod;
    $dbrss = ReadDBFields(DBRSS);
    sort($dbrss);
    $out = '';
    $i = $lng == $lang[0] ? 0 : 1;
	$titre = TYP_SCREEN == 'WEB' ? getLabel($nom[36 + $i]) : getLabel($nom[$lng == $lang[0] ? 72 : 73]);
	$titre = mb_substr(trim($titre), 0, 1, $charset) == '§' ? '' : DisplayDownArrow($dynabox[27]).$titre;
    for ($j = 0; $j < count($dbrss); $j++) {
        Readdoc($dbrss[$j][4]);
        $tconf = empty($fieldweb) ? 0 : ($fieldweb == 'ALL' ? $tconfig : $fieldweb);
        $out .= '
<div class="textCenter itemRssBox'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
  <a class="box" href="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[19].'-2-'.$dbrss[$j][4].'-'.$tconf.$z2 : 'newsrss.php?lng='.$lng.'&amp;id='.$dbrss[$j][4].'&amp;tconfig='.$tconf.$z2).'">'.$dbrss[$j][$i].'</a>
</div>';
    }
    $out   .= displayQuickConfig($pos, false, 'rss', '', '', 34);
    return '
<div class="'.$pos.$tconfig.'RSS">'.boxthin($pos, $titre, $out, ' RSS'.$pos.$tconfig, TYP_SCREEN == 'WEB' ? $dynabox[7] : $dynabox[27]).'</div>';
}

################################################################################

function fbox_news($pos = NULL, $args = NULL) {
    global $id, $pg, $lng, $lang, $drtuser, $members, $nom, $page, $site, $serviz, $user, $userprefs, $web, 
	     $topmess, $prt, $urlrw, $tconfig, $reptheme, $charset, $z2;
    global $type, $fileid, $status, $creadate, $moddate, $author, $email,
         $fielda1, $fielda2, $fieldb1, $fieldb2, $fieldc1, $fieldc2,
         $fieldd1, $fieldd2, $fieldweb, $fieldmail, $fieldmod;
    if ($serviz[8] != 'on') return FALSE;
    static $nbox = 0;
    $nbox++;
    $out = '';
    $id  = strip_tags($id);
    $max_height  = isset($site[29]) && $site[29] > 0 && empty($prt) ? $site[29] : 0;
    $max_height2 = isset($site[13]) && $site[13] > 0 && empty($prt) ? $site[13] : 0;
    if ($members[0] == 'on' && $userprefs[1] == '' && !isAccessGranted($members[13])) {
    	$out .= '
<div class="textCenter web342">'.$web[342];
	if ($members[19] != '0' && $members[19] != '3') 
		$out .= '
  <p>[&nbsp;
    <a href="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[15].'-5-new-'.$tconfig.$z2 : $site['USR'].'.php?lng='.$lng.'&amp;uuser=new&amp;tconfig='.$tconfig.$z2).'" title="'.$web[160].'">'.$web[160].'</a>&nbsp;]
  </p>';
	$out .= '
</div>';
    } else {
		$outrs = '';
		if ($prt == 0 && $serviz[106] == 'on') {
			include CONFIGREP.'sncode.inc';
			if (!empty($coders))
				$outrs .= '
<div class="codersNews">'.$coders.'</div>';
		}
		if ($pos != BOX_EDITO) {
			$archdate = ReadCounter(DBNEWSARCHDATE);
			if ($archdate > 0) {
				$out .= '
<div class="textCenter archNews">'.$web[580].' '.FormatDate($archdate).'
  <br />'.$web[579].' <a href="'.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[8].'-26'.$z2 : 'newsarch.php?lng='.$lng.$z2).'" title="'.$web[578].'">'.$web[578].'
  <img src="'.$reptheme.'/ed_copy.png" alt="" /></a>
</div>';
			}
		}
		$out .= '
<div class="headNews textCenter">';
		if ($serviz[16] == 'on' && TYP_SCREEN == 'WEB' && empty($prt)) {
			$rssnewsurl = $site[3].sprintf(RSSNEWS, $lng);
			$out .= '
  <span class="pop popRss">
    <a href="'.$rssnewsurl.'" target="'.TYP_BLANK.'">
      <img src="'.CHEMIN .$reptheme.'/rssguppy.png" alt="rss" />
      <span><em></em>'.$web[221].':<br /><b> '.$rssnewsurl.'</b></span>
    </a>
  </span><span class="c-left"></span>';
		}
		if ($site[5] != '2' && empty($prt)) {
			$out .= '
  <form name="postnews'.$nbox.'" action="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[14].'-'.TYP_NEWS.$z2 : $site['PG'].'.php?lng='.$lng.'&amp;typ='.TYP_NEWS.$z2).'" method="post">
    <input type="hidden" name="tconfig" value="'.$tconfig.'" />
    <div class="textCenter'.($serviz[16] == 'on' && TYP_SCREEN == 'WEB' ? ' postNews' : '').'">'.SubmitButton($web[4]).'</div>
  </form>';
		} else
			$out .= '<div class="divnewline"></div>';
		$out .= '
</div>';
		if (!empty($pg)) {
			$db1 = SelectDbFieldsByField(ReadDbFields(DBNEWS), 4, $pg);
			$db2 = array_filter($db1, 'IsNotEmptyTitle');
			if (empty($db2) || 1 != count($db2)) {
                if ($site[10] != '')
                    header('location:'.$site[3].'error.php?lng='.$lng.'&err=404');
                else
                    header('HTTP/1.0 404 Not Found');
                exit;
			} else {
                if (isAccessGranted($db2[0][6]) && isAuthorizedPublication($db2[0][5]))
                    $dbwnews = array(array(TYP_NEWS, $db2[0][5], $pg, 'a'));
                else
                    $dbwnews = array();
			}
		} else {
			$db1 = ReadDbFields(DBNEWS);
			$db2 = array_filter($db1, 'IsNotEmptyTitle');
			$dbwnews = array();
			foreach ($db2 as $db) {
				if (isAccessGranted($db[6]) && isAuthorizedPublication($db[5])) {
					$dbwnews[] = array(TYP_NEWS, $db[5], $db[4], 'a');
				}
			}
			@rsort($dbwnews);
		}
		unset($db1, $db2);
		if ($pos == BOX_EDITO) { // edito
			$minnews = 0;
			$maxnews = Min($site[4], count($dbwnews));
			$id = 1;
		}
		else { // news
			$id = empty($id) ? 1 : $id;
			$minnews = $serviz[2]*($id-1);
			$maxnews = Min($serviz[2]*$id, count($dbwnews));
		}
		if (!empty($dbwnews)) {
			for ($i = $minnews; $i < $maxnews; $i++) {
				ReadDoc($dbwnews[$i][2]);
				$img = getNewUpdateDoc($creadate, $moddate, $serviz[137]);
				if ($lng == $lang[0]) {
					$txt1 = $fieldb1;
					$txt2 = $fieldc1;
				}
				else {
					$txt1 = $fieldb2;
					$txt2 = $fieldc2;
				}
				$txt2 .= $outrs;
				// date création
				if ($serviz[73] == '') {
					$txt73 = ' - '.$web[6].' ';
					if ($fieldd1 == 'on') {
						$txt73 .= displayWriteEmail('boxnews'.$i, $author, $email);
					} else {
						$txt73 .= '
    <b>'.$author.'</b> ';
					}
				} else {
					$txt73 = '';
				}
				// auteur
				if ($serviz[72] == '') {
					$txt72 = (empty($txt73) ? ' - ' : ' ').$web[7].' '.FormatDate($creadate);
				} else {
					$txt72 = '';
				}
				// icone
				if (!empty($fieldd2)) {
					$txt1 = '<img src="'.CHEMIN.'img/'.$fieldd2.'" class="'.($serviz[152] == 'on' ? 'f-left' : 'f-right').'" alt="'.$fieldd2.'" />'.$txt1;
				}
				$out .= '
  <div class="bord">
    <div class="quest '.($serviz[152] != 'on' ? 'textLeft' : 'textRight').'">
	  <a href="'.$site[3].($site['URLR'] == 'on' ? $lng.'-'.$urlrw[8].'-22-'.$fileid.'-'.$tconfig.$z2 : $site['NE'].'.php?lng='.$lng.'&amp;pg='.$fileid.'&amp;tconfig='.$tconfig.$z2).'" title="'.$web[511].'">
        '.$img.'<b>'.$txt1.'</b>
      </a>'.(TYP_SCREEN == 'WEB' ? '' : '<br />').$txt73.$txt72.'
    </div>';
				if ($pos == BOX_EDITO) { // edito : nouvelle réduite
					$txt3 = '
    <a id="news'.$pos.$i.'"></a>
<style type="text/css">
.repNews {
  height: '.($max_height > 0 ? $max_height.'px;' : 'auto;').'
  overflow: '.($max_height > 0 ? 'hidden;' : 'visible;').'
  background: transparent;
}
</style>';
					if (!empty($txt2)) {
						$txt3 .= '
    <div id="texte3'.$i.'" class="rep editoNews">
      <div class="rep repNews">
        '.$txt2.'
      </div><div class="c-both"></div>';
                        if ($max_height > 0) $txt3 .= '
      <p class="textRight">
        <a href="javascript:ActiveMenu(\'texte3\',\'texte2\',0,'.$maxnews.','.$i.')" class="box" title="'.$web[296].'">
          '.$web[296].' <img src="'.$reptheme.'/plus.png" alt="'.$web[296].'" />
        </a>
      </p>';
                        $txt3 .= '
    </div>' ;
                        if ($max_height > 0) $txt3 .= '
    <div id="texte2'.$i.'" class="rep displayNone txt2News">'.$txt2.'
      <p class="textRight clsCursor">
        <a href="#news'.$pos.$i.'" title="'.$web[57].'" onclick="cache(\'texte2'.$i.'\');montre(\'texte3'.$i.'\')">
          '.$web[57].' <img src="'.$reptheme.'/minus.png" alt="'.$web[57].'" />
        </a>
      </p>
    </div><div class="c-both"></div>';
					}
                    $out .= $txt3;
				} else { // news : nouvelle complète
					$txt3 = '
    <a id="news'.$pos.$i.'"></a>
<style type="text/css">
.repNews2 {
  height: '.($max_height2 > 0 ? $max_height2.'px;' : 'auto;').'
  overflow: '.($max_height2 > 0 ? 'hidden;' : 'visible;').'
  background: transparent;
}
</style>';
					if (!empty($txt2)) {
						$txt3 .= '
    <div id="texte3'.$i.'" class="rep fullNews">
      <div class="rep repNews2">
        '.$txt2.'
      </div><div class="c-both"></div>';
                    if ($max_height2 > 0) $txt3 .= '
      <p class="textRight">
        <a href="javascript:ActiveMenu(\'texte3\',\'texte2\',0,'.$maxnews.','.$i.')" class="box" title="'.$web[296].'">
          '.$web[296].' <img src="'.$reptheme.'/plus.png" alt="'.$web[296].'" />
        </a>
      </p>';
				$txt3 .= '
    </div>' ;
                    if ($max_height2 > 0) $txt3 .= '
    <div id="texte2'.$i.'" class="rep displayNone txt2News">'.$txt2.'
      <p class="textRight clsCursor">
        <a href="#news'.$pos.$i.'" title="'.$web[57].'" onclick="cache(\'texte2'.$i.'\');montre(\'texte3'.$i.'\')">
          '.$web[57].' <img src="'.$reptheme.'/minus.png" alt="'.$web[57].'" />
        </a>
      </p>
    </div><div class="c-both"></div>';
					}
                    $out .= $txt3;
				}
                $out .= displayQuickConfig($pos, $dbwnews[$i][2], 'news&amp;form=2&amp;id='.$dbwnews[$i][2], 'news&amp;act=i&amp;id='.$dbwnews[$i][2], 'news&amp;del='.$dbwnews[$i][2], 14);
				$out .= '
  </div>
  <br />';
			}
		} elseif (!empty($pg)) {
			$out .= '
  <p>'.$web[36].'</p>';
		}
		$pg = empty($pg)? '0': $pg;
		if ($pos != BOX_EDITO) { // news
			$out .= GetNavBar(($site['URLR'] == 'on'? $lng.'-'.$urlrw[8].'-3-'.$pg.'-': $site['NE'].'.php?lng='.$lng.'&amp;pg='.$pg.'&amp;id='), count($dbwnews), $id, $serviz[2], $z2);
		}
    }
    if ($pos != BOX_EDITO) {
        $topmess = getLabel($nom[$lng == $lang[0] ? 7 : 17]);
        $class   = ' NEW'.$tconfig;
    } else {
        if (count($dbwnews) > 1 && $site[4] > 1) {
            $topmess = sprintf($web[2], min($site[4], count($dbwnews)));
        } else {
            $topmess = $web[145];
        }
        $class = ' NEW'.$pos.$tconfig;
    }
    if ($page[9] != '') {
        $topmess = '<img src="'.CHEMIN.'inc/img/icons/'.$page[9].'/news.gif" class="f-right img32x32" alt="" />'.$topmess;
    }
    return $pos == BOX_EDITO && $maxnews == 0 ? false : boxwide($pos, $topmess, $out, $class);
}

################################################################################

function fbox_lastdoc($pos = NULL, $args = NULL) {
    global $lng, $lang, $nom, $page, $serviz, $site, $userprefs, $web, $urlrw, $tconfig, 
	       $charset, $reptheme, $drtuser, $dynabox, $members, $z2;
    global $type, $fileid, $status, $creadate, $moddate, $author, $email,
         $fielda1, $fielda2, $fieldb1, $fieldb2, $fieldc1, $fieldc2,
         $fieldd1, $fieldd2, $fieldweb, $fieldmail, $fieldmod;
	if ((TYP_SCREEN == 'WEB' ? $serviz[116] : $serviz[161]) != 'on') return false;
	if ((TYP_SCREEN == 'WEB' ? $serviz[117].$serviz[118] : $serviz[162].$serviz[163]) == '') return false;
    static $nbox = 0;
    $nbox++;
    $out   = '';
    $ndays = 0;
    if (TYP_SCREEN == 'WEB' && $serviz[118] == 'on') $ndays = !empty($serviz[119]) && is_numeric($serviz[119]) ? $serviz[119] : '15';
    if (TYP_SCREEN == 'MOB' && $serviz[163] == 'on') $ndays = !empty($serviz[164]) && is_numeric($serviz[164]) ? $serviz[164] : '15';
	if (($serviz[118] == 'on' || $serviz[163] == 'on') && $ndays > 0) $dat = date('YmdHi', strtotime($ndays.' days ago'));
    if ((TYP_SCREEN == 'WEB' && $serviz[117] == 'on') || (TYP_SCREEN == 'MOB' && $serviz[162] == 'on')) {
        if ($userprefs[1] != '') $dat = !empty($userprefs[14]) ? $userprefs[14] : date('YmdHi');
        else $dat = date('YmdHi');
    }
	$db    = $dba = $dbb = array();
	$docid = SelectDBFieldsByStatus(ReadDBFields(DOCID), 'a');
	$dbdat = ReadDBFields(DOCDATES);
	foreach ($dbdat as $item) if ($item[2] >= $dat) $db[] = array($item[2], $item[0]);
	rsort($db);
	$dbag = $dbag2 = $dbar = $dbra = $dbom = $dbbl = $dbrb = $dbdn = $dbfa = $dbfr = $dbli = $dbgb = $dbne = $dbph = array();
	foreach ($db as $item) {
		$typ    = SelectDBFieldsByField($docid, 1, $item[1]);
		$idat   = (TYP_SCREEN == 'WEB' && $serviz[169] == 'on') || (TYP_SCREEN == 'MOB' && $serviz[170] == 'on') ? '' : substr(FormatDate($item[0]), 0, 10).' :';
		$typdoc = empty($typ[0][0]) ? '' : $typ[0][0];
		switch ($typdoc) {
		case 'ag' : // agenda
            $zmbr = $members[0] == 'on' && $userprefs[1] == '' && !isAccessGranted($members[14]) ? true : false;
			if ($serviz[121] == 'on' && !$zmbr) {
				ReadDoc($item[1]);
				if (isAuthorizedPublication($creadate) && isAccessGranted($fieldmod) && $status == 'a') {
					$url0 = 'agenda.php?lng='.$lng.'&amp;idpg='.$fileid.'-'.'&amp;pg='.$item[0].'&amp;agv=1&amp;tconfig='.$tconfig.$z2;
					$url1 = $lng.'-'.$urlrw[17].'-22-'.$fileid.'--'.$fileid.'-1-'.$tconfig.$z2;
					$link = $idat.' <a href="'.CHEMIN.($site['URLR'] == 'on' ? $url1 : $url0).'" target="_self" title="">'.FormatDate(substr($fielda1, 0, 8)).' - '.CutLongWord(strip_tags($lng == $lang[0] ? $fieldc1 : $fieldc2), 36).'...</a>';
					$dbag[]  = array($nom[$lng == $lang[0] ? 32 : 33], $link);
                    $dbag2[] = $fielda1;
				}
			}
			break;
		case 'ar' : // articles
   		case 'ra' : // réactions articles
            $zmbr = $members[0] == 'on' && $userprefs[1] == '' && !isAccessGranted($members[1]) ? true : false;
            $id = false;
            if ($typdoc == 'ra' && $serviz[29] != '2' && $serviz[166] == 'on' && !$zmbr) {
                $dbw = SelectDBFieldsByField(ReadDBFields(DBREACT), 0, $item[1]);
                $id  = $dbw[0][1];
            }
            if ($typdoc == 'ar' && $serviz[122] == 'on' && !$zmbr) {
                $id = $item[1];
            }
            if ($id) {
                ReadDoc($id);
                if (isAuthorizedPublication($creadate) && isAccessGranted($fieldmod) && $status == 'a') {
                    $fa1  = $fielda1;
                    $fa2  = $fielda2;
                    $fb1  = $fieldb1;
                    $fb2  = $fieldb2;
                    $dbwo = ReadDBFields(DBOPTMENU);
                    $url0 = 'articles.php?lng='.$lng.'&pg='.$id.'&tconfig='.$fieldmail.$z2;
                    $url1 = $lng.'-'.$urlrw[20].'-102-'.$id.'-'.$fieldmail.$z2;
                    foreach ($dbwo as $item1) {
                        ReadDoc($item1[4]);
                        if (!isAuthorizedPublication($creadate) || !isAccessGranted($fieldmod) || $status != 'a') continue;
                        $urls = explode('||', $lng == $lang[0] ? $fieldd1 : $fieldd2);
                        $pg   = substr($urls[0], strpos($urls[0], 'pg=') + 3);
                        $pos1 = strpos($pg, '&');
                        $pg   = $pos1 === false ? $pg : substr($pg, 0, $pos1);
                        if ($pg == $id) {
                            $fa1  = $fielda1;
                            $fa2  = $fielda2;
                            $fb1  = $fieldb1;
                            $fb2  = $fieldb2;
                            $url0 = 'articles.php?lng='.$lng.'&pg='.$pg.'&mnuid='.$item1[5].'&tconfig='.$fieldmail.$z2;
                            $url1 = $lng.'-'.$urlrw[20].'-103-'.$pg.'-'.$item1[5].'-'.$fieldmail.$z2;
                            break;
                        }
                    }
                    $link = $idat.' <a href="'.CHEMIN.($site['URLR'] == 'on' ? $url1 : $url0).'" target="_self" title="">'.strip_tags($lng == $lang[0] ? $fa1 : $fa2).' - '.strip_tags($lng == $lang[0] ? $fb1 : $fb2).'</a>';
                    if ($typdoc == 'ar') {
                        $dbar[] = array($web[169], $link); 
                        $dba[]  = $id;
                    }
                    if ($typdoc == 'ra') {
                        $dbra[] = array($web[187], $link); 
                        $dba[]  = $id;
                    }
                }
            }
            break;
		case 'om' : // options de menu indépendantes des services
			if ($serviz[154] == 'on') {
				ReadDoc($item[1]);
                $targets = array('agenda', 'articles', 'blog', 'download', 'faq', 'links', 'guestbk', 'thread', 'news', 'photorama2');
                $isValid = true;
                foreach($targets as $target) if (strpos($fieldd1, $target.'.php') === true) $isValid = false;
				if (isAuthorizedPublication($creadate) && isAccessGranted($fieldmod) && $status == 'a' && $isValid) {
                    $fa1  = $fielda1;
                    $fa2  = $fielda2;
                    $fb1  = $fieldb1;
                    $fb2  = $fieldb2;
                    $urls = explode('||', $lng == $lang[0] ? $fieldd1 : $fieldd2);
                    if (empty($urls[1])) $urls[1] = $urls[0];
					$link = $idat.' <a href="'.CHEMIN.($site['URLR'] == 'on' ? $urls[1].$z2 : $urls[0].$z2).'" target="_self" title="">'.strip_tags($lng == $lang[0] ? $fa1 : $fa2).' - '.strip_tags($lng == $lang[0] ? $fb1 : $fb2).'</a>';
					$dbom[] = array($web[448], $link);
				}
			}
			break;
		case 'bl' : // blog et commentaires
		case 'rb' : 
            $zmbr = $members[0] == 'on' && $userprefs[1] == '' && !isAccessGranted($members[15]) ? true : false;
            $id = false;
            if ($typdoc == 'rb' && $serviz[57] != '2' && $serviz[167] == 'on' && !$zmbr) {
                $dbw = SelectDBFieldsByField(ReadDBFields(DBREBLOG), 0, $item[1]);
                $id  = $dbw[0][1];
            }
            if ($typdoc == 'bl' && $serviz[123] == 'on' && !$zmbr) {
                $id = $item[1];
            }
            if ($id) {
                ReadDoc($id);
				if (isAuthorizedPublication($creadate) && isAccessGranted($fieldmod) && $status == 'a') {
                    $url0 = $site['BL'].'.php?lng='.$lng.'&amp;sel=pg&amp;pg='.$fileid.$z2;
                    $url1 = $lng.'-'.$urlrw[1].'-2-pg-'.$fileid.$z2;
                    $link = $idat.' <a href="'.CHEMIN.($site['URLR'] == 'on' ? $url1 : $url0).'" target="_self" title="">'.strip_tags($lng == $lang[0] ? $fielda1 : $fielda2).' - '.strip_tags($lng == $lang[0] ? $fieldb1 : $fieldb2).'</a>';
                    if ($typdoc == 'bl') {
                        $dbbl[] = array($nom[$lng == $lang[0] ? 42 : 43], $link); 
                        $dbb[]  = $id;
                    }
                    if ($typdoc == 'rb') {
                        $dbrb[] = array($web[407].' '.strtolower($nom[$lng == $lang[0] ? 42 : 43]), $link);
                        $dbb[]  = $id;
                    }
				}
			}
			break;
		case 'dn' : // téléchargements
            $zmbr = $members[0] == 'on' && $userprefs[1] == '' && !isAccessGranted($members[7]) ? true : false;
			if ($serviz[124] == 'on' && !$zmbr) {
				ReadDoc($item[1]);
				if (isAuthorizedPublication($creadate) && isAccessGranted($fieldmod) && $status == 'a') {
					$url0 = $site['DN'].'.php?lng='.$lng.'&amp;pg='.$fileid.'&amp;tconfig='.$tconfig.$z2;
					$url1 = $lng.'-'.$urlrw[11].'-4-'.$fileid.'-'.$tconfig.$z2;
					$link = $idat.' <a href="'.CHEMIN.($site['URLR'] == 'on' ? $url1 : $url0).'" target="_self" title="">'.strip_tags($lng == $lang[0] ? $fielda1 : $fielda2).' - '.strip_tags($lng == $lang[0] ? $fieldb1 : $fieldb2).'</a>';
					$dbdn[] = array($nom[$lng == $lang[0] ? 1 : 11], $link);
				}
			}
			break;
		case 'fa' : // faq
            $zmbr = $members[0] == 'on' && $userprefs[1] == '' && !isAccessGranted($members[4]) ? true : false;
			if ($serviz[125] == 'on' && !$zmbr) {
				ReadDoc($item[1]);
				if (isAuthorizedPublication($creadate) && isAccessGranted($fieldmod) && $status == 'a') {
					$url0 = 'faq.php?lng='.$lng.'&amp;pg='.$fileid.'&amp;tconfig='.$tconfig.$z2;
					$url1 = $lng.'-'.$urlrw[4].'-6-'.$fileid.'-'.$tconfig.$z2;
					$link = $idat.' <a href="'.CHEMIN.($site['URLR'] == 'on' ? $url1 : $url0).'" target="_self" title="">'.strip_tags($lng == $lang[0] ? $fielda1 : $fielda2).' - '.strip_tags($lng == $lang[0] ? $fieldb1 : $fieldb2).'</a>';
					$dbfa[] = array($nom[$lng == $lang[0] ? 24 : 25], $link);
				}
			}
			break;
		case 'fr' : // forum
            $zmbr = $members[0] == 'on' && $userprefs[1] == '' && !isAccessGranted($members[5]) ? true : false;
			if ($serviz[126] == 'on' && !$zmbr) {
				ReadDoc($item[1]);
				$dbw  = SelectDBFieldsByField(ReadDBFields(DBFORUM), 1, $fielda1);
				$fid  = $dbw[0][2];
				$urw0 = empty($fieldb2) ? '-41-'.$fid : '-4-'.$fid.'-'.getForumcatId($fieldb2);
				$urw1 = empty($fieldb2) ? '-411-'.$fid : '-5-'.$fid.'-'.getForumcatId($fieldb2);
				$url0 = $site['TH'].'.php?lng='.$lng.'&amp;pg='.$fid.'&amp;cat='.getForumcatId($fieldb2).($fielda2 == '0' ? '' : '&amp;id=1#R'.$fielda2);
				$url1 = $lng.'-'.$urlrw[5].($fielda2 == '0' ? $urw0.$z2 : $urw1.'-1#R'.$fielda2);
				$lbl0 = ($fielda2 == '0' ? 'S' : 'R').$fielda1;
				$lbl1 = $fielda2 == '0' ? $fieldb1 : CutLongWord(strip_tags($fieldc1), 36).'...';
				$link = $idat.' <a href="'.CHEMIN.($site['URLR'] == 'on' ? $url1 : $url0).'" target="_self" title="">'.$lbl0.' - '.strip_tags($lbl1).'</a>';
				$dbfr[] = array($nom[$lng == $lang[0] ? 22 : 23], $link);
			}
			break;
		case 'li' : // liens
            $zmbr = $members[0] == 'on' && $userprefs[1] == '' && !isAccessGranted($members[3]) ? true : false;
			if ($serviz[127] == 'on' && !$zmbr) {
				ReadDoc($item[1]);
				if (isAuthorizedPublication($creadate) && isAccessGranted($fieldmod) && $status == 'a') {
					$url0 = 'links.php?lng='.$lng.'&amp;pg='.$fileid.'&amp;tconfig='.$tconfig.$z2;
					$url1 = $lng.'-'.$urlrw[6].'-5-'.$fileid.'-'.$tconfig.$z2;
					$link = $idat.' <a href="'.CHEMIN.($site['URLR'] == 'on' ? $url1 : $url0).'" target="_self" title="">'.strip_tags($lng == $lang[0] ? $fielda1 : $fielda2).' - '.strip_tags($lng == $lang[0] ? $fieldb1 : $fieldb2).'</a>';
					$dbli[] = array($nom[$lng == $lang[0] ? 3 : 13], $link);
				}
			}
			break;
		case 'gb' : // livre d'or
            $zmbr = $members[0] == 'on' && $userprefs[1] == '' && !isAccessGranted($members[12]) ? true : false;
			if ($serviz[128] == 'on' && !$zmbr) {
				ReadDoc($item[1]);
				$url0 = $site['GB'].'.php?lng='.$lng.'&amp;pg='.$fileid.'&amp;tconfig='.$tconfig.$z2;
				$url1 = $lng.'-'.$urlrw[7].'-4-'.$fileid.'-'.$tconfig.$z2;
				$link = $idat.' <a href="'.CHEMIN.($site['URLR'] == 'on' ? $url1 : $url0).'" target="_self" title="">'.$author.' - '.CutLongWord(strip_tags($fieldc1), 36).'...</a>';
				$dbgb[] = array($nom[$lng == $lang[0] ? 9 : 19], $link);
			}
			break;
		case 'ne' : // nouvelles
            $zmbr = $members[0] == 'on' && $userprefs[1] == '' && !isAccessGranted($members[13]) ? true : false;
			if ($serviz[129] == 'on' && !$zmbr) {
				ReadDoc($item[1]);
				if (isAuthorizedPublication($creadate) && isAccessGranted($fieldmod)) {
					$url0 = $site['NE'].'.php?lng='.$lng.'&amp;pg='.$fileid.'&amp;tconfig='.$tconfig.$z2;
					$url1 = $lng.'-'.$urlrw[8].'-22-'.$fileid.'-'.$tconfig.$z2;
					$link = $idat.' <a href="'.CHEMIN.($site['URLR'] == 'on' ? $url1 : $url0).'" target="_self" title="">'.strip_tags($lng == $lang[0] ? $fielda1 : $fielda2).' - '.strip_tags($lng == $lang[0] ? $fieldb1 : $fieldb2).'</a>';
					$dbne[] = array($nom[$lng == $lang[0] ? 7 : 17], $link);
				}
			}
			break;
		case 'ph' : // photos
            $zmbr = $members[0] == 'on' && $userprefs[1] == '' && !isAccessGranted($members[2]) ? true : false;
			if ($serviz[130] == 'on' && $zmbr === false) {
                ReadDoc($item[1]);
                if (isAuthorizedPublication($creadate) && isAccessGranted($fieldmod) && $status == 'a') {
                    $url0 = 'photorama2.php?lng='.$lng.'&amp;pg='.$fileid.'&amp;tconfig='.$tconfig.$z2;
                    $url1 = $lng.'-'.$urlrw[9].'-2-'.$fileid.'-'.$tconfig.$z2;
                    $link = $idat.' <a href="'.CHEMIN.($site['URLR'] == 'on' ? $url1 : $url0).'" target="_self" title="">'.strip_tags($lng == $lang[0] ? $fielda1 : $fielda2).' - '.strip_tags($lng == $lang[0] ? $fieldb1 : $fieldb2).'</a>';
                    $dbph[] = array($nom[$lng == $lang[0] ? 2 : 12], $link);
                }
			}
			break;
		}
	}
	unset($db);
    if (!empty($dbag)) $cr = array_multisort($dbag2, SORT_ASC, $dbag);
	$dbw = array($dbag, $dbar, $dbra, $dbom, $dbbl, $dbrb, $dbdn, $dbfa, $dbfr, $dbli, $dbgb, $dbne, $dbph);
	foreach ($dbw as $db) {
		if (!empty($db)) {
			$out .= '
	<fieldset><legend>'.$db[0][0].'</legend>';
			foreach ($db as $item) {
				$out .= '
	  <div'.($pos == 'NWL' ? ' style="padding:4px 0;"' : (TYP_SCREEN == 'MOB' ? ' class="itemLastdoc"' : '')).'>'.$item[1].'</div>';
			}
			$out .= '
	</fieldset>';
		}
	}
	unset($dbag, $dbar, $dbra, $dbom, $dbbl, $dbrb, $dbdn, $dbfa, $dbfr, $dbli, $dbgb, $dbne, $dbphn, $dbw);
	if ($out != '') {
		$sidebox    = $pos == BOX_LEFT || $pos == BOX_RIGHT;
		$titre      = TYP_SCREEN == 'WEB' ? getLabel($nom[$lng == $lang[0] ? 54 : 55]) : getLabel($nom[$lng == $lang[0] ? 78 : 79]);
		$lenout     = mb_strlen($out, $charset);
		$max_height = $pos == 'NWL' ? 0 : (TYP_SCREEN == 'WEB' ? $serviz[120] : $serviz[165]);
		$txt        = '
	'.($pos == 'NWL' ? '' : '<a id="hautlastdoc'.$nbox.'"></a>').'
	<div '.($pos == 'NWL' ? 'style="text-align:center;"' : 'class="textCenter"').'>
      '.($serviz[118] == 'on' || $serviz[163] == 'on' ? sprintf($web[645], $ndays) : sprintf($web[683], FormatDate(substr($userprefs[14], 0, 8)))).'
    </div>';
		if ($lenout > 0) {
			$txt .= '
<style type="text/css">
.outLastdoc {
  height: '.($max_height > 0 ? $max_height.'px;' : 'auto;').'
  overflow: '.($max_height > 0 ? 'hidden;' : 'visible;').'
}
</style>';
            if ($pos != 'NWL') $txt .= '
    <div id="lastdoc'.$nbox.'" class="lastdoc">';
            $txt .= '
      <div class="outLastdoc">
        '.$out.'
      </div>';
            if ($max_height > 0) $txt .= '
      <div class="textRight '.(TYP_SCREEN == 'MOB' ? 'plusLastdocM' : 'plusLastdocW').'">
        <a href="#lastdoc'.$nbox.'" title="'.$web[296].'" onclick="cache(\'lastdoc'.$nbox.'\'); montre(\'lastdoc2'.$nbox.'\');">
          '.$web[505].' <img src="'.$reptheme.'/plus.png" alt="'.$web[296].'" />
        </a>
      </div>';
            if ($pos != 'NWL') $txt .= '
    </div>';
            if ($max_height > 0) $txt .= '
    <div id="lastdoc2'.$nbox.'" class="displayNone lastdoc2">'.$out.'
      <div class="textRight '.(TYP_SCREEN == 'MOB' ? 'plusLastdocM' : 'plusLastdocW').'">
        <a href="#lastdoc'.$nbox.'" title="'.$web[57].'" onclick="cache(\'lastdoc2'.$nbox.'\'); montre(\'lastdoc'.$nbox.'\');">
	      '.$web[57].' <img src="'.$reptheme.'/minus.png" alt="'.$web[57].'" />
        </a>
      </div>
    </div>';
        }
        if ($pos == 'NWL') return $txt;
        $txt .= displayQuickConfig($pos);
		if ($sidebox) {
            $titre = mb_substr(trim($titre), 0, 1, $charset) == '§' ? '' : DisplayDownArrow($dynabox[35]).$titre;
			return '
<div class="'.$pos.$tconfig.'NOV">'.boxthin($pos, $titre, $txt, ' NOV'.$pos.$tconfig, TYP_SCREEN == 'WEB' ? $dynabox[15] : $dynabox[35]).'</div>';
		} else {
            $titre = mb_substr(trim($titre), 0, 1, $charset) == '§' ? '' : $titre;
			return boxwide($pos, $titre, $txt, ' NOV'.$pos.$tconfig);
        }
	} else
		return false;
}

################################################################################

function fbox_newsarch($pos = NULL, $args = NULL) {
    global $id, $pg, $lng, $lang, $drtuser, $members, $nom, $page, $site, $serviz, $userprefs, $web, $topmess, $urlrw, $tconfig, $reptheme, $z2;
    global $type, $fileid, $status, $creadate, $moddate, $author, $email,
         $fielda1, $fielda2, $fieldb1, $fieldb2, $fieldc1, $fieldc2,
         $fieldd1, $fieldd2, $fieldweb, $fieldmail, $fieldmod;
    $out = '';
    $id = strip_tags($id);
    if ($members[0] == 'on' && $userprefs[1] == '' && !isAccessGranted($members[13])) {
    	$out .= '
<div class="textCenter web342">'.$web[342];
	if ($members[19] != '0' && $members[19] != '3') 
		$out .= '
  <p>[&nbsp;
    <a href="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[15].'-5-new-'.$tconfig.$z2 : $site['USR'].'.php?lng='.$lng.'&amp;uuser=new&amp;tconfig='.$tconfig.$z2).'" title="'.$web[160].'">'.$web[160].'</a>&nbsp;]
  </p>';
	$out .= '
</div>';
    } else {
		$archdate = ReadCounter(DBNEWSARCHDATE);
		if ($archdate > 0) {
			$out .= '
	<div class="textCenter archNews">'.$web[583].' '.FormatDate($archdate).'
	  <br />'.$web[582].' <a href="'.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[8].$z2 : $site['NE'].'.php?lng='.$lng.$z2).'" title="'.$web[581].'">'.$web[581].'
	  <img src="'.$reptheme.'/ed_copy.png" alt="" /></a>
	</div>';
		}
		if (!empty($pg)) {
			$db1 = SelectDbFieldsByField(ReadDbFields(DBNEWSARCH), 4, $pg);
			$db2 = array_filter($db1, 'IsNotEmptyTitle');
			if (1 != count($db2) || !isAccessGranted($db2[0][6]) || !isAuthorizedPublication($db2[0][5])) {
                if ($site[10] != '') {
                    header('location:'.$site[3].'error.php?lng='.$lng.'&err=404');
                    exit;
                }
                else header('HTTP/1.0 404 Not Found');
                    $dbwnews = array();
            } else {
                $dbwnews = array(array(TYP_NEWS, $pg, 'a'));
			}
		} else {
			$db1 = ReadDbFields(DBNEWSARCH);
			$db2 = array_filter($db1, 'IsNotEmptyTitle');
			$dbwnews = array();
			foreach ($db2 as $db) {
				if (isAccessGranted($db[6])) {
					$dbwnews[] = array(TYP_NEWS, $db[4], 'a');
				}
			}
		}
		@rsort($dbwnews);
        unset($db1, $db2);
		$id = empty($id) ? 1 : $id;
		$minnews = $serviz[2]*($id-1);
		$maxnews = Min($serviz[2]*$id, count($dbwnews));

        if (!empty($dbwnews)) {
            for ($i = $minnews; $i < $maxnews; $i++) {
                ReadDoc($dbwnews[$i][1], ARCHDBBASE);
                if ($lng == $lang[0]) {
                    $txt1 = $fieldb1;
                    $txt2 = $fieldc1;
                }
                else {
                    $txt1 = $fieldb2;
                    $txt2 = $fieldc2;
                }
                // date création
                if ($serviz[72] == '') {
                    $txt72 = ' - '.$web[6].' ';
                    $txt72 .= '
    <b>'.$author.'</b> ';
                } else {
                    $txt72 = '';
                }
                // auteur
                if ($serviz[73] == '') {
                    $txt73 = (empty($txt72) ? ' - ' : ' ').$web[7].' '.FormatDate($creadate);
                } else {
                    $txt73 = '';
                }
                // icone
                if (!empty($fieldd2)) {
					$txt1 = '<img src="'.CHEMIN.'img/'.$fieldd2.'" class="'.($serviz[152] == 'on' ? 'f-left' : 'f-right').'" alt="'.$fieldd2.'" />'.$txt1;
                }
                $out .= '
<div class="bord">
  <div class="forum2"><p><b>'.$txt1.'</b>'.$txt72.$txt73.'</p></div>';
                $out .= '
    <div id="texte'.$i.'" class="rep">'.$txt2.'</div><div class="c-both"></div>';
                $out .= '
  </div>
  <br />';
            }
        } elseif (!empty($pg)) {
            $out .= '
  <p>'.$web[36].'</p>';
        }
		$pg = empty($pg)? '0': $pg;
        $out .= GetNavBar(($site['URLR'] == 'on'? $lng.'-'.$urlrw[8].'-4-'.$pg.'-': 'newsarch.php?lng='.$lng.'&amp;pg='.$pg.'&amp;id='), count($dbwnews), $id, $serviz[2], $z2);
    }
    $topmess = $web[578];
    if ($page[9] != '') {
        $topmess = '<img src="'.CHEMIN.'inc/img/icons/'.$page[9].'/news.gif" class="f-right img32x32" alt="" />'.$topmess;
    }
    return boxwide($pos, $topmess, $out, 'NWA'.$pos.$tconfig);
}

################################################################################

function fbox_menubox($pos = NULL, $args = NULL) {
    global $lng, $lang, $drtuser, $site, $serviz, $userprefs, $web, $texte, $page, $urlrw, $tconfig, $charset, $reptheme,
        $type, $fileid, $status, $creadate, $moddate, $author, $email,$fielda1, $fielda2, $z2, 
		$fieldb1, $fieldb2, $fieldc1, $fieldc2,$fieldd1, $fieldd2, $fieldweb, $fieldmail, $fieldmod;
    static $nbox = 0;
    $nbox++;
	$tconfig = empty($tconfig) ? 0 : $tconfig;
    $sidebox = in_array($pos, array(BOX_LEFT, BOX_RIGHT, BOX_TOP, BOX_BOTTOM));
	$ilng    = $lng == $lang[0] ? 0 : 1 ;
    $menu    = $args[0];
    ReadDoc($menu);
    if (!isAccessGranted($fieldmod) || !isAuthorizedPublication($creadate)) return FALSE;
    if ($type != TYP_MENUBOX) return FALSE;
    if ($status != 'a') return FALSE;
    $type_menu = $fieldweb;
    $posimg    = $fieldd1;
	$class     = ' MNU'.$fileid;
	$dynbox    = explode('|', $fielda2);
    $titre     = $lng == $lang[0] ? $fieldb1 : $fieldb2;
    $contenu   = PathToImage($lng == $lang[0] ? $fieldc1 : $fieldc2);
    $len       = strlen(parse_url($site[3], PHP_URL_PATH));
    $url_self  = $site['URLR'] == 'on' ? substr($_SERVER['REQUEST_URI'], $len): substr($_SERVER['PHP_SELF'], $len).($_SERVER['QUERY_STRING'] == '' ? '' : '?'.$_SERVER['QUERY_STRING']);
	$url_self .= $site['URLR'] == 'on' ? '': (strpos($url_self, 'tconfig') > 0 ? '' : '&amp;tconfig='.$tconfig);
    $dbw       = SelectDbFieldsByField(ReadDBFields(DBOPTMENU), 5, $menu);
    /**
     * $optmenu : tableau des options de menu
     *
     * $optmenu[*][0] = catégorie
     * $optmenu[*][1] = titre de l'option
     * $optmenu[*][2] = ID de l'option de menu
     * $optmenu[*][3] = URL de l'option de menu
     * $optmenu[*][4] = target du lien
     * $optmenu[*][5] = ID de la boîte menu
     * $optmenu[*][6] = indique si c'est la page courante (true/false]
	 * $optmenu[*][7] = indique si nouveauté
	 * $optmenu[*][8] = image new ou maj
     **/
    $optmenu  = array();
    $curr_cat = '';
    foreach ($dbw as $item) {
        if (!isAccessGranted($item[6])) continue;
        ReadDoc($item[4]);
		if (!isAuthorizedPublication($creadate)) continue;
        if ((mb_substr(trim($item[2]), 0, 1, $charset) == '§' && $ilng == 0) || (mb_substr(trim($item[3]), 0, 1, $charset) == '§' && $ilng == 1)) continue;
		$fieldmail = empty($fieldmail) ? '0' : $fieldmail;
        if ($status != 'a') continue;
        if ($lng == $lang[1] && empty($fieldb2)) continue;
		$img   = '';
		$urls  = explode('||', $lng == $lang[0] ? $fieldd1 : $fieldd2);
        $ancre = '';
        $posa  = strpos($urls[0], '#');
        if ($posa !== false) $ancre = substr($urls[0], $posa);
		$pg   = '';
		if (preg_match('!https?://|ftps?://|www.!', $urls[0]))
			$url = $urls[0];
		else {
            $is_art   = strpos($urls[0], 'articles.php') !== false;
            $is_photo = strpos($urls[0], 'photorama2.php') !== false;
			if ($is_art || $is_photo) {
				$pg   = substr($urls[0], strpos($urls[0], 'pg=') + 3);
				$pos1 = strpos($pg, '&');
				$pg   = $pos1 === false ? $pg : substr($pg, 0, $pos1);
                if ($is_art) {
                    $urls[0] = 'articles.php?lng='.$lng.'&pg='.$pg.'&mnuid='.$item[5].'&tconfig='.$fieldmail.$ancre;
                    $urls[1] = $lng.'-'.$urlrw[20].'-103-'.$pg.'-'.$item[5].'-'.$fieldmail;
                }
                if ($is_photo) {
                    $urls[0] = 'photorama2.php?lng='.$lng.'&pg='.$pg.'&mnuid='.$item[5].'&tconfig='.$fieldmail;
                    $urls[1] = $lng.'-'.$urlrw[9].'-30-'.$pg.'-'.$item[5].'-'.$fieldmail;
                }
			}
			$url = empty($urls[1]) ? $urls[0] : $site['URLR'] != 'on' ? $urls[0] : $urls[1];
			if (strpos($url, $site[3]) !== false) {
				$url  = CHEMIN.substr($url, strlen($site[3]));
				$slng = (strpos($url, '?lng=') > 0 || strpos($url, '&lng=') > 0 || $site['URLR'] == 'on') ? '' : 'lng='.$lng;
				if ($slng != '') $url .= (strpos($url, '?') > 0) ? '&'.$slng : '?'.$slng;
			} else {
				$url  = CHEMIN.$url;
				$slng = (strpos($url, '?lng=') > 0 || strpos($url, '&lng=') > 0 || $site['URLR'] == 'on') ? '' : 'lng='.$lng;
				if ($slng != '') $url .= (strpos($url, '?') > 0) ? '&'.$slng : '?'.$slng;
			}
		}
		if ($fieldc1 == '_POPUP')
			$target = '	onclick="window.open(this.href, \'popup'.$item[4].'\', '
				.'\'resizable=yes,status=yes,location=no,toolbar=yes,menubar=no,fullscreen=no,scrollbars=yes,dependent=no,width=1024,left=0,height=768,top=0\'); return false;"';
		else
			$target = ' target="'.strtolower($fieldc1).'"';
		$target  = strtolower($fieldc1) == '_self' ? '' : $target;
        $is_curr = basename($url_self) == basename($url);
		$isNew   = $img != '';
        if ($is_curr) {
            $curr_cat  = trim($item[0 + $ilng]);
			$dynbox[0] = $dynbox[0] != 'off' ? 'open' : $dynbox[0];
			$dynbox[1] = $dynbox[1] != 'off' ? 'open' : $dynbox[1];
        }
		if (!empty($pg)) {
			ReadDoc($pg);
            if (($lng == $lang[0] && empty($fieldb1)) || ($lng == $lang[1] && empty($fieldb2))) continue;
            $accept = $type == TYP_ART ? ($serviz[154] == 'on' ? $serviz[136] : 'off') : ($type == TYP_PHOTO ? $serviz[142] : 'off');
			$imgpg  = getNewUpdateDoc($creadate, $moddate, $accept);
			$isNew  = $isNew || ($imgpg != '');
			$img    = $imgpg != '' ?  $imgpg : $img;
		} else {
			$imgpg = getNewUpdateDoc($creadate, $moddate, $serviz[154]);
			$isNew = $isNew || ($imgpg != '');
			$img   = $imgpg != '' ?  $imgpg : $img;
        }
        if ($isNew) {
            $dynbox[0] = 'open';
            $dynbox[1] = 'open';
        }
		$optmenu[] = array(trim($item[0 + $ilng]), trim($item[2 + $ilng]), $item[4], $url, $target, $item[5], $is_curr, $isNew, $img);
    }
    unset($dbw);
    sort($optmenu);

    $curcats = array();
    /**
     * $liste = liste des catégories et items dans l'ordre d'affichage
     *
     * $liste[*]['opt'] = item du tableau $optmenu d'où provient l'élément
     * $liste[*]['cat'] = est-ce une catégorie (true/false)
     * $liste[*]['txt'] = texte de l'élément, cad soit la [sous-]catégorie, soit le titre du lien
     * $liste[*]['niv'] = niveau d'indentation (0=racine)
     * $liste[*]['vis'] = est-ce un élément visible (true/false)
     * $liste[*]['new'] = est-ce un élément nouveau ou modifié
	 *
     **/
    $liste = array();
    foreach ($optmenu as $item) {
        if (empty($item[0])) {
            $i = 0;
        } else {
            $cats = explode('|', $item[0]);
            $xcat = '';
            for ($i = 0; $i < count($cats); $i++) {
                $xcat .= (empty($xcat) ? '' : '|').$cats[$i];
                // @ pour supprimer les NOTICE dûes à l'initialisation aléatoire des tableaux
                if (@$curcats[$i] != @$cats[$i]) {
                    $liste[] = array(
                        'cat' => TRUE, 'txt' => trim($cats[$i]), 'niv' => $i+1,
                        'vis' => (0 === strpos($curr_cat, $xcat)), 'opt' => $item, 'new' => $item[7]);
                    $curcats[$i] = $cats[$i];
                    array_splice($curcats, $i+1);
                }
            }
        }
        $liste[] = array('cat' => FALSE, 'txt' => ($posimg == 'L' ? $item[8].$item[1] : $item[1].'&nbsp;'.$item[8]), 'niv' => $i+1, 'vis' => $item[6], 'opt' => $item, 'new' => $item[7]);
    }
    unset($cats, $curcats);
    $content = '';
    if (!empty($optmenu)) {
        $out = '
<div class="'.$pos.$tconfig.'mb'.$menu.'">';
        $content = empty($contenu) ? '' : '
 <div class="box">
'.$contenu.'
 </div>';
        $typeRubrique = 'mnu'.$nbox;
      	$marqueur = $texte[3].' ';
      	$curr_marq = '<img src="'.$reptheme.'/puce2.png" alt="&gt;" class="puce" />&nbsp;';
      	$rubr = '---';

      	switch ($type_menu) {
        /**********************************************************************/
  		case "0" : // liste de menu
            $niveau = 0;
            $content .= '
 <div class="mbtype0">
  <ul class="item">';
            foreach ($liste as $item) {
                $opt = $item['opt'];
                $opt[3] = 1 != preg_match('/(ftp|http|https)$/i', $opt[3]) ? $opt[3].$z2 : $opt[3];
                while ($niveau > $item['niv']) {
                    $niveau--;
                    $padding = str_pad('', 3*$niveau);
                    $content .=  '
'.$padding.'  </ul>
'.$padding.' </div>
'.$padding.'</li>';
                }
                $niveau = $item['niv'];
                $padding = str_pad('', 3*$niveau);
                if ($item['cat']) {
                    $content .=  '
'.$padding.'<li>
'.$padding.' <div>
'.$padding.'  <p class="rubr categ niv'.$item['niv'].'">'.$item['txt'].'</p>
'.$padding.'  <ul class="item">';
                }
                else {
                    $content .= '
'.$padding.'<li class="link '.($opt[6] ? 'curr_item' : 'item').' niv'.$item['niv'].'">'.($opt[6] ? $curr_marq : $marqueur).'<a href="'.htmlentities($opt[3]).'" title="'.strip_tags($opt[1]).'"'.$opt[4].'>'.$item['txt'].'</a>';
        			$content .= displayQuickConfig(NULL, $opt[2], 'optmenu&amp;menubox='.$opt[5].'&amp;form=2&amp;tri=-id&amp;id='.$opt[2], '', '', 17);
                    $content .= '
'.$padding.'</li>';
                }
            }
            while ($niveau > 1) {
                $niveau--;
                $padding = str_pad('', 3*$niveau);
                $content .= '
'.$padding.'  </ul>
'.$padding.' </div>
'.$padding.'</li>';
            }
            $content .= '
  </ul>
 </div>';
    	break;

        /**********************************************************************/
    	case "1" : // menu dynamique
            $niveau = 0;
            $content .= '
 <div class="mbtype1">
  <form name="'.$typeRubrique.'" method="post">
   <p class="ta-center">';
            foreach ($liste as $item) {
                $opt = $item['opt'];
                $opt[3] = 1 != preg_match('/(ftp|http|https)$/i', $opt[3]) ? $opt[3].$z2 : $opt[3];
                if ($item['cat'] && 1 == $item['niv']) {
                    if (0 != $niveau) {
            $content .= '
    </select>';
                    }
                    $content .= '
    <select size="1" onchange="if (\'\' != this.value) { document.'.$typeRubrique.'.action=this.value; document.'.$typeRubrique.'.submit(); }" title="">';
                }
                $selected = $opt[6] ? ' selected="selected"' : '';
                $padding = '';
                for ($i = 1; $i < $item['niv']; $i++) $padding .= '&nbsp; ';
                if ($item['cat']) {
                    $content .= '
     <option class="categ niv'.$item['niv'].'" value=""'.$selected.'>'.$padding.strip_tags($item['txt']).'</option>';
                } else {
                    if (0 == $niveau) {
                    $content .= '
    <select size="1" onchange="if (\'\' != this.value) { document.'.$typeRubrique.'.action=this.value; document.'.$typeRubrique.'.submit(); }" title="">';
                    }
            		$content .= '
     <option class="link niv'.$item['niv'].($opt[6] ? ' current' : '').'" value="'.$opt[3].'"'.$selected.'>'.$padding.$marqueur.strip_tags($item['txt']).'</option>';
                }
                $niveau = $item['niv'];
            }
            $content .= '
    </select>
   </p>
  </form>
 </div>';
            break;

        /**********************************************************************/
    	case "2" : // menu liste dynamique n°1
    		$openimg = $reptheme.'/plus.png';
    		$closeimg = $reptheme.'/minus.png';
        /**********************************************************************/
    	case "3" : // menu liste dynamique n°2
    		if ($type_menu == "3") {
        		$openimg = $reptheme.'/open.png';
        		$closeimg = $reptheme.'/close.png';
    		}

            $niveau = 0;
			$cpt    = 0;
			$nliste = $liste;
            $nums   = array_pad(array(), 12, 1);
            $bids   = array();
            $cache  = '';
			$padding = '';
            $content .= '
 <div class="mbtype'.$type_menu.'">
  <ul class="item">';
            foreach ($liste as $item) {
                $opt = $item['opt'];
                $opt[3] = 1 != preg_match('/(ftp|http|https)$/i', $opt[3]) ? $opt[3].$z2 : $opt[3];
                while ($niveau > $item['niv']) {
                    $niveau--;
                    $padding = str_pad('', 3*$niveau);
                    $content .=  '
'.$padding.'  </ul>
'.$padding.' </div>
'.$padding.'</li>';
                }
                $niveau = $item['niv'];
                $padding = str_pad('', 3*$niveau);
                if ($item['cat']) {
					$n = $cpt + 1;
					$isNew = false;
					while ($n < count($nliste) && $nliste[$n]['niv'] > $niveau) {
						if ($nliste[$n]['new']) {
							$isNew = true;
							break;
						}
						$n++;
					} 
                    $baseid = 'mb'.$opt[5].'_'.$item['niv'].'_'.$nums[$item['niv']]++;
                    if (!$item['vis'] && !$isNew) {
                        $cache .= '
  $(\'#'.$baseid.'\').toggle(); $(\'#'.$baseid.'p\').toggle(); $(\'#'.$baseid.'m\').toggle();';
                    }
                    $content .=  '
'.$padding.'<li>
'.$padding.' <div>
'.$padding.'  <p class="rubr categ niv'.$item['niv'].'" data-rubrid="'.$baseid.'">'
    .'<img id="'.$baseid.'p" class="displayNone" src="'.$openimg.'" alt="'.$web[429].'" title="'.$web[429].'"  />'
    .'<img id="'.$baseid.'m" src="'.$closeimg.'" alt="'.$web[57].'" title="'.$web[57].'" /> '.$item['txt'].'</p>
'.$padding.'  <ul id="'.$baseid.'" class="item">';
                }
                else {
                    $content .= '
'.$padding.'<li class="link '.($opt[6] ? 'curr_item' : 'item').' niv'.$item['niv'].'">'.($opt[6] ? $curr_marq : $marqueur).'<a href="'.htmlentities($opt[3]).'" title="'.strip_tags($opt[1]).'"'.$opt[4].'>'.$item['txt'].'</a>';
        			$content .= displayQuickConfig(NULL, $opt[2], 'optmenu&amp;menubox='.$opt[5].'&amp;form=2&amp;tri=-id&amp;id='.$opt[2], '', '', 17);
                    $content .= '
'.$padding.'</li>';
                }
				$cpt++;
            }
            while ($niveau > 1) {
                $niveau--;
                $padding = str_pad('', 3*$niveau);
                $content .= '
'.$padding.'  </ul>
'.$padding.' </div>
'.$padding.'</li>';
            }
            $content .= '
  </ul>
 </div>';
            if ($cache != '') {
                $content .= BeginJavascript().$cache.EndJavascript();
            }
            break;

        /**********************************************************************/
    	case "4" : // menu dynamique compact
            $content .= '
 <div class="mbtype4">
  <form name="'.$typeRubrique.'" method="post">
   <p class="ta-center">
    <select size="1" onchange="if (\'\' != this.value) { document.'.$typeRubrique.'.action=this.value; document.'.$typeRubrique.'.submit(); }" title="">';
            foreach ($liste as $item) {
                $opt = $item['opt'];
                $selected = $opt[6] ? ' selected="selected"' : '';
                $padding = '';
                for ($i = 1; $i < $item['niv']; $i++) $padding .= '&nbsp; ';
                if ($item['cat']) {
            		$content .= '
     <option class="categ niv'.$item['niv'].'" value=""'.$selected.'>'.$padding.strip_tags($item['txt']).'</option>';
                } else {
            		$content .= '
     <option class="link niv'.$item['niv'].($opt[6] ? ' current' : '').'" value="'.$opt[3].'"'.$selected.'>'.$padding.$marqueur.strip_tags($item['txt']).'</option>';
                }
            }
            $content .= '
    </select>
   </p>
  </form>
 </div>';
            break;

        }
        $content .= displayQuickConfig($pos, $menu, 'menu&amp;form=2&amp;tri=ch&amp;id='.$menu, '', '', 17);
        $titre    = mb_substr(trim($titre), 0, 1, $charset) == '§' ? '' : $titre;
        if ($sidebox) {
            $titre = DisplayDownArrow($dynbox[1]).$titre;
            $out  .= boxthin($pos, $titre, $content, $class, TYP_SCREEN == 'WEB' ? $dynbox[0] : $dynbox[1]);
        } else {
            $out .= boxwide($pos, $titre, $content, $class);
        }
        $out .= '
</div>';
        return $out;
    } else {
        return false;
    }
}

################################################################################

function fbox_ddmenubox($pos = NULL, $args = NULL) {
    global $lng, $lang, $drtuser, $site, $serviz, $userprefs, $web, $urlrw, $tconfig, $charset, $meskin, $reptheme, $z2;
    global $type, $fileid, $status, $creadate, $moddate, $author, $email,
         $fielda1, $fielda2, $fieldb1, $fieldb2, $fieldc1, $fieldc2,
         $fieldd1, $fieldd2, $fieldweb, $fieldmail, $fieldmod;
    static $nbox = 0;
    $nbox++;
    $sidebox = $pos == BOX_LEFT || $pos == BOX_RIGHT;
	$ilng    = $lng == $lang[0] ? 0 : 1 ;
    $menu    = $args[0];
    ReadDoc($menu);
    if (!isAccessGranted($fieldmod) || !isAuthorizedPublication($creadate)) return FALSE;
    if ($type != TYP_DDMENUBOX) return FALSE;
    if ($status != 'a') return FALSE;
    $len       = strlen(parse_url($site[3], PHP_URL_PATH));
    $url_self  = $site['URLR'] == 'on' ? substr($_SERVER['REQUEST_URI'], $len) : (substr($_SERVER['PHP_SELF'], $len).($_SERVER['QUERY_STRING'] == '' ? '' : '?'.$_SERVER['QUERY_STRING']));
	$url_self .= $site['URLR'] == 'on' ? '' : (strpos($url_self, 'tconfig') > 0 ? '' : '&amp;tconfig='.$tconfig);
    $type_menu = $fielda2;
	$class     = $type_menu.$fileid;
    $titre     = $lng == $lang[0] ? $fieldb1 : $fieldb2;
	$titre     = mb_substr(trim($titre), 0, 1, $charset) == '§' ? '' : $titre;
    $dbw       = SelectDbFieldsByField(ReadDBFields(DBOPTDDMENU), 5, $menu);
	$optmenu   = array();
    $is_curr   = false;
    sort($dbw);
    $num = 0;
    foreach ($dbw as $item) {
        if (!isAccessGranted($item[6])) continue;
        ReadDoc($item[4]);
		if (!isAuthorizedPublication($creadate)) continue;
        if ($status != 'a') continue;
		if ($type_menu == 'DDL') {
			$panel     = PathToImage($ilng == 0 ? $fieldc1 : $fieldc2);
			$optmenu[] = array(trim($item[2 + $ilng]), $panel);
		} else {
			$urls     = explode('||', $lng == $lang[0] ? $fieldd1 : $fieldd2);
            $is_art   = strpos($urls[0], 'articles.php') !== false;
            $is_photo = strpos($urls[0], 'photorama2.php') !== false;
			$icon     = $fieldc2;
			$url      = '';
			$target   = '';
			if (trim($urls[0]) != '?') {
				if (preg_match('!https?://|ftps?://|www.!', $urls[0]))
					$url = $urls[0];
				else {
					$urls[0] = strpos($urls[0], 'tconfig') > 0 ? $urls[0] : ($urls[0].'&tconfig='.(empty($fieldmail) ? $tconfig : $fieldmail));
					if (!empty($urls[1]) && $fieldmail > 0 && ($is_art || $is_photo)) {
                        $pg   = substr($urls[0], strpos($urls[0], 'pg=') + 3);
                        $pos1 = strpos($pg, '&');
                        $pg   = $pos1 === false ? $pg : substr($pg, 0, $pos1);
                        if ($is_art) $urls[1] = $lng.'-'.$urlrw[20].'-102-'.$pg.'-'.$fieldmail;
                        if ($is_photo) $urls[1] = $lng.'-'.$urlrw[9].'-2-'.$pg.'-'.$fieldmail;
					}
					$url = empty($urls[1]) ? $urls[0] : ($site['URLR'] != 'on' ? $urls[0] : $urls[1]);
                    $is_curr = $url_self == $url ? true : false;
					if (strpos($url, $site[3]) !== false) {
						$url  = CHEMIN.substr($url, strlen($site[3]));
						$slng = (strpos($url, '?lng=') > 0 || strpos($url, '&amp;lng=') > 0 || $site['URLR'] == 'on') ? '' : 'lng='.$lng;
						if ($slng != '') $url .= (strpos($url, '?') > 0) ? '&amp;'.$slng : '?'.$slng;
					} elseif ($url != '#') {
						$url  = CHEMIN.$url;
						$slng = (strpos($url, '?lng=') > 0 || strpos($url, '&lng=') > 0 || $site['URLR'] == 'on') ? '' : 'lng='.$lng;
						if ($slng != '') $url .= (strpos($url, '?') > 0) ? '&'.$slng : '?'.$slng;
					}
                    $url = 1 != preg_match('/(ftp|http|https)$/i', $url) ? $url.(strstr($url, 'index.php') ? '' : $z2) : $url;
				}
				if (strtoupper($fieldc1) == '_POPUP')
					$target = '	onclick="window.open(this.href, \'popup'.$item[4].'\', 
						\'resizable=yes,status=yes,location=no,toolbar=yes,menubar=no,fullscreen=no,scrollbars=yes,dependent=no,width=1024,left=0,height=768,top=0\'); return false;"';
				else
					$target = ' target="'.strtolower($fieldc1).'"';
				$target = strtolower($fieldc1) == '_self' ? '': $target;
			}
			$optmenu[] = array($item[0], trim($item[2 + $ilng]), str_replace('&', '&amp;', $url), $target, $icon, $fielda1, $is_curr);
            if ($is_curr) {
                $pos = strrpos($item[0], '-');
                $pos = $pos !== false ? $pos : 10;
                $niv = substr($item[0], 0, $pos);
                for ($j = $num; $j > -1; $j--) {
                    if ($niv == $optmenu[$j][0] && 1 !== preg_match('!https?://|ftps?://|www.!', $optmenu[$j][2])) {
                        $pos            = strrpos($niv, '-');
                        $pos            = $pos !== false ? $pos : 10;
                        $niv            = substr($niv, 0, $pos);
                        $optmenu[$j][6] = $j > ($typ_menu == 'DDH' ? 0 : -1) ? true : false;
                        $is_curr        = false;
                        if ($pos == 1) break;
                    }
                }
            }
		}
        $num++;
    }
    unset($dbw);
    if (!empty($optmenu)) {
		sort($optmenu);
        $downarrow  = '<span class="f-right ddmArrow" title="">&#xe807;</span>';
        $rightarrow = '<span class="f-right ddmArrow" title="">&#xe80a;</span>';
		if ($type_menu == 'DDL') {
			$out = '';
			$content = '
    <ul class="dropdown dropdown-linear">';
			$n = 0;
			foreach ($optmenu as $opt) {
				$content .= '
	  <li class="T'.$n.'">'.$opt[0].'
		<ul>
		  <li class="C'.$n.'">'.$opt[1].'</li>
		</ul>
	  </li>';
				$n++;
			}
			$content .= '
	</ul>';
            $out .= boxwide($pos, $titre, $content, ' noborder bknocolor '.$class);
			$out .= displayQuickConfig($pos, false, '', '', '', 17);
			return $out;
		} else {
			$out = '
<div class="tbldiv '.$class.'">
  <div class="trtbldiv">
    <div class="tdtbldiv">';
			switch ($type_menu) {
			case 'DDH' :
				$content = '
      <ul class="dropdown dropdown-horizontal  H'.$nbox.'">';
				break;
			case 'DDV' :
				$content = '
      <ul class="dropdown dropdown-vertical  V'.$nbox.'">';
				break;
			case 'DDM' :
				$content = '
      <ul class="menu-vertical  M'.$nbox.'">';
				break;
			}
			switch ($type_menu) {
            case 'DDH' :
            case 'DDV' :
                $cnt = count($optmenu);
                $i   = 0;
                while ($i < $cnt) {
                    $img = empty($optmenu[$i][4]) ? '' : '<img src="'.CHEMIN.'img/'.$optmenu[$i][4].'" class="ddmImg" />';
                    $cur = explode('-', $optmenu[$i][0]);
                    $c   = count($cur);
                    $p   = $c;
                    if ($i > 0) {
                        $pred = explode('-', $optmenu[$i - 1][0]);
                        $p    = count($pred);
                    }
                    if ($i + 1 < $cnt) {
                        $succ = explode('-', $optmenu[$i + 1][0]);
                        $s    = count($succ);
                    }
                    if ($c == $s)
                        $content .= $optmenu[$i][2] == '' ? '
	    <li class="L'.$optmenu[$i][0].($optmenu[$i][6]  ? ' dd_current' : '').'">'.$img.$optmenu[$i][1] : '
	      <a href="'.$optmenu[$i][2].'"'.$optmenu[$i][3].'><li class="L'.$optmenu[$i][0].($optmenu[$i][6] ? ' dd_current' : '').'">'.$img.$optmenu[$i][1].'</li></a>';
                    elseif ($s > $c) {
                        $arrow    = $c == 1 ? $downarrow : $rightarrow;
                        $content .= $optmenu[$i][2] == '' ? '
	    <li class="L'.$optmenu[$i][0].($optmenu[$i][6] ? ' dd_current' : '').'">'.$img.$optmenu[$i][1].$arrow : '
	      <a href="'.$optmenu[$i][2].'"'.$optmenu[$i][3].'><li class="L'.$optmenu[$i][0].($optmenu[$i][6] ? ' dd_current' : '').'">'.$img.$optmenu[$i][1].$arrow.'</li></a>';
                        $content .= '
	    <ul>';					
                    }
                    elseif ($s < $c) {
                        $content .= $optmenu[$i][2] == '' ? '
	    <li class="L'.$optmenu[$i][0].($optmenu[$i][6] ? ' dd_current' : '').'">'.$img.$optmenu[$i][1].'</li>' : '
	      <a href="'.$optmenu[$i][2].'"'.$optmenu[$i][3].'><li class="L'.$optmenu[$i][0].($optmenu[$i][6] ? ' dd_current' : '').'">'.$img.$optmenu[$i][1].'</li></a>';
                        $content .= '
	    </ul>
	    </li>';
                        for ($k = 1; $k < $c - $s; $k++)
                            $content .= '
	    </ul>
	    </li>';
                    }
                    $i++;
                }
                break;
            case 'DDM' :
                $cnt = count($optmenu);
                $i   = 0;
                while ($i < $cnt) {
                    $img = empty($optmenu[$i][4]) ? '' : '<img src="'.CHEMIN.'img/'.$optmenu[$i][4].'" class="ddmImg" />';
                    $cur = explode('-', $optmenu[$i][0]);
                    if (count($cur) == 1 && !empty($optmenu[$i][2])) {
                        $content .= '
        <li class="L'.$optmenu[$i][0].'"><a href="'.$optmenu[$i][2].'"'.$optmenu[$i][3].'>'.$img.$optmenu[$i][1].'</a>'.(count($cur) == 1 ? '<ul></ul>' : '').'</li>';
                    }
                    if (count($cur) == 1 && empty($optmenu[$i][2])) {
                        $content .= '
        <li class="L'.$optmenu[$i][0].'"><a href="#">'.$img.$optmenu[$i][1].$downarrow.'</a>
          <ul>';
                        while ($i < $cnt) {
                            if (!empty($optmenu[$i][2])) 
                                $content .= '
            <li class="L'.$optmenu[$i][0].'"><a href="'.$optmenu[$i][2].'"'.$optmenu[$i][3].'>'.$img.$optmenu[$i][1].'</a></li>';
                            if (empty($optmenu[$i+1][2]) || count(explode('-', $optmenu[$i+1][5])) == 1) {
                                $content .= '
          </ul>
        </li>';
                                break;
                            }
                            $i++;
                        }
                    }
                    $i++;
                }
                break;
            }
			$content .= '
	  </ul>';
			if ($sidebox) {
				$out .= boxthin($pos, $titre, $content, ' noborder bknocolor '.$class);
			} else {
				$out .= boxwide($pos, $titre, $content, ' noborder bknocolor '.$class);
			}
			$out .= displayQuickConfig($pos, false, '', '', '', 17);
			$out .= '
    </div>
  </div>
</div>';
			return $out;
		}
    } else {
        return false;
    }
}

################################################################################

function fbox_contact($pos = NULL, $args = NULL) {
    global $lng, $lang, $drtuser, $nom, $urlrw, $site, $serviz, $userprefs, $web, $dynabox, $tconfig, $charset, $reptheme, $menuico, $z2;
    if ($serviz[99] == '') return false;
    $tconfig = $menuico[21] == 'ALL' ? $tconfig : $menuico[21];
	$out = '
<div class="box textLeft">';
	$ctfiles = ReadDBFields(CONFIGREP.'ctconfigs.dtb');
	foreach($ctfiles as $ct) {
		if ($ct[2] == 'a') $out .= '
  <div class="itemContact'.(TYP_SCREEN == 'WEB' ? 'W' : 'M').'">
    <a href="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[2].'-2-'.$ct[1].'-'.$tconfig.$z2 : $site['CT'].'.php?lng='.$lng.'&amp;ctconfig='.$ct[1].'&amp;tconfig='.$tconfig.$z2).'" title="'.$ct[$lng == $lang[0] ? 3 : 4].'">
	  <img alt="mail" src="'.$reptheme.'/mail.png" class="imgContact" />'.($ct[$lng == $lang[0] ? 3 : 4]).'
	</a>
  </div>';
	}
    $out .= '
</div>';
    $out .= displayQuickConfig($pos, false, 'contact', '', '', 13);
	$titre = TYP_SCREEN == 'WEB' ? getLabel($nom[$lng == $lang[0] ? 56 : 57]) : getLabel($nom[$lng == $lang[0] ? 80 : 81]);
	$titre = mb_substr(trim($titre), 0, 1, $charset) == '§' ? '' : DisplayDownArrow($dynabox[36]).$titre;
    return '
<div class="'.$pos.$tconfig.'CT">'.boxthin($pos, $titre, $out, ' CT'.$pos.$tconfig, TYP_SCREEN == 'WEB' ? $dynabox[16] : $dynabox[36]).'
</div>';
}

################################################################################

function fbox_photobox($pos = NULL, $args = NULL) {
    global $lng, $lang, $drtuser, $nom, $urlrw, $site, $serviz, $userprefs, $web, $dynabox, $tconfig, $charset, $reptheme, $z2, $titre;
	if (!in_array($pos, array(BOX_EDITO, BOX_LEFT, BOX_RIGHT, BOX_ABOVE, BOX_UNDER, BOX_TOP, BOX_BOTTOM))) return false;
    static $nbox = 0;
    $nbox++;
	$phs = ReadDBFields(DBPHOTO);
	$dps = array();
	$n   = 0;
	foreach ($phs as $ph) {
        if (isAccessGranted($ph[6]) && is_file(CHEMIN.'photo/gal_'.$ph[4].'/params_'.$ph[4].INCEXT)) {
            include CHEMIN.'photo/gal_'.$ph[4].'/params_'.$ph[4].INCEXT;
            if ($param9 == 'on' && empty($param10)) $dps[] = array($ph[4], $n);
            $param9 = '';
        }
        $n++;
	}
    $serviz[83] = TYP_SCREEN == 'WEB' ? $serviz[83] : '1';
	if (empty($dps)) return false;
	$nb   = rand(0, count($dps) - 1);
	$dir  = 'gal_'.$dps[$nb][0];
	$gals = ReadDBFields(CHEMIN.'photo/'.$dir.'/'.$dir.DBEXT);
    $imgs = array();
	foreach ($gals as $img) if ($img[1] == 'a') $imgs[] = $img;
	if (empty($imgs)) return false;
    $nbimg = count($imgs);
	$title = $phs[$dps[$nb][1]][$lng == $lang[0] ? 2 : 3];
	$tpos  = mb_strpos($title, '-->');
	$title = $tpos === false ? $title : mb_substr($title, $tpos + 3);
	$out = '
<div class="textCenter marginAuto">
  <div class="phtitlebox">
    <a href="'.CHEMIN.($site['URLR'] == 'on' ? $lng.'-'.$urlrw[9].'-2-'.$phs[$dps[$nb][1]][4].'-'.$tconfig.$z2 : 'photorama2.php?lng='.$lng.'&amp;pg='.$phs[$dps[$nb][1]][4].'&amp;tconfig='.$tconfig.$z2).'" title="'.$title.'">'.$title.'</a>
  </div>';
    $ugw  = in_array($pos, array(BOX_LEFT, BOX_RIGHT)) ? intval($titre[$pos == BOX_LEFT ? 13 : 20]) : (in_array($pos, array(BOX_ABOVE, BOX_UNDER, BOX_EDITO)) ? 540 : 200);
    $ugh  = intval($ugw * 0.75);
    $long = floor($ugw / 17);
    $nblg = intval(floor($nbimg / ($long > 0 ? $long : 1))) + ($long * 17 > $ugw ? 1 : 0);
	switch ($serviz[83]) {
	case '0' :
        $out .= '
  <script src="inc/unitegallery/themes/tilesgrid/ug-theme-tilesgrid.js" type="text/javascript"></script>
  <script type="text/javascript">
    jQuery(document).ready(function(){
	  jQuery("#'.$pos.$nbox.$dir.'").unitegallery({
		gallery_theme: "tilesgrid",
        grid_num_rows: 1,
        theme_navigation_type: "arrows",
        theme_arrows_margin_top: 8,
        tile_border_width: 3,
        tile_border_radius: 8,
        tile_enable_shadow: false,
        lightbox_type: "compact",
        lightbox_arrows_position: "inside",
      });
    });
  </script>';
		break;
	case '1' :
        $out .= '
  <script src="inc/unitegallery/themes/carousel/ug-theme-carousel.js" type="text/javascript"></script>
  <script type="text/javascript">
    jQuery(document).ready(function(){
	  jQuery("#'.$pos.$nbox.$dir.'").unitegallery({
		gallery_theme: "carousel",
        theme_navigation_margin: 0,
        tile_border_width: 3,
        tile_width: '.$ugw.',
        tile_height: '.$ugh.',
        tile_border_radius: 0,
        tile_enable_shadow: false,
        lightbox_type: "compact",
        lightbox_arrows_position: "inside",
      });
    });
  </script>';
		break;
	case '2' :
        $out .= '
  <script src="inc/unitegallery/themes/slider/ug-theme-slider.js" type="text/javascript"></script>
  <script type="text/javascript">
    jQuery(document).ready(function(){
	  jQuery("#'.$pos.$nbox.$dir.'").unitegallery({
		gallery_theme: "slider",
        gallery_width: '.$ugw.',
        gallery_height: '.($ugh + 32 + ($nblg * 15)).',
        slider_transition: "fade",
        slider_transition_speed: 1500,
        slider_enable_zoom_panel: false,
        slider_enable_arrows: false,
        slider_enable_progress_indicator: false,
        slider_item_padding_bottom: '.(32 + ($nblg * 15)).',
      });
    });
  </script>';
		break;
	}
	$out .= '
  <div id="'.$pos.$nbox.$dir.'" style="display:none;margin:auto;">';
	foreach ($imgs as $img) {
		$out .= '
    <img alt="" src="'.CHEMIN.'photo/'.$dir.'/'.$img[2].'" style="display:none;" />';
	}
	$out .= '
  </div>
</div>';
    $out .= displayQuickConfig($pos, false, '', '', '', 18);
	$titre = TYP_SCREEN == 'WEB' ? getLabel($nom[$lng == $lang[0] ? 30 : 31]) : getLabel($nom[$lng == $lang[0] ? 82 : 83]);
	$titre = mb_substr(trim($titre), 0, 1, $charset) == '§' ? '' : DisplayDownArrow($dynabox[37]).$titre;
	return '
<div class="'.$pos.$tconfig.'SWPH">'.boxthin($pos, $titre, $out, ' photobox SWPH'.$pos.$tconfig, TYP_SCREEN == 'WEB' ? $dynabox[17] : $dynabox[37]).'</div>';
}

################################################################################

function isAdmin($pseudo) {
    global $serviz;
    if (empty($pseudo) && trim($serviz[31]) == '' && trim($serviz[176]) == '' && is_file(CHEMIN.'install/install.php')) return TRUE;
    if ($pseudo == $serviz[31] || $pseudo == $serviz[176]) return TRUE;
    if ($serviz[42] == 'on') {
		static $admins = null;
		if (!isset($admins)) {
			$admins = ReadDbFields(ADMINS);
		}
		foreach ($admins as $admin) {
			if ($pseudo == $admin[0]) return TRUE;
		}
	}
    return FALSE;
}
?>